@@ -392,6 +392,26 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
         sage: c^3 * a * b^2
         a*b^2*c^3
 
+    Two free algebras are considered the same if they have the same
+    base ring, number of generators and variable names, and the same
+    implementation::
+
+        sage: F = FreeAlgebra(QQ,3,'x')
+        sage: F == FreeAlgebra(QQ,3,'x')
+        True
+        sage: F is FreeAlgebra(QQ,3,'x')
+        True
+        sage: F == FreeAlgebra(ZZ,3,'x')
+        False
+        sage: F == FreeAlgebra(QQ,4,'x')
+        False
+        sage: F == FreeAlgebra(QQ,3,'y')
+        False
+
+    Note that since :trac:`7797` there is a different
+    implementation of free algebras. Two corresponding free
+    algebras in different implementations are not equal, but there
+    is a coercion.
     """
     Element = FreeAlgebraElement
     def __init__(self, R, n, names):
@@ -468,41 +488,6 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
         """
         return self.__ngens <= 1 and self.base_ring().is_commutative()
 
-    def __eq__(self, other):
-        """
-        Two free algebras are considered the same if they have the same
-        base ring, number of generators and variable names, and the same
-        implementation.
-
-        EXAMPLES::
-
-            sage: F = FreeAlgebra(QQ,3,'x')
-            sage: F == FreeAlgebra(QQ,3,'x')
-            True
-            sage: F is FreeAlgebra(QQ,3,'x')
-            True
-            sage: F == FreeAlgebra(ZZ,3,'x')
-            False
-            sage: F == FreeAlgebra(QQ,4,'x')
-            False
-            sage: F == FreeAlgebra(QQ,3,'y')
-            False
-
-        Note that since :trac:`7797` there is a different
-        implementation of free algebras. Two corresponding free
-        algebras in different implementations are not equal, but there
-        is a coercion.
-        """
-        if not isinstance(other, FreeAlgebra_generic):
-            return False
-        if self.base_ring() != other.base_ring():
-            return False
-        if self.__ngens != other.ngens():
-            return False
-        if self.variable_names() != other.variable_names():
-            return False
-        return True
-
     def _repr_(self):
         """
         Text representation of this free algebra.
