@@ -34,17 +34,14 @@ TESTS::
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 from __future__ import print_function
+from six import iteritems
 
 from sage.misc.misc import repr_lincomb
 from sage.monoids.free_monoid_element import FreeMonoidElement
 from sage.modules.with_basis.indexed_element import IndexedFreeModuleElement
-from sage.combinat.free_module import CombinatorialFreeModule
 from sage.structure.element import AlgebraElement
 
 
-import six
-
-
 class FreeAlgebraElement(IndexedFreeModuleElement, AlgebraElement):
     """
     A free algebra element.
@@ -173,7 +170,7 @@ class FreeAlgebraElement(IndexedFreeModuleElement, AlgebraElement):
         # I don't start with 0, because I don't want to preclude evaluation with
         # arbitrary objects (e.g. matrices) because of funny coercion.
         result = None
-        for m, c in six.iteritems(self._monomial_coefficients):
+        for m, c in iteritems(self._monomial_coefficients):
             if result is None:
                 result = c*m(x)
             else:
