@@ -249,18 +249,41 @@ class LieAlgebra(Parent, UniqueRepresentation): # IndexedGenerators):
     **5.** We construct a free Lie algebra in a few different ways. There are
     two primary representations, as brackets and as polynomials::
 
-        sage: L = LieAlgebra(QQ, 'x,y,z'); L # not tested #16823
+        sage: L = LieAlgebra(QQ, 'x,y,z'); L
         Free Lie algebra generated by (x, y, z) over Rational Field
         sage: P.<a,b,c> = LieAlgebra(QQ, representation="polynomial"); P
         Lie algebra generated by (a, b, c) in
          Free Algebra on 3 generators (a, b, c) over Rational Field
 
-    We currently (:trac:`16823`) have the free Lie algebra given in the
-    polynomial representation, which is the Lie subalgebra of the Free
-    algebra generated by the degree-`1` component.
+    This has the basis given by Hall and the one indexed by Lyndon words.
+    We do some computations and convert between the bases::
+
+        sage: H = L.Hall()
+        doctest:warning...:
+        FutureWarning: The Hall basis has not been fully proven correct, but currently no bugs are known
+        See http://trac.sagemath.org/16823 for details.
+        sage: H
+        Free Lie algebra generated by (x, y, z) over Rational Field in the Hall basis
+        sage: Lyn = L.Lyndon()
+        sage: Lyn
+        Free Lie algebra generated by (x, y, z) over Rational Field in the Lyndon basis
+        sage: x,y,z = Lyn.lie_algebra_generators()
+        sage: a = Lyn([x, [[z, [x, y]], [y, x]]]); a
+        -[x, [[x, y], [x, [y, z]]]] - [x, [[x, y], [[x, z], y]]]
+        sage: H(a)
+        [[x, y], [z, [x, [x, y]]]] - [[x, y], [[x, y], [x, z]]]
+         + [[x, [x, y]], [z, [x, y]]]
+
+    We also have the free Lie algebra given in the polynomial
+    representation, which is the canonical embedding of the free
+    Lie algebra into the free algebra (i.e., the ring of
+    noncommutative polynomials).
     So the generators of the free Lie algebra are the generators of the
     free algebra and the Lie bracket is the commutator::
 
+        sage: P.<a,b,c> = LieAlgebra(QQ, representation="polynomial"); P
+        Lie algebra generated by (a, b, c) in
+         Free Algebra on 3 generators (a, b, c) over Rational Field
         sage: P.bracket(a, b) + P.bracket(a - c, b + 3*c)
         2*a*b + 3*a*c - 2*b*a + b*c - 3*c*a - c*b
 
@@ -391,9 +414,8 @@ class LieAlgebra(Parent, UniqueRepresentation): # IndexedGenerators):
             #   subclass with specialized methods for the free Lie algebra
             return LieAlgebraFromAssociative(F, F.gens(), names=names, index_set=index_set)
 
-        raise NotImplementedError("the free Lie algebra has only been"
-                                  " implemented using polynomials in the"
-                                  " free algebra, see trac ticket #16823")
+        from sage.algebras.lie_algebras.free_lie_algebra import FreeLieAlgebra
+        return FreeLieAlgebra(R, names, index_set)
 
     def __init__(self, R, names=None, category=None):
         """
@@ -497,6 +519,38 @@ class LieAlgebra(Parent, UniqueRepresentation): # IndexedGenerators):
 
         return self.base_ring().has_coerce_map_from(R.base_ring())
 
+    def _Hom_(self, Y, category):
+        """
+        Return the homset from ``self`` to ``Y`` in the category ``category``.
+
+        INPUT:
+
+        - ``Y`` -- a Lie algebra
+        - ``category`` -- a subcategory of :class:`LieAlgebras` or ``None``
+
+        The sole purpose of this method is to construct the homset
+        as a :class:`~sage.algebras.lie_algebras.morphism.LieAlgebraHomset`.
+
+        This method is not meant to be called directly. Please use
+        :func:`sage.categories.homset.Hom` instead.
+
+        EXAMPLES::
+
+            sage: L.<x,y> = LieAlgebra(QQ)
+            sage: H = L.Hall()
+            sage: Hom(H, H)
+            Set of Lie algebra morphisms from
+             Free Lie algebra generated by (x, y) over Rational Field in the Hall basis
+             to Free Lie algebra generated by (x, y) over Rational Field in the Hall basis
+        """
+        cat = LieAlgebras(self.base_ring())
+        if category is not None and not category.is_subcategory(cat):
+            raise TypeError("%s is not a subcategory of Lie algebras"%category)
+        if Y not in cat:
+            raise TypeError("%s is not a Lie algebra"%Y)
+        from sage.algebras.lie_algebras.morphism import LieAlgebraHomset
+        return LieAlgebraHomset(self, Y, category=category)
+
     @cached_method
     def zero(self):
         """
