@@ -15,7 +15,7 @@ intended effect of your patch.
     sage: from sage import *
     sage: frames = [x for x in gc.get_objects() if inspect.isframe(x)]
 
-We exclude the dependencies and check to see that there are no others 
+We exclude the dependencies and check to see that there are no others
 except for the known bad apples::
 
     sage: allowed = [
@@ -210,6 +210,7 @@ copyright = license
 _cpu_time_ = cputime()
 _wall_time_ = walltime()
 
+
 def quit_sage(verbose=True):
     """
     If you use Sage in library mode, you should call this function
@@ -239,14 +240,6 @@ def quit_sage(verbose=True):
     import sage.libs.flint.flint
     sage.libs.flint.flint.free_flint_stack()
 
-    # stop the twisted reactor
-    try:
-       from twisted.internet import reactor
-       if reactor.running:
-          reactor.callFromThread(reactor.stop)
-    except ImportError:
-       pass
-
     # Free globally allocated mpir integers.
     import sage.rings.integer
     sage.rings.integer.free_integer_pool()
@@ -257,15 +250,16 @@ def quit_sage(verbose=True):
     symmetrica.end()
 
 
-sage.structure.sage_object.register_unpickle_override('sage.categories.category', 'Sets', Sets)
-sage.structure.sage_object.register_unpickle_override('sage.categories.category_types', 'HeckeModules', HeckeModules)
-sage.structure.sage_object.register_unpickle_override('sage.categories.category_types', 'Objects', Objects)
-sage.structure.sage_object.register_unpickle_override('sage.categories.category_types', 'Rings', Rings)
-sage.structure.sage_object.register_unpickle_override('sage.categories.category_types', 'Fields', Fields)
-sage.structure.sage_object.register_unpickle_override('sage.categories.category_types', 'VectorSpaces', VectorSpaces)
-sage.structure.sage_object.register_unpickle_override('sage.categories.category_types', 'Schemes_over_base', sage.categories.schemes.Schemes_over_base)
-sage.structure.sage_object.register_unpickle_override('sage.categories.category_types', 'ModularAbelianVarieties', ModularAbelianVarieties)
-sage.structure.sage_object.register_unpickle_override('sage.libs.pari.gen_py', 'pari', pari)
+from sage.misc.persist import register_unpickle_override
+register_unpickle_override('sage.categories.category', 'Sets', Sets)
+register_unpickle_override('sage.categories.category_types', 'HeckeModules', HeckeModules)
+register_unpickle_override('sage.categories.category_types', 'Objects', Objects)
+register_unpickle_override('sage.categories.category_types', 'Rings', Rings)
+register_unpickle_override('sage.categories.category_types', 'Fields', Fields)
+register_unpickle_override('sage.categories.category_types', 'VectorSpaces', VectorSpaces)
+register_unpickle_override('sage.categories.category_types', 'Schemes_over_base', sage.categories.schemes.Schemes_over_base)
+register_unpickle_override('sage.categories.category_types', 'ModularAbelianVarieties', ModularAbelianVarieties)
+register_unpickle_override('sage.libs.pari.gen_py', 'pari', pari)
 
 # Cache the contents of star imports.
 sage.misc.lazy_import.save_cache_file()
