@@ -7,13 +7,10 @@ of special (or random) linear codes and wraps them in a
 therefore not rich objects such as
 :class:`sage.coding.grs.GeneralizedReedSolomonCode`.
 
-For deprecation reasons, this file also contains some constructions for which
-Sage now does have rich representations.
-
 All codes available here can be accessed through the ``codes`` object::
 
-    sage: codes.GolayCode(GF(2),extended=False)
-    [23, 12, 7]  Golay code over GF(2)
+    sage: codes.random_linear_code(GF(2), 5, 2)
+    [5, 2]  linear code over GF(2)
 
 REFERENCES:
 
@@ -43,33 +40,27 @@ AUTHOR:
 # (at your option) any later version.
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import print_function, absolute_import
 
 from sage.matrix.matrix_space import MatrixSpace
 from sage.matrix.constructor import matrix
 from sage.matrix.special import random_matrix
 from sage.rings.finite_rings.finite_field_constructor import FiniteField as GF
-from sage.groups.perm_gps.permgroup_named import SymmetricGroup
 from sage.misc.all import prod
 from .linear_code import LinearCode
-from sage.modules.free_module import span
-from sage.schemes.projective.projective_space import ProjectiveSpace
 from sage.structure.sequence import Sequence, Sequence_generic
-from sage.arith.all import GCD, LCM, divisors, quadratic_residues, gcd
+from sage.arith.all import quadratic_residues, gcd
 from sage.rings.finite_rings.integer_mod_ring import IntegerModRing
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.integer import Integer
-from sage.sets.set import Set
 from sage.rings.finite_rings.integer_mod import Mod
 
-from sage.misc.superseded import deprecation, deprecated_function_alias
 
 ############### utility functions ################
 
 
 def _is_a_splitting(S1, S2, n, return_automorphism=False):
-    """
+    r"""
     Check wether ``(S1,S2)`` is a splitting of `\ZZ/n\ZZ`.
 
     A splitting of `R = \ZZ/n\ZZ` is a pair of subsets of `R` which is a
@@ -178,8 +169,8 @@ def _is_a_splitting(S1, S2, n, return_automorphism=False):
 
     # now that we know that (S1,S2) is a partition, we look for an invertible
     # element b that maps S1 to S2 by multiplication
-    for b in range(2,n):
-        if GCD(b,n) == 1 and all(b*x in S2 for x in S1):
+    for b in Integer(n).coprime_integers(n):
+        if b != 1 and all(b * x in S2 for x in S1):
             if return_automorphism:
                 return True, b
             else:
@@ -189,7 +180,6 @@ def _is_a_splitting(S1, S2, n, return_automorphism=False):
     else:
         return False
 
-is_a_splitting = deprecated_function_alias(21165, _is_a_splitting)
 
 def _lift2smallest_field(a):
     """
@@ -200,15 +190,13 @@ def _lift2smallest_field(a):
 
     EXAMPLES::
 
-        sage: from sage.coding.code_constructions import lift2smallest_field
+        sage: from sage.coding.code_constructions import _lift2smallest_field
         sage: FF.<z> = GF(3^4,"z")
         sage: a = z^10
-        sage: lift2smallest_field(a)
-        doctest:...: DeprecationWarning: lift2smallest_field is deprecated. Please use sage.coding.code_constructions._lift2smallest_field instead.
-        See http://trac.sagemath.org/21165 for details.
+        sage: _lift2smallest_field(a)
         (2*z + 1, Finite Field in z of size 3^2)
         sage: a = z^40
-        sage: lift2smallest_field(a)
+        sage: _lift2smallest_field(a)
         (2, Finite Field of size 3)
 
     AUTHORS:
@@ -229,53 +217,8 @@ def _lift2smallest_field(a):
     return b, F
 
 
-lift2smallest_field = deprecated_function_alias(21165, _lift2smallest_field)
-
-def lift2smallest_field2(a):
-    """
-    INPUT: a is an element of a finite field GF(q)
-
-    OUTPUT: the element b of the smallest subfield F of GF(q) for which F(b)=a.
-
-    EXAMPLES::
-
-        sage: from sage.coding.code_constructions import lift2smallest_field2
-        sage: FF.<z> = GF(3^4,"z")
-        sage: a = z^40
-        sage: lift2smallest_field2(a)
-        doctest:...: DeprecationWarning: lift2smallest_field2 will be removed in a future release of Sage. Consider using sage.coding.code_constructions._lift2smallest_field instead, though this is private and may be removed in the future without deprecation warning. If you care about this functionality being in Sage, consider opening a Trac ticket for promoting the function to public.
-        See http://trac.sagemath.org/21165 for details.
-        (2, Finite Field of size 3)
-        sage: FF.<z> = GF(2^4,"z")
-        sage: a = z^15
-        sage: lift2smallest_field2(a)
-        (1, Finite Field of size 2)
-
-    .. warning::
-
-       Since coercion (the FF(b) step) has a bug in it, this
-       *only works* in the case when you *know* F is a prime field.
-
-    AUTHORS:
-
-    - David Joyner
-    """
-    deprecation(21165, "lift2smallest_field2 will be removed in a future release of Sage. Consider using sage.coding.code_constructions._lift2smallest_field instead, though this is private and may be removed in the future without deprecation warning. If you care about this functionality being in Sage, consider opening a Trac ticket for promoting the function to public.")
-    FF = a.parent()
-    q = FF.order()
-    if q.is_prime():
-        return a,FF
-    p = q.factor()[0][0]
-    k = q.factor()[0][1]
-    for d in divisors(k):
-        F = GF(p**d,"zz")
-        for b in F:
-            if FF(b) == a:
-                return b, F
-
-
 def permutation_action(g,v):
-    """
+    r"""
     Returns permutation of rows g\*v. Works on lists, matrices,
     sequences and vectors (by permuting coordinates). The code requires
     switching from i to i+1 (and back again) since the SymmetricGroup
@@ -347,6 +290,7 @@ def permutation_action(g,v):
         return gv
     return V(gv)
 
+
 def walsh_matrix(m0):
     """
     This is the generator matrix of a Walsh code. The matrix of
@@ -384,96 +328,6 @@ def walsh_matrix(m0):
 ##################### main constructions #####################
 
 
-def BinaryGolayCode():
-    """
-    This method is now deprecated.
-    Please use :class:`sage.coding.golay_code.GolayCode` instead.
-    """
-    from sage.misc.superseded import deprecation
-    from .golay_code import GolayCode
-    deprecation(20787, "codes.BinaryGolayCode is now deprecated. Please use codes.GolayCode instead.")
-    return GolayCode(GF(2), False)
-
-def CyclicCodeFromGeneratingPolynomial(n,g,ignore=True):
-    r"""
-    If g is a polynomial over GF(q) which divides `x^n-1` then
-    this constructs the code "generated by g" (ie, the code associated
-    with the principle ideal `gR` in the ring
-    `R = GF(q)[x]/(x^n-1)` in the usual way).
-
-    The option "ignore" says to ignore the condition that (a) the
-    characteristic of the base field does not divide the length (the
-    usual assumption in the theory of cyclic codes), and (b) `g`
-    must divide `x^n-1`. If ignore=True, instead of returning
-    an error, a code generated by `gcd(x^n-1,g)` is created.
-
-    EXAMPLES::
-
-        sage: P.<x> = PolynomialRing(GF(3),"x")
-        sage: g = x-1
-        sage: C = codes.CyclicCodeFromGeneratingPolynomial(4,g); C
-        doctest:...
-        DeprecationWarning: codes.CyclicCodeFromGeneratingPolynomial is now deprecated. Please use codes.CyclicCode instead.
-        See http://trac.sagemath.org/20100 for details.
-        [4, 3] Cyclic Code over GF(3)
-        sage: P.<x> = PolynomialRing(GF(4,"a"),"x")
-        sage: g = x^3+1
-        sage: C = codes.CyclicCodeFromGeneratingPolynomial(9,g); C
-        [9, 6] Cyclic Code over GF(4)
-        sage: P.<x> = PolynomialRing(GF(2),"x")
-        sage: g = x^3+x+1
-        sage: C = codes.CyclicCodeFromGeneratingPolynomial(7,g); C
-        [7, 4] Cyclic Code over GF(2)
-        sage: C.generator_matrix()
-        [1 1 0 1 0 0 0]
-        [0 1 1 0 1 0 0]
-        [0 0 1 1 0 1 0]
-        [0 0 0 1 1 0 1]
-        sage: g = x+1
-        sage: C = codes.CyclicCodeFromGeneratingPolynomial(4,g); C
-        Traceback (most recent call last):
-        ...
-        ValueError: Only cyclic codes whose length and field order are coprimes are implemented.
-    """
-    from sage.misc.superseded import deprecation
-    from sage.coding.cyclic_code import CyclicCode
-    deprecation(20100, "codes.CyclicCodeFromGeneratingPolynomial is now deprecated. Please use codes.CyclicCode instead.")
-    return CyclicCode(length = n, generator_pol = g)
-
-
-def CyclicCodeFromCheckPolynomial(n,h,ignore=True):
-    r"""
-    If h is a polynomial over GF(q) which divides `x^n-1` then
-    this constructs the code "generated by `g = (x^n-1)/h`"
-    (ie, the code associated with the principle ideal `gR` in
-    the ring `R = GF(q)[x]/(x^n-1)` in the usual way). The
-    option "ignore" says to ignore the condition that the
-    characteristic of the base field does not divide the length (the
-    usual assumption in the theory of cyclic codes).
-
-    EXAMPLES::
-
-        sage: P.<x> = PolynomialRing(GF(3),"x")
-        sage: C = codes.CyclicCodeFromCheckPolynomial(4,x + 1); C
-        doctest:...
-        DeprecationWarning: codes.CyclicCodeFromCheckPolynomial is now deprecated. Please use codes.CyclicCode instead.
-        See http://trac.sagemath.org/20100 for details.
-        [4, 1] Cyclic Code over GF(3)
-        sage: C = codes.CyclicCodeFromCheckPolynomial(4,x^3 + x^2 + x + 1); C
-        [4, 3] Cyclic Code over GF(3)
-        sage: C.generator_matrix()
-        [2 1 0 0]
-        [0 2 1 0]
-        [0 0 2 1]
-    """
-    from sage.misc.superseded import deprecation
-    from sage.coding.cyclic_code import CyclicCode
-    deprecation(20100, "codes.CyclicCodeFromCheckPolynomial is now deprecated. Please use codes.CyclicCode instead.")
-    P = h.parent()
-    x = P.gen()
-    g = P((x**n-1)/h)
-    return CyclicCode(length = n, generator_pol = g)
-
 def DuadicCodeEvenPair(F,S1,S2):
     r"""
     Constructs the "even pair" of duadic codes associated to the
@@ -499,6 +353,9 @@ def DuadicCodeEvenPair(F,S1,S2):
         ([11, 5] Cyclic Code over GF(3),
          [11, 5] Cyclic Code over GF(3))
     """
+    from sage.misc.stopgap import stopgap
+    stopgap("The function DuadicCodeEvenPair has several issues which may cause wrong results", 25896)
+
     from .cyclic_code import CyclicCode
     n = len(S1) + len(S2) + 1
     if not _is_a_splitting(S1,S2,n):
@@ -546,6 +403,9 @@ def DuadicCodeOddPair(F,S1,S2):
 
     This is consistent with Theorem 6.1.3 in [HP2003]_.
     """
+    from sage.misc.stopgap import stopgap
+    stopgap("The function DuadicCodeOddPair has several issues which may cause wrong results", 25896)
+
     from .cyclic_code import CyclicCode
     n = len(S1) + len(S2) + 1
     if not _is_a_splitting(S1,S2,n):
@@ -573,16 +433,6 @@ def DuadicCodeOddPair(F,S1,S2):
     return C1,C2
 
 
-def ExtendedBinaryGolayCode():
-    """
-    This method is now deprecated.
-    Please use :class:`sage.coding.golay_code.GolayCode` instead.
-    """
-    from sage.misc.superseded import deprecation
-    from .golay_code import GolayCode
-    deprecation(20787, "codes.ExtendedBinaryGolayCode is now deprecated. Please use codes.GolayCode instead.")
-    return GolayCode(GF(2))
-
 
 def ExtendedQuadraticResidueCode(n,F):
     r"""
@@ -626,16 +476,6 @@ def ExtendedQuadraticResidueCode(n,F):
     C = QuadraticResidueCodeOddPair(n,F)[0]
     return C.extended_code()
 
-def ExtendedTernaryGolayCode():
-    """
-    This method is now deprecated.
-    Please use :class:`sage.coding.golay_code.GolayCode` instead.
-    """
-    from sage.misc.superseded import deprecation
-    from .golay_code import GolayCode
-    deprecation(20787, "codes.ExtendedTernaryGolayCode is now deprecated. Please use codes.GolayCode instead.")
-    return GolayCode(GF(3))
-
 def from_parity_check_matrix(H):
     r"""
     Return the linear code that has ``H`` as a parity check matrix.
@@ -659,8 +499,6 @@ def from_parity_check_matrix(H):
     Cd = LinearCode(H)
     return Cd.dual_code()
 
-LinearCodeFromCheckMatrix = deprecated_function_alias(21165, from_parity_check_matrix)
-
 
 def QuadraticResidueCode(n,F):
     r"""
@@ -721,13 +559,13 @@ def QuadraticResidueCodeEvenPair(n,F):
 
     EXAMPLES::
 
-        sage: codes.QuadraticResidueCodeEvenPair(17, GF(13))
+        sage: codes.QuadraticResidueCodeEvenPair(17, GF(13))  # known bug (#25896)
         ([17, 8] Cyclic Code over GF(13),
          [17, 8] Cyclic Code over GF(13))
         sage: codes.QuadraticResidueCodeEvenPair(17, GF(2))
         ([17, 8] Cyclic Code over GF(2),
          [17, 8] Cyclic Code over GF(2))
-        sage: codes.QuadraticResidueCodeEvenPair(13,GF(9,"z"))
+        sage: codes.QuadraticResidueCodeEvenPair(13,GF(9,"z"))  # known bug (#25896)
         ([13, 6] Cyclic Code over GF(9),
          [13, 6] Cyclic Code over GF(9))
         sage: C1,C2 = codes.QuadraticResidueCodeEvenPair(7,GF(2))
@@ -785,13 +623,13 @@ def QuadraticResidueCodeOddPair(n,F):
 
     EXAMPLES::
 
-        sage: codes.QuadraticResidueCodeOddPair(17, GF(13))
+        sage: codes.QuadraticResidueCodeOddPair(17, GF(13))  # known bug (#25896)
         ([17, 9] Cyclic Code over GF(13),
          [17, 9] Cyclic Code over GF(13))
         sage: codes.QuadraticResidueCodeOddPair(17, GF(2))
         ([17, 9] Cyclic Code over GF(2),
          [17, 9] Cyclic Code over GF(2))
-        sage: codes.QuadraticResidueCodeOddPair(13, GF(9,"z"))
+        sage: codes.QuadraticResidueCodeOddPair(13, GF(9,"z"))  # known bug (#25896)
         ([13, 7] Cyclic Code over GF(9),
          [13, 7] Cyclic Code over GF(9))
         sage: C1 = codes.QuadraticResidueCodeOddPair(17, GF(2))[1]
@@ -853,51 +691,7 @@ def random_linear_code(F, length, dimension):
         G = random_matrix(F, dimension, length)
         if G.rank() == dimension:
             return LinearCode(G)
-    
-def RandomLinearCode(n, k, F):
-    r"""
-    Deprecated alias of :func:`random_linear_code`.
 
-    EXAMPLES::
-
-        sage: C = codes.RandomLinearCode(10, 3, GF(2))
-        doctest:...: DeprecationWarning: codes.RandomLinearCode(n, k, F) is deprecated. Please use codes.random_linear_code(F, n, k) instead
-        See http://trac.sagemath.org/21165 for details.
-        sage: C
-        [10, 3] linear code over GF(2)
-        sage: C.generator_matrix().rank()
-        3
-    """
-    deprecation(21165, "codes.RandomLinearCode(n, k, F) is deprecated. Please use codes.random_linear_code(F, n, k) instead")
-    return random_linear_code(F, n, k)
-
-def ReedSolomonCode(n,k,F,pts = None):
-    from sage.coding.grs import GeneralizedReedSolomonCode
-    deprecation(18928, "codes.ReedSolomonCode is now deprecated. Please use codes.GeneralizedReedSolomonCode instead.")
-    q = F.order()
-    if n>q or k>n or k>q:
-        raise ValueError("RS codes does not exist with the given input.")
-    if pts is not None and len(pts) != n:
-        raise ValueError("You must provide exactly %s distinct points of %s"%(n,F))
-    if (pts is None):
-        pts = []
-        i = 0
-        for x in F:
-            if i<n:
-                pts.append(x)
-                i = i+1
-    return GeneralizedReedSolomonCode(pts, k)
-
-
-def TernaryGolayCode():
-    """
-    This method is now deprecated.
-    Please use :class:`sage.coding.golay_code.GolayCode` instead.
-    """
-    from sage.misc.superseded import deprecation
-    from .golay_code import GolayCode
-    deprecation(20787, "codes.TernaryGolayCode is now deprecated. Please use codes.GolayCode instead.")
-    return GolayCode(GF(3), False)
 
 def ToricCode(P,F):
     r"""
