@@ -222,9 +222,9 @@ def bch_bound(n, D, arithmetic=False):
         one_len, offset = longest_streak(1)
         return (one_len + 1, (1, offset))
     else:
+        n = Integer(n)
         longest_streak_list = [(longest_streak(step), step)
-                               for step in range(1, n // 2 + 1)
-                               if gcd(step, n) == 1]
+                               for step in n.coprime_integers(n // 2 + 1)]
         (max_len, offset), step = max(longest_streak_list)
         return (max_len + 1, (step, offset))
 
