@@ -119,12 +119,10 @@ def bounds_on_minimum_distance_in_guava(n, k, F):
     return Ldata
 
 
-
-
 def best_linear_code_in_codetables_dot_de(n, k, F, verbose=False):
     r"""
     Return the best linear code and its construction as per the web database
-    http://codetables.de.
+    http://www.codetables.de/
 
     INPUT:
 
@@ -166,13 +164,13 @@ def best_linear_code_in_codetables_dot_de(n, k, F, verbose=False):
     from six.moves.urllib.request import urlopen
     q = F.order()
     if not q in [2, 3, 4, 5, 7, 8, 9]:
-        raise ValueError("q (=%s) must be in [2,3,4,5,7,8,9]"%q)
+        raise ValueError("q (=%s) must be in [2,3,4,5,7,8,9]" % q)
     n = int(n)
     k = int(k)
 
-    param = ("?q=%s&n=%s&k=%s"%(q,n,k)).replace('L','')
+    param = ("?q=%s&n=%s&k=%s" % (q, n, k)).replace('L', '')
 
-    url = "http://iaks-www.ira.uka.de/home/grassl/codetables/BKLC/BKLC.php"+param
+    url = "http://www.codetables.de/" + "BKLC/BKLC.php" + param
     if verbose:
         print("Looking up the bounds at %s" % url)
     f = urlopen(url)
@@ -187,7 +185,6 @@ def best_linear_code_in_codetables_dot_de(n, k, F, verbose=False):
     return text
 
 
-
 def self_orthogonal_binary_codes(n, k, b=2, parent=None, BC=None, equal=False,
     in_test=None):
     """
@@ -276,7 +273,7 @@ def self_orthogonal_binary_codes(n, k, b=2, parent=None, BC=None, equal=False,
     Since all the codes will be self-orthogonal, b must be divisible by
     2::
 
-        sage: list(self_orthogonal_binary_codes(8, 4, 1, equal=True))
+        sage: list(codes.databases.self_orthogonal_binary_codes(8, 4, 1, equal=True))
         Traceback (most recent call last):
         ...
         ValueError: b (1) must be a positive even integer.
