@@ -22,12 +22,13 @@ from __future__ import print_function
 from six.moves import range
 
 import time
-from sage.groups.perm_gps.partn_ref.refinement_graphs import *
+from sage.groups.perm_gps.partn_ref.refinement_graphs import search_tree, get_orbits
 from sage.rings.all import ZZ, infinity
 from sage.graphs.all import DiGraph
 from sage.combinat.cluster_algebra_quiver.quiver_mutation_type import _edge_list_to_matrix
 
-def _principal_part( mat ):
+
+def _principal_part(mat):
     """
     Returns the principal part of a matrix.
 
@@ -246,8 +247,7 @@ def _mutation_class_iter( dg, n, m, depth=infinity, return_dig6=False, show_dept
 
     while gets_bigger and depth_counter < depth:
         gets_bigger = False
-        keys = list(dig6s.keys())
-        for key in keys:
+        for key in list(dig6s):
             mutation_indices = [ i for i in dig6s[key][0] if i < n ]
             if mutation_indices:
                 dg = _dig6_to_digraph( key )
