@@ -243,9 +243,20 @@ class ColoredPermutation(MultiplicativeGroupElement):
         return self._perm.to_matrix() * D
 
     def has_left_descent(self, i):
-        """
+        r"""
         Return ``True`` if ``i`` is a left descent of ``self``.
 
+        Let `p = ((s_1, \ldots s_n), \sigma)` be a colored permutation.
+        We say `p` has a left `n`-descent if `s_n > 0`. If `i < n`, then
+        we say `p` has a left `i`-descent if either
+
+        - `s_i \neq 0, s_{i+1} = 0` and `\sigma_i < \sigma_{i+1}` or
+        - `s_i = s_{i+1}` and `\sigma_i > \sigma_{i+1}`.
+
+        This notion of a left `i`-descent is done in order to recursively
+        construct `w(p) = \sigma_i w(\sigma_i^{-1} p)`, where `w(p)`
+        denotes a reduced word of `p`.
+
         EXAMPLES::
 
             sage: C = ColoredPermutations(2, 4)
@@ -259,18 +270,105 @@ class ColoredPermutation(MultiplicativeGroupElement):
             sage: x = s4*s1*s2*s3*s4
             sage: [x.has_left_descent(i) for i in C.index_set()]
             [True, False, False, True]
+
+            sage: C = ColoredPermutations(3, 3)
+            sage: x = C([[2,1,0],[3,1,2]])
+            sage: [x.has_left_descent(i) for i in C.index_set()]
+            [False, True, False]
+
+            sage: C = ColoredPermutations(4, 4)
+            sage: x = C([[2,1,0,1],[3,2,4,1]])
+            sage: [x.has_left_descent(i) for i in C.index_set()]
+            [False, True, False, True]
         """
         if self.parent()._m == 1:
-            return self._perm[i - 1] > self._perm[i]
+            return self._perm[i-1] > self._perm[i]
 
-        if self.parent()._m == 2:
-            if i == self.parent()._n:
-                return self._colors[-1] == 1
-            if self._colors[i - 1] == 1:
-                return self._colors[i] == 0 or self._perm[i - 1] < self._perm[i]
-            return self._colors[i] == 0 and self._perm[i - 1] > self._perm[i]
+        if i == self.parent()._n:
+            return self._colors[-1] != 0
+        if self._colors[i-1] != 0:
+            return self._colors[i] == 0 or self._perm[i-1] < self._perm[i]
+        return self._colors[i] == 0 and self._perm[i-1] > self._perm[i]
 
-        raise ValueError("descents are undefined")
+    def reduced_word(self):
+        r"""
+        Return a word in the simple reflections to obtain ``self``.
+
+        EXAMPLES::
+
+            sage: C = ColoredPermutations(3, 3)
+            sage: x = C([[2,1,0],[3,1,2]])
+            sage: x.reduced_word()
+            [2, 1, 3, 2, 1, 3, 3]
+
+            sage: C = ColoredPermutations(4, 4)
+            sage: x = C([[2,1,0,1],[3,2,4,1]])
+            sage: x.reduced_word()
+            [2, 1, 4, 3, 2, 1, 4, 3, 2, 4, 4, 3]
+
+        TESTS::
+
+            sage: C = ColoredPermutations(3, 3)
+            sage: all(C.from_reduced_word(p.reduced_word()) == p for p in C)
+            True
+        """
+        if self == self.parent().one():
+            return []
+        I = self.parent().index_set()
+        sinv = self.parent()._inverse_simple_reflections()
+        for i in I:
+            if self.has_left_descent(i):
+                return [i] + (sinv[i] * self).reduced_word()
+        assert False, "BUG in reduced_word"
+
+    def length(self):
+        r"""
+        Return the length of ``self`` in generating reflections.
+
+        This is the minimal numbers of generating reflections needed
+        to obtain ``self``.
+
+        EXAMPLES::
+
+            sage: C = ColoredPermutations(3, 3)
+            sage: x = C([[2,1,0],[3,1,2]])
+            sage: x.length()
+            7
+
+            sage: C = ColoredPermutations(4, 4)
+            sage: x = C([[2,1,0,1],[3,2,4,1]])
+            sage: x.length()
+            12
+
+        TESTS::
+
+            sage: C = ColoredPermutations(3, 3)
+            sage: d = [p.length() for p in C]
+            sage: [d.count(i) for i in range(14)]
+            [1, 3, 6, 10, 15, 20, 23, 24, 23, 19, 12, 5, 1, 0]
+            sage: d = [p.length() for p in ReflectionGroup([3, 1, 3])] # optional - gap3
+            sage: [d.count(i) for i in range(14)]                      # optional - gap3
+            [1, 3, 6, 10, 15, 20, 23, 24, 23, 19, 12, 5, 1, 0]
+
+            sage: C = ColoredPermutations(4, 3)
+            sage: d = [p.length() for p in C]
+            sage: [d.count(i) for i in range(17)]
+            [1, 3, 6, 11, 18, 27, 36, 44, 50, 52, 49, 40, 27, 14, 5, 1, 0]
+            sage: d = [p.length() for p in ReflectionGroup([4, 1, 3])] # optional - gap3
+            sage: [d.count(i) for i in range(17)]                      # optional - gap3
+            [1, 3, 6, 11, 18, 27, 36, 44, 50, 52, 49, 40, 27, 14, 5, 1, 0]
+
+            sage: C = ColoredPermutations(3, 4)
+            sage: d = [p.length() for p in C]
+            sage: [d.count(i) for i in range(22)]
+            [1, 4, 10, 20, 35, 56, 82, 112, 144, 174, 197,
+             209, 209, 197, 173, 138, 96, 55, 24, 7, 1, 0]
+            sage: d = [p.length() for p in ReflectionGroup([3, 1, 4])] # optional - gap3
+            sage: [d.count(i) for i in range(22)]                      # optional - gap3
+            [1, 4, 10, 20, 35, 56, 82, 112, 144, 174, 197,
+             209, 209, 197, 173, 138, 96, 55, 24, 7, 1, 0]
+        """
+        return ZZ(len(self.reduced_word()))
 
 # TODO: Parts of this should be put in the category of complex
 # reflection groups
@@ -352,8 +450,8 @@ class ColoredPermutations(Parent, UniqueRepresentation):
             from sage.categories.finite_coxeter_groups import FiniteCoxeterGroups
             category = FiniteCoxeterGroups().Irreducible()
         else:
-            from sage.categories.generalized_coxeter_groups import GeneralizedCoxeterGroups
-            category = GeneralizedCoxeterGroups().Finite().Irreducible()
+            from sage.categories.complex_reflection_groups import ComplexReflectionGroups
+            category = ComplexReflectionGroups().Finite().Irreducible().WellGenerated()
         Parent.__init__(self, category=category)
 
     def _repr_(self):
@@ -471,6 +569,27 @@ class ColoredPermutations(Parent, UniqueRepresentation):
         colors[-1] = self._C.one()
         return self.element_class(self, colors, self._P.identity())
 
+    @cached_method
+    def _inverse_simple_reflections(self):
+        """
+        Return the inverse of the simple reflections of ``self``.
+
+        .. WARNING::
+
+            This returns a ``dict`` that should not be mutated since
+            the result is cached.
+
+        EXAMPLES::
+
+            sage: C = ColoredPermutations(4, 3)
+            sage: C._inverse_simple_reflections()
+            {1: [[0, 0, 0], [2, 1, 3]],
+             2: [[0, 0, 0], [1, 3, 2]],
+             3: [[0, 0, 3], [1, 2, 3]]}
+        """
+        s = self.simple_reflections()
+        return {i: ~s[i] for i in self.index_set()}
+
     @cached_method
     def gens(self):
         """
@@ -634,7 +753,7 @@ class ColoredPermutations(Parent, UniqueRepresentation):
         return self._n
 
     def degrees(self):
-        """
+        r"""
         Return the degrees of ``self``.
 
         The degrees of a complex reflection group are the degrees of
@@ -778,7 +897,7 @@ class ColoredPermutations(Parent, UniqueRepresentation):
         return prod(q + d - 1 for d in self.degrees())
 
     def is_well_generated(self):
-        """
+        r"""
         Return if ``self`` is a well-generated complex reflection group.
 
         A complex reflection group `G` is well-generated if it is
@@ -957,9 +1076,9 @@ class SignedPermutations(ColoredPermutations):
         [2 3 1 4]
         [2 2 4 1]
         sage: S.long_element()
-        [-4, -3, -2, -1]
+        [-1, -2, -3, -4]
         sage: S.long_element().reduced_word()
-        [4, 3, 4, 2, 3, 4, 1, 2, 3, 4]
+        [1, 2, 1, 3, 2, 1, 4, 3, 2, 1, 4, 3, 2, 4, 3, 4]
 
     We can also go between the 2-colored permutation group::
 
@@ -1152,12 +1271,22 @@ class SignedPermutations(ColoredPermutations):
 
             sage: S = SignedPermutations(4)
             sage: S.long_element()
-            [-4, -3, -2, -1]
+            [-1, -2, -3, -4]
+
+        TESTS:
+
+        Check that this is the element of maximal length (:trac:`25200`)::
+
+            sage: S = SignedPermutations(4)
+            sage: S.long_element().length() == max(x.length() for x in S)
+            True
+            sage: all(SignedPermutations(n).long_element().length() == n^2
+            ....:     for n in range(2,10))
+            True
         """
         if index_set is not None:
             return super(SignedPermutations, self).long_element()
-        p = list(range(self._n, 0, -1))
-        return self.element_class(self, [-ZZ.one()] * self._n, self._P(p))
+        return self.element_class(self, [-ZZ.one()] * self._n, self._P.one())
 
     Element = SignedPermutation
 
