@@ -120,7 +120,7 @@ or with colored edges::
 
     sage: K = crystals.KirillovReshetikhin(['A',3,1], 1,1)
     sage: G = K.digraph()
-    sage: G.set_latex_options(color_by_label = {0:"black", 1:"red", 2:"blue", 3:"green"}) #optional - dot2tex graphviz
+    sage: G.set_latex_options(color_by_label={0:"black", 1:"red", 2:"blue", 3:"green"})
     sage: view(G, pdflatex=True) # optional - dot2tex graphviz, not tested (opens external window)
 
 For rank two crystals, there is an alternative method of getting
