@@ -7,7 +7,7 @@ AUTHORS:
 - Travis Scrimshaw (2013-03-30): Put derangements into category framework
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2010 Alasdair McAndrew <amca01@gmail.com>,
 #                     2013 Travis Scrimshaw <tscrim@ucdavis.edu>
 #
@@ -21,7 +21,7 @@ AUTHORS:
 #  The full text of the GPL is available at:
 #
 #                  http://www.gnu.org/licenses/
-#*****************************************************************************
+# ****************************************************************************
 from six.moves import range
 
 from sage.structure.parent import Parent
@@ -67,10 +67,11 @@ class Derangement(CombinatorialElement):
             ...
             ValueError: Can only convert to a permutation for derangements of [1, 2, ..., n]
         """
-        if self.parent()._set != tuple(range(1, len(self)+1)):
+        if self.parent()._set != tuple(range(1, len(self) + 1)):
             raise ValueError("Can only convert to a permutation for derangements of [1, 2, ..., n]")
         return Permutation(list(self))
 
+
 class Derangements(UniqueRepresentation, Parent):
     r"""
     The class of all derangements of a set or multiset.
@@ -92,7 +93,10 @@ class Derangements(UniqueRepresentation, Parent):
 
     REFERENCES:
 
-    .. [DerUB] http://www.u-bourgogne.fr/LE2I/jl.baril/derange.pdf
+    .. [DerUB] Jean-Luc Baril, Vincent Vajnovszki. *Gray code for derangements*.
+       Discrete Applied Math. 140 (2004)
+       :doi:`10.1016/j.dam.2003.06.002`
+       http://jl.baril.u-bourgogne.fr/derange.pdf
 
     - :wikipedia:`Derangement`
 
@@ -180,8 +184,8 @@ class Derangements(UniqueRepresentation, Parent):
             Derangements of the multiset [2, 2, 1, 1]
         """
         if self.__multi:
-            return "Derangements of the multiset %s"%list(self._set)
-        return "Derangements of the set %s"%list(self._set)
+            return "Derangements of the multiset %s" % list(self._set)
+        return "Derangements of the set %s" % list(self._set)
 
     def _element_constructor_(self, der):
         """
@@ -198,7 +202,7 @@ class Derangements(UniqueRepresentation, Parent):
         if isinstance(der, Derangement):
             if der.parent() is self:
                 return der
-            raise ValueError("Cannot convert %s to an element of %s"%(der, self))
+            raise ValueError("Cannot convert %s to an element of %s" % (der, self))
         return self.element_class(self, der)
 
     Element = Derangement
@@ -287,7 +291,7 @@ class Derangements(UniqueRepresentation, Parent):
                     yield self.element_class(self, list(p))
         else:
             for d in self._iter_der(len(self._set)):
-                yield self.element_class(self, [self._set[i-1] for i in d])
+                yield self.element_class(self, [self._set[i - 1] for i in d])
 
     def _iter_der(self, n):
         r"""
@@ -311,22 +315,22 @@ class Derangements(UniqueRepresentation, Parent):
         if n <= 1:
             return
         elif n == 2:
-            yield [2,1]
+            yield [2, 1]
         elif n == 3:
-            yield [2,3,1]
-            yield [3,1,2]
+            yield [2, 3, 1]
+            yield [3, 1, 2]
         elif n >= 4:
-            for d in self._iter_der(n-1):
+            for d in self._iter_der(n - 1):
                 for i in range(1, n):
                     s = d[:]
                     ii = d.index(i)
                     s[ii] = n
                     yield s + [i]
-            for d in self._iter_der(n-2):
+            for d in self._iter_der(n - 2):
                 for i in range(1, n):
                     s = d[:]
-                    s = [x >= i and x+1 or x for x in s]
-                    s.insert(i-1, n)
+                    s = [x >= i and x + 1 or x for x in s]
+                    s.insert(i - 1, n)
                     yield s + [i]
 
     def _fixed_point(self, a):
@@ -367,8 +371,8 @@ class Derangements(UniqueRepresentation, Parent):
         # n >= 4
         last = Integer(2)
         second_last = Integer(1)
-        for i in range(4, n+1):
-            current = (i-1) * (last + second_last)
+        for i in range(4, n + 1):
+            current = (i - 1) * (last + second_last)
             second_last = last
             last = current
         return last
@@ -420,12 +424,12 @@ class Derangements(UniqueRepresentation, Parent):
             A = [self._set.count(i) for i in sL]
             R = PolynomialRing(QQ, 'x', len(A))
             S = sum(i for i in R.gens())
-            e = prod((S-x)**y for (x, y) in zip(R.gens(), A))
+            e = prod((S - x)**y for (x, y) in zip(R.gens(), A))
             return Integer(e.coefficient(dict([(x, y) for (x, y) in zip(R.gens(), A)])))
         return self._count_der(len(self._set))
 
     def _rand_der(self):
-        """
+        r"""
         Produces a random derangement of `[1, 2, \ldots, n]`.
 
         This is an
@@ -440,18 +444,18 @@ class Derangements(UniqueRepresentation, Parent):
         """
         n = len(self._set)
         A = list(range(1, n + 1))
-        mark = [x<0 for x in A]
-        i,u = n,n
+        mark = [x < 0 for x in A]
+        i, u = n, n
         while u >= 2:
-            if not(mark[i-1]):
+            if not(mark[i - 1]):
                 while True:
-                    j = randint(1,i-1)
-                    if not(mark[j-1]):
-                        A[i-1], A[j-1] = A[j-1], A[i-1]
+                    j = randint(1, i - 1)
+                    if not(mark[j - 1]):
+                        A[i - 1], A[j - 1] = A[j - 1], A[i - 1]
                         break
                 p = random()
-                if p < (u-1) * self._count_der(u-2) // self._count_der(u):
-                    mark[j-1] = True
+                if p < (u - 1) * self._count_der(u - 2) // self._count_der(u):
+                    mark[j - 1] = True
                     u -= 1
                 u -= 1
             i -= 1
@@ -477,7 +481,9 @@ class Derangements(UniqueRepresentation, Parent):
 
         REFERENCES:
 
-        .. [Martinez08]
+        .. [Martinez08] Conrado Martinez, Alois Panholzer and Helmut Prodinger,
+           *Generating random derangements*
+           :doi:`10.1137/1.9781611972986.7`
            http://www.siam.org/proceedings/analco/2008/anl08_022martinezc.pdf
 
         EXAMPLES::
@@ -508,5 +514,4 @@ class Derangements(UniqueRepresentation, Parent):
             i = randint(0, len(L))
             return L[i]
         temp = self._rand_der()
-        return self.element_class(self, [self._set[i-1] for i in temp])
-
+        return self.element_class(self, [self._set[ii - 1] for ii in temp])
