@@ -266,7 +266,6 @@ def unrank(L, i):
             for _ in range(i):
                 next(it)
             return next(it)
-        except StopIteration as e:
+        except StopIteration:
             raise IndexError("index out of range")
     raise ValueError("Don't know how to unrank on {}".format(L))
-
