@@ -268,7 +268,7 @@ class WeightLatticeRealizations(Category_over_base_ring):
                        for base_ring in set([ZZ, self.base_ring()])
                        for extended  in set([self.cartan_type().is_affine(), self.is_extended()])]
             for domain in domains:
-                tester.assert_(self._internal_coerce_map_from(domain) is not None)
+                tester.assertTrue(self._internal_coerce_map_from(domain) is not None)
                 for i in self.index_set():
                     # This embedding maps fundamental weights to fundamental weights
                     tester.assertEqual(self(domain.fundamental_weight(i)), Lambda[i])
@@ -291,9 +291,9 @@ class WeightLatticeRealizations(Category_over_base_ring):
                 for j in self.index_set():
                     tester.assertEqual(Lambda[j].scalar(alphacheck[i]), (1 if i==j else 0))
 
-            tester.assert_(self.rho().is_dominant())
+            tester.assertTrue(self.rho().is_dominant())
             if self.root_system.is_finite() and self.root_system.is_irreducible():
-                tester.assert_(self.highest_root().is_dominant())
+                tester.assertTrue(self.highest_root().is_dominant())
 
         @cached_method
         def fundamental_weights(self):
@@ -681,21 +681,21 @@ class WeightLatticeRealizations(Category_over_base_ring):
                 w = self.weyl_group().from_reduced_word(self.reduced_word_of_translation(t))
                 if self.null_root().is_zero():
                     # The following formula is only valid when the null root is zero
-                    tester.assertEquals(w.action(rho), rho + rho.level()*t)
+                    tester.assertEqual(w.action(rho), rho + rho.level()*t)
                     # TODO: fix this formula to take delta into account,
                     # and remove the above condition
                 if test_automorphism:
                     permutation = [None for i in self.index_set()]
                     for i in self.index_set():
                         root = w.action(alpha[i])
-                        tester.assert_(root in rank_simple_roots)
+                        tester.assertTrue(root in rank_simple_roots)
                         permutation[i] = rank_simple_roots[root]
-                    tester.assertEquals(set(permutation), set(self.index_set()))
+                    tester.assertEqual(set(permutation), set(self.index_set()))
                     #print permutation
                     # It could be nicer to test equality of G and its relabelling
                     for i in self.index_set():
                         for j in self.index_set():
-                            tester.assertEquals(G[permutation[i],permutation[j]], G[i,j])
+                            tester.assertEqual(G[permutation[i],permutation[j]], G[i,j])
                     permutations.append(permutation)
 
             if test_automorphism and elements is None: # note: the test on elements is broken
@@ -706,7 +706,7 @@ class WeightLatticeRealizations(Category_over_base_ring):
                 #from sage.groups.perm_gps.permgroup import PermutationGroup
                 #P = PermutationGroup([[i+1 for i in permutation] for permutation in permutations])
                 #print P, len(P)
-                #tester.assertEquals(P, G.automorphism_group())
+                #tester.assertEqual(P, G.automorphism_group())
                 pass
 
         def signs_of_alcovewalk(self, walk):
@@ -741,7 +741,7 @@ class WeightLatticeRealizations(Category_over_base_ring):
             where the `k^{th}` entry denotes whether the `k^{th}` step was
             positive or negative.
 
-            See equation 3.4, of Ram: Alcove walks ..., arxiv:math/0601343v1 [math.RT]
+            See equation 3.4, of Ram: Alcove walks ..., :arxiv:`math/0601343v1`
 
             EXAMPLES::
 
@@ -864,7 +864,7 @@ class WeightLatticeRealizations(Category_over_base_ring):
                 16
 
                 sage: type(RootSystem(['A',3]).ambient_lattice().weyl_dimension([2,1,0,0]))
-                <type 'sage.rings.integer.Integer'>
+                <... 'sage.rings.integer.Integer'>
             """
             highest_weight = self(highest_weight)
             if not highest_weight.is_dominant():
