@@ -87,7 +87,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
     For more information, see the thematic tutorial *Lie Methods and
     Related Combinatorics in Sage*, available at:
 
-    http://doc.sagemath.org/html/en/thematic_tutorials/lie.html
+    https://doc.sagemath.org/html/en/thematic_tutorials/lie.html
     """
     @staticmethod
     def __classcall__(cls, ct, base_ring=ZZ, prefix=None, style="lattice"):
@@ -494,8 +494,7 @@ class WeylCharacterRing(CombinatorialFreeModule):
         """
         alphacheck = self._space.simple_coroots()
         alpha = self._space.simple_roots()
-        sr = self._space.weyl_group().simple_reflections()
-        [epsilon, ret] = [1,a]
+        [epsilon, ret] = [1, a]
         done = False
         while not done:
             done = True
@@ -586,9 +585,9 @@ class WeylCharacterRing(CombinatorialFreeModule):
             [{(1, 0): 1, (0, 1): 1}, {(-1/2, 1/2): 1, (1/2, -1/2): 1, (1/2, 1/2): 1}]
         """
         alphacheck = self._space.simple_coroots()
-        alpha = self._space.simple_roots()
         dd = {}
-        h = tuple(int(hwv.inner_product(alphacheck[j])) for j in self._space.index_set())
+        h = tuple(int(hwv.inner_product(alphacheck[j]))
+                  for j in self._space.index_set())
         dd[h] = int(1)
         return self._demazure_helper(dd, word=word, debug=debug)
 
