@@ -550,6 +550,7 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
     * Jack bases
     * Macdonald bases
     * `k`-Schur functions
+    * Hecke character basis
 
     We briefly demonstrate how to access these bases. For more information, see
     the documentation of the individual bases.
@@ -578,6 +579,16 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
         sage: J(P[2,1])
         (1/(-q*t^4+2*q*t^3-q*t^2+t^2-2*t+1))*McdJ[2, 1]
 
+    We can also construct the `\bar{q}` basis that can be used
+    to determine character tables for Hecke algebras (with quadratic
+    relation `T_i^2 = (1-q) T_i + q`::
+
+        sage: Sym = SymmetricFunctions(ZZ['q'].fraction_field())
+        sage: qbar = Sym.hecke_character()
+        sage: s = Sym.s()
+        sage: s(qbar[2,1])
+        -s[1, 1, 1] + (q-1)*s[2, 1] + q*s[3]
+
     .. rubric:: `k`-Schur functions
 
     The `k`-Schur functions live in the `k`-bounded subspace of the ring of
@@ -1171,6 +1182,24 @@ class SymmetricFunctions(UniqueRepresentation, Parent):
         return orthogonal.SymmetricFunctionAlgebra_orthogonal(self)
     o = orthogonal
 
+    def hecke_character(self, q='q'):
+        """
+        The basis of symmetric functions that determines the character
+        tables for Hecke algebras.
+
+        EXAMPLES::
+
+            sage: SymmetricFunctions(ZZ['q'].fraction_field()).hecke_character()
+            Symmetric Functions over
+             Fraction Field of Univariate Polynomial Ring in q over Integer Ring
+             in the Hecke character with q=q basis
+            sage: SymmetricFunctions(QQ).hecke_character(1/2)
+            Symmetric Functions over Rational Field in the Hecke character with q=1/2 basis
+        """
+        from sage.combinat.sf.hecke import HeckeCharacter
+        return HeckeCharacter(self, q)
+    qbar = hecke_character
+
     def macdonald(self, q='q', t='t'):
         r"""
         Returns the entry point for the various Macdonald bases.
