@@ -39,8 +39,11 @@ from sage.structure.sage_object import SageObject
 from sage.combinat.words.word_options import word_options
 from itertools import islice, groupby
 from sage.rings.all import Integers, ZZ, Infinity
+from sage.structure.richcmp import (richcmp_method, rich_to_bool,
+                                    richcmp, op_LT, op_GT)
 
 
+@richcmp_method
 class Word_class(SageObject):
     def parent(self):
         r"""
@@ -258,93 +261,43 @@ class Word_class(SageObject):
             raise TypeError(msg)
         return int(L)
 
-    def __cmp__(self, other):
+    def __richcmp__(self, other, op):
         r"""
-        Compares two words lexicographically according to the ordering
-        defined by the parent of self. This corresponds to Python's built-in
+        Compare two words lexicographically according to the ordering
+        defined by the parent of ``self``.
+
+        This corresponds to Python's built-in
         ordering when no parent nor alphabet was used to defined the word.
 
         Provides for all normal comparison operators.
 
         .. NOTE::
 
-            This function will not terminate if self and other are equal
-            infinite words!
+            This function will not terminate if ``self`` and ``other``
+            are equal infinite words!
 
         EXAMPLES::
 
             sage: W = Word
             sage: from itertools import count
-            sage: W(range(1,10)).__cmp__(W(range(10))) > 0
+            sage: W(range(1,10)) > W(range(10))
             True
-            sage: W(range(10)).__cmp__(W(range(1,10))) < 0
+            sage: W(range(10)) < W(range(1,10))
             True
-            sage: W(range(10)).__cmp__(W(range(10))) == 0
+            sage: W(range(10)) == W(range(10))
             True
-            sage: W(range(10)).__cmp__(W(count())) < 0
+            sage: W(range(10)) < W(count())
             True
-            sage: W(count()).__cmp__(W(range(10))) > 0
+            sage: W(count()) > W(range(10))
             True
 
         ::
 
             sage: W = Words(['a', 'b', 'c'])
-            sage: W('a').__cmp__(W([]))
-            1
-            sage: W([]).__cmp__(W('a'))
-            -1
-        """
-        if not isinstance(other, Word_class):
-            return NotImplemented
-        self_it, other_it = iter(self), iter(other)
-        cmp_key = self._parent.sortkey_letters
-        while True:
-            try:
-                cs = next(self_it)
-            except StopIteration:
-                try:
-                    co = next(other_it)
-                except StopIteration:
-                    # If both self_it and other_it are exhausted then
-                    # self == other. Return 0.
-                    return 0
-                else:
-                    # If self_it is exhausted, but not other_it, then
-                    # self is a proper prefix of other: return -1
-                    return -1
-            else:
-                try:
-                    co = next(other_it)
-                except StopIteration:
-                    # If self_it is not exhausted but other_it is, then
-                    # other is a proper prefix of self: return 1.
-                    return 1
-                else:
-                    key_cs = cmp_key(cs)
-                    key_co = cmp_key(co)
-                    if key_cs < key_co:
-                        return -1
-                    elif key_cs > key_co:
-                        return 1
-
-    def __eq__(self, other):
-        r"""
-        Returns True if self is equal to other and False otherwise.
-
-        INPUT:
-
-        - ``other`` - a word
-
-        OUTPUT:
-
-            boolean
-
-        .. NOTE::
-
-            This function will not terminate if self and other are equal
-            infinite words!
-
-        EXAMPLES::
+            sage: W('a') > W([])
+            True
+            sage: W([]) < W('a')
+            True
 
             sage: Word('abc') == Word(['a','b','c'])
             True
@@ -369,11 +322,21 @@ class Word_class(SageObject):
             sage: Word(lambda n:n) == Word(range(20))
             False
 
-        Beware the following does not halt!::
+        Beware the following does not halt! ::
 
             sage: from itertools import count
             sage: Word(lambda n:n) == Word(count()) #not tested
 
+        Examples for unequality::
+
+            sage: w = Word(range(10))
+            sage: z = Word(range(10))
+            sage: w != z
+            False
+            sage: u = Word(range(12))
+            sage: u != w
+            True
+
         TESTS::
 
             sage: Word(count())[:20] == Word(range(20))
@@ -388,6 +351,7 @@ class Word_class(SageObject):
         if not isinstance(other, Word_class):
             return NotImplemented
         self_it, other_it = iter(self), iter(other)
+        cmp_key = self._parent.sortkey_letters
         while True:
             try:
                 cs = next(self_it)
@@ -397,50 +361,25 @@ class Word_class(SageObject):
                 except StopIteration:
                     # If both self_it and other_it are exhausted then
                     # self == other. Return 0.
-                    return True
+                    return rich_to_bool(op, 0)
                 else:
                     # If self_it is exhausted, but not other_it, then
                     # self is a proper prefix of other: return -1
-                    return False
+                    return rich_to_bool(op, -1)
             else:
                 try:
                     co = next(other_it)
                 except StopIteration:
                     # If self_it is not exhausted but other_it is, then
                     # other is a proper prefix of self: return 1.
-                    return False
+                    return rich_to_bool(op, 1)
                 else:
-                    if cs != co:
-                        return False
-
-    def __ne__(self, other):
-        r"""
-        Returns True if self is not equal to other and False otherwise.
-
-        INPUT:
-
-        - ``other`` - a word
-
-        OUTPUT:
-
-            boolean
-
-        .. NOTE::
-
-            This function will not terminate if self and other are equal
-            infinite words!
-
-        EXAMPLES::
-
-            sage: w = Word(range(10))
-            sage: z = Word(range(10))
-            sage: w != z
-            False
-            sage: u = Word(range(12))
-            sage: u != w
-            True
-        """
-        return not self == other
+                    key_cs = cmp_key(cs)
+                    key_co = cmp_key(co)
+                    if key_cs < key_co:
+                        return rich_to_bool(op, -1)
+                    elif key_cs > key_co:
+                        return rich_to_bool(op, 1)
 
     def _longest_common_prefix_iterator(self, other):
         r"""
@@ -470,9 +409,7 @@ class Word_class(SageObject):
             if b == c:
                 yield b
             else:
-                raise StopIteration
-        else:
-            raise StopIteration
+                break
 
     def longest_common_prefix(self, other, length='unknown'):
         r"""
@@ -600,11 +537,11 @@ class Word_class(SageObject):
             sage: list(Word([1,2,1,2,1,3])._longest_periodic_prefix_iterator(2))
             [1, 2, 1, 2, 1]
         """
-        for i,l in enumerate(self):
-            if self[i%period] == l:
+        for i, l in enumerate(self):
+            if self[i % period] == l:
                 yield l
             else:
-                raise StopIteration
+                break
 
     def longest_periodic_prefix(self, period=1):
         r"""
@@ -770,7 +707,7 @@ class Word_class(SageObject):
             sage: t[:10].lex_less(t)
             True
         """
-        return self < other
+        return richcmp(self, other, op_LT)
 
     def lex_greater(self, other):
         r"""
@@ -800,9 +737,9 @@ class Word_class(SageObject):
             sage: t.lex_greater(t[:10])
             True
         """
-        return self > other
+        return richcmp(self, other, op_GT)
 
-    def apply_morphism(self,morphism):
+    def apply_morphism(self, morphism):
         r"""
         Returns the word obtained by applying the morphism to self.
 
@@ -874,13 +811,14 @@ class Word_class(SageObject):
 
     def delta(self):
         r"""
-        Returns the image of self under the delta morphism. This is the
-        word composed of the length of consecutive runs of the same letter
-        in a given word.
+        Returns the image of self under the delta morphism.
+
+        This is the word composed of the length of consecutive runs of
+        the same letter in a given word.
 
         OUTPUT:
 
-            Word over integers
+        Word over integers
 
         EXAMPLES:
 
@@ -903,7 +841,8 @@ class Word_class(SageObject):
             word: 1211222112112112221122211222112112112221...
         """
         from sage.combinat.words.word import Word
-        return Word(self._delta_iterator())
+        from sage.rings.semirings.non_negative_integer_semiring import NN
+        return Word(self._delta_iterator(), alphabet=NN)
 
     def _iterated_right_palindromic_closure_iterator(self, f=None):
         r"""
