@@ -18,8 +18,7 @@ AUTHORS:
 #
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
-from __future__ import print_function
-from __future__ import absolute_import, unicode_literals
+from __future__ import print_function, absolute_import
 
 import os
 import sys
@@ -27,6 +26,7 @@ import re
 import random
 import doctest
 from Cython.Utils import is_package_dir
+from sage.cpython.string import bytes_to_str
 from sage.repl.preparse import preparse
 from sage.repl.load import load
 from sage.misc.lazy_attribute import lazy_attribute
@@ -62,7 +62,7 @@ sagestart = re.compile(r"^\s*(>>> |sage: )\s*[^#\s]")
 untested = re.compile("(not implemented|not tested)")
 
 # For parsing a PEP 0263 encoding declaration
-pep_0263 = re.compile(r'coding[:=]\s*([-\w.]+)')
+pep_0263 = re.compile(br'^[ \t\v]*#.*?coding[:=]\s*([-\w.]+)')
 
 # Source line number in warning output
 doctest_line_number = re.compile(r"^\s*doctest:[0-9]")
@@ -468,6 +468,7 @@ class StringDocTestSource(DocTestSource):
         """
         return self._create_doctests(namespace)
 
+
 class FileDocTestSource(DocTestSource):
     """
     This class creates doctests from a file.
@@ -534,7 +535,8 @@ class FileDocTestSource(DocTestSource):
             sage: from sage.doctest.sources import FileDocTestSource
             sage: filename = tmp_filename(ext=".py")
             sage: s = "'''\n    sage: 2 + 2\n    4\n'''"
-            sage: _ = open(filename, 'w').write(s)
+            sage: with open(filename, 'w') as f:
+            ....:     _ = f.write(s)
             sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: for n, line in FDS:
             ....:     print("{} {}".format(n, line))
@@ -550,30 +552,32 @@ class FileDocTestSource(DocTestSource):
 
         We create a file with a Latin-1 encoding without declaring it::
 
-            sage: s = "'''\nRegardons le polyn\xF4me...\n'''\n"
-            sage: open(filename, 'w').write(s)
+            sage: s = b"'''\nRegardons le polyn\xF4me...\n'''\n"
+            sage: with open(filename, 'wb') as f:
+            ....:     _ = f.write(s)
             sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: L = list(FDS)
             Traceback (most recent call last):
             ...
-            UnicodeDecodeError: 'utf8' codec can't decode byte 0xf4 in position 18: invalid continuation byte
+            UnicodeDecodeError: 'utf...8' codec can't decode byte 0xf4 in position 18: invalid continuation byte
 
         This works if we add a PEP 0263 encoding declaration::
 
-            sage: s = "#!/usr/bin/env python\n# -*- coding: latin-1 -*-\n" + s
-            sage: open(filename, 'w').write(s)
+            sage: s = b"#!/usr/bin/env python\n# -*- coding: latin-1 -*-\n" + s
+            sage: with open(filename, 'wb') as f:
+            ....:     _ = f.write(s)
             sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: L = list(FDS)
             sage: FDS.encoding
             'latin-1'
         """
-        with open(self.path) as source:
+        with open(self.path, 'rb') as source:
             for lineno, line in enumerate(source):
                 if lineno < 2:
                     match = pep_0263.search(line)
                     if match:
-                        self.encoding = match.group(1)
-                yield lineno, unicode(line, self.encoding)
+                        self.encoding = bytes_to_str(match.group(1), 'ascii')
+                yield lineno, line.decode(self.encoding)
 
     @lazy_attribute
     def printpath(self):
@@ -695,7 +699,7 @@ class FileDocTestSource(DocTestSource):
             sage: doctests[18].name
             'sage.doctest.sources.FileDocTestSource.create_doctests'
             sage: doctests[18].examples[10].source
-            'doctests[Integer(18)].examples[Integer(10)].source\n'
+            u'doctests[Integer(18)].examples[Integer(10)].source\n'
 
         TESTS:
 
@@ -765,22 +769,9 @@ class FileDocTestSource(DocTestSource):
             ....:             filename = os.path.join(path, F)
             ....:             FDS = FileDocTestSource(filename, DocTestDefaults(long=True,optional=True))
             ....:             FDS._test_enough_doctests(verbose=False)
-            There are 7 tests in sage/combinat/diagram_algebras.py that are not being run
-            There are 7 tests in sage/combinat/dyck_word.py that are not being run
             There are 7 tests in sage/combinat/finite_state_machine.py that are not being run
-            There are 6 tests in sage/combinat/interval_posets.py that are not being run
-            There are 18 tests in sage/combinat/partition.py that are not being run
-            There are 15 tests in sage/combinat/permutation.py that are not being run
-            There are 14 tests in sage/combinat/skew_partition.py that are not being run
-            There are 18 tests in sage/combinat/tableau.py that are not being run
-            There are 8 tests in sage/combinat/crystals/tensor_product.py that are not being run
-            There are 11 tests in sage/combinat/rigged_configurations/rigged_configurations.py that are not being run
-            There are 15 tests in sage/combinat/root_system/cartan_type.py that are not being run
-            There are 8 tests in sage/combinat/root_system/type_A.py that are not being run
-            There are 8 tests in sage/combinat/root_system/type_G.py that are not being run
             There are 3 unexpected tests being run in sage/doctest/parsing.py
             There are 1 unexpected tests being run in sage/doctest/reporting.py
-            There are 15 tests in sage/manifolds/manifold.py that are not being run
             There are 3 tests in sage/rings/invariant_theory.py that are not being run
             sage: os.chdir(cwd)
         """
@@ -1049,23 +1040,23 @@ class PythonSource(SourceLanguage):
             sage: FDS = FileDocTestSource(filename,DocTestDefaults())
             sage: FDS._init()
             sage: FDS.starting_docstring("r'''")
-            <_sre.SRE_Match object at ...>
+            <_sre.SRE_Match object...>
             sage: FDS.ending_docstring("'''")
-            <_sre.SRE_Match object at ...>
+            <_sre.SRE_Match object...>
             sage: FDS.qualified_name = NestedName(FDS.basename)
             sage: FDS.starting_docstring("class MyClass(object):")
             sage: FDS.starting_docstring("    def hello_world(self):")
             sage: FDS.starting_docstring("        '''")
-            <_sre.SRE_Match object at ...>
+            <_sre.SRE_Match object...>
             sage: FDS.qualified_name
             sage.doctest.sources.MyClass.hello_world
             sage: FDS.ending_docstring("    '''")
-            <_sre.SRE_Match object at ...>
+            <_sre.SRE_Match object...>
             sage: FDS.starting_docstring("class NewClass(object):")
             sage: FDS.starting_docstring("    '''")
-            <_sre.SRE_Match object at ...>
+            <_sre.SRE_Match object...>
             sage: FDS.ending_docstring("    '''")
-            <_sre.SRE_Match object at ...>
+            <_sre.SRE_Match object...>
             sage: FDS.qualified_name
             sage.doctest.sources.NewClass
             sage: FDS.starting_docstring("print(")
@@ -1073,7 +1064,7 @@ class PythonSource(SourceLanguage):
             sage: FDS.starting_docstring("    ''')")
             sage: FDS.starting_docstring("def foo():")
             sage: FDS.starting_docstring("    '''This is a docstring'''")
-            <_sre.SRE_Match object at ...>
+            <_sre.SRE_Match object...>
         """
         indent = whitespace.match(line).end()
         quotematch = None
@@ -1127,7 +1118,7 @@ class PythonSource(SourceLanguage):
             sage: FDS._init()
             sage: FDS.quotetype = "'''"
             sage: FDS.ending_docstring("'''")
-            <_sre.SRE_Match object at ...>
+            <_sre.SRE_Match object...>
             sage: FDS.ending_docstring('\"\"\"')
         """
         quotematch = triple_quotes.match(line)
