@@ -1,78 +1,33 @@
 """
 Hyperbolic Functions
+
+The full set of hyperbolic and inverse hyperbolic functions is
+available:
+
+ - hyperbolic sine: :class:`sinh() <Function_sinh>`
+ - hyperbolic cosine: :class:`cosh() <Function_cosh>`
+ - hyperbolic tangent: :class:`tanh() <Function_tanh>`
+ - hyperbolic cotangent: :class:`coth() <Function_coth>`
+ - hyperbolic secant: :class:`sech() <Function_sech>`
+ - hyperbolic cosecant: :class:`csch() <Function_csch>`
+ - inverse hyperbolic sine: :class:`asinh() <Function_arcsinh>`
+ - inverse hyperbolic cosine: :class:`acosh() <Function_arccosh>`
+ - inverse hyperbolic tangent: :class:`atanh() <Function_arctanh>`
+ - inverse hyperbolic cotangent: :class:`acoth() <Function_arccoth>`
+ - inverse hyperbolic secant: :class:`asech() <Function_arcsech>`
+ - inverse hyperbolic cosecant: :class:`acsch() <Function_arccsch>`
+
+REFERENCES:
+
+- :wikipedia:`Hyperbolic function`
+
+- :wikipedia:`Inverse hyperbolic functions`
+
+- R. Roy, F. W. J. Olver, Elementary Functions, http://dlmf.nist.gov/4
 """
 from __future__ import division
 
-from sage.symbolic.function import GinacFunction, BuiltinFunction
-from sage.rings.infinity import Infinity
-from sage.symbolic.expression import Expression
-from sage.symbolic.constants import pi, I
-from sage.rings.integer_ring import ZZ
-
-import math
-
-
-class HyperbolicFunction(BuiltinFunction):
-    r"""
-    Abstract base class for the functions defined in this file.
-
-    EXAMPLES::
-
-        sage: from sage.functions.hyperbolic import HyperbolicFunction
-        sage: f = HyperbolicFunction('foo', latex_name='\\foo', conversions={'mathematica':'Foo'},evalf_float=lambda x: 2*x)
-        sage: f(x)
-        foo(x)
-        sage: f(0.5r)
-        1.0
-        sage: latex(f(x))
-        \foo\left(x\right)
-        sage: f(x)._mathematica_init_()
-        'Foo[x]'
-    """
-    def __init__(self, name, latex_name=None, conversions=None,
-            evalf_float=None):
-        """
-        Note that subclasses of HyperbolicFunction should be instantiated only
-        once, since they inherit from BuiltinFunction which only uses the
-        name and class to check if a function was already registered.
-
-        EXAMPLES::
-
-            sage: from sage.functions.hyperbolic import HyperbolicFunction
-            sage: class Barh(HyperbolicFunction):
-            ....:     def __init__(self):
-            ....:         HyperbolicFunction.__init__(self, 'barh')
-            sage: barh = Barh()
-            sage: barh(x)
-            barh(x)
-        """
-        self._evalf_float = evalf_float
-        BuiltinFunction.__init__(self, name, latex_name=latex_name,
-                conversions=conversions)
-
-    def _evalf_(self, x, parent=None, algorithm=None):
-        """
-        EXAMPLES::
-
-            sage: from sage.functions.hyperbolic import HyperbolicFunction
-            sage: class Fooh(HyperbolicFunction):
-            ....:     def __init__(self):
-            ....:         HyperbolicFunction.__init__(self, 'fooh',evalf_float=lambda x: 2*x)
-            sage: fooh = Fooh()
-            sage: fooh(float(5))
-            10.0
-            sage: fooh(0.5r)
-            1.0
-            sage: fooh(x).subs(x=.5r)
-            1.0
-            sage: fooh(x).n()
-            Traceback (most recent call last):
-            ...
-            AttributeError: 'sage.symbolic.expression.Expression' object has no attribute 'fooh'
-        """
-        if parent is float:
-            return self._evalf_float(x)
-        return getattr(x, self.name())()
+from sage.symbolic.function import GinacFunction
 
 
 class Function_sinh(GinacFunction):
@@ -101,12 +56,10 @@ class Function_sinh(GinacFunction):
             sage: sinh(arccosh(x),hold=True)
             sinh(arccosh(x))
 
-        To then evaluate again, we currently must use Maxima via
-        :meth:`sage.symbolic.expression.Expression.simplify`::
+        To then evaluate again, use the ``unhold`` method::
 
-            sage: sinh(arccosh(x),hold=True).simplify()
+            sage: sinh(arccosh(x),hold=True).unhold()
             sqrt(x + 1)*sqrt(x - 1)
-
         """
         GinacFunction.__init__(self, "sinh", latex_name=r"\sinh")
 
@@ -139,12 +92,10 @@ class Function_cosh(GinacFunction):
             sage: cosh(arcsinh(x),hold=True)
             cosh(arcsinh(x))
 
-        To then evaluate again, we currently must use Maxima via
-        :meth:`sage.symbolic.expression.Expression.simplify`::
+        To then evaluate again, use the ``unhold`` method::
 
-            sage: cosh(arcsinh(x),hold=True).simplify()
+            sage: cosh(arcsinh(x),hold=True).unhold()
             sqrt(x^2 + 1)
-
         """
         GinacFunction.__init__(self, "cosh", latex_name=r"\cosh")
 
@@ -185,10 +136,9 @@ class Function_tanh(GinacFunction):
             sage: tanh(arcsinh(x),hold=True)
             tanh(arcsinh(x))
 
-        To then evaluate again, we currently must use Maxima via
-        :meth:`sage.symbolic.expression.Expression.simplify`::
+        To then evaluate again, use the ``unhold`` method::
 
-            sage: tanh(arcsinh(x),hold=True).simplify()
+            sage: tanh(arcsinh(x),hold=True).unhold()
             x/sqrt(x^2 + 1)
 
         TESTS::
@@ -251,11 +201,11 @@ class Function_coth(GinacFunction):
             sage: diff(coth(x), x)
             -1/sinh(x)^2
             sage: latex(coth(x))
-            \operatorname{coth}\left(x\right)
+            \coth\left(x\right)
             sage: coth(x)._sympy_()
             coth(x)
         """
-        GinacFunction.__init__(self, "coth", latex_name=r"\operatorname{coth}")
+        GinacFunction.__init__(self, "coth", latex_name=r"\coth")
 
     def _eval_numpy_(self, x):
         """
@@ -355,11 +305,11 @@ class Function_csch(GinacFunction):
             sage: diff(csch(x), x)
             -coth(x)*csch(x)
             sage: latex(csch(x))
-            {\rm csch}\left(x\right)
+            \operatorname{csch}\left(x\right)
             sage: csch(x)._sympy_()
             csch(x)
         """
-        GinacFunction.__init__(self, "csch", latex_name=r"{\rm csch}")
+        GinacFunction.__init__(self, "csch", latex_name=r"\operatorname{csch}")
 
     def _eval_numpy_(self, x):
         """
@@ -387,54 +337,54 @@ class Function_arcsinh(GinacFunction):
 
         EXAMPLES::
 
-            sage: arcsinh
+            sage: asinh
             arcsinh
-            sage: arcsinh(0.5)
+            sage: asinh(0.5)
             0.481211825059603
-            sage: arcsinh(1/2)
+            sage: asinh(1/2)
             arcsinh(1/2)
-            sage: arcsinh(1 + I*1.0)
+            sage: asinh(1 + I*1.0)
             1.06127506190504 + 0.666239432492515*I
 
         To prevent automatic evaluation use the ``hold`` argument::
 
-            sage: arcsinh(-2,hold=True)
+            sage: asinh(-2,hold=True)
             arcsinh(-2)
 
-        To then evaluate again, we currently must use Maxima via
-        :meth:`sage.symbolic.expression.Expression.simplify`::
+        To then evaluate again, use the ``unhold`` method::
 
-            sage: arcsinh(-2,hold=True).simplify()
+            sage: asinh(-2,hold=True).unhold()
             -arcsinh(2)
 
-        ``conjugate(arcsinh(x))==arcsinh(conjugate(x))`` unless on the branch
+        ``conjugate(asinh(x))==asinh(conjugate(x))`` unless on the branch
         cuts which run along the imaginary axis outside the interval [-I, +I].::
 
-            sage: conjugate(arcsinh(x))
+            sage: conjugate(asinh(x))
             conjugate(arcsinh(x))
             sage: var('y', domain='positive')
             y
-            sage: conjugate(arcsinh(y))
+            sage: conjugate(asinh(y))
             arcsinh(y)
-            sage: conjugate(arcsinh(y+I))
+            sage: conjugate(asinh(y+I))
             conjugate(arcsinh(y + I))
-            sage: conjugate(arcsinh(1/16))
+            sage: conjugate(asinh(1/16))
             arcsinh(1/16)
-            sage: conjugate(arcsinh(I/2))
+            sage: conjugate(asinh(I/2))
             arcsinh(-1/2*I)
-            sage: conjugate(arcsinh(2*I))
+            sage: conjugate(asinh(2*I))
             conjugate(arcsinh(2*I))
 
         TESTS::
 
-            sage: arcsinh(x).operator()
+            sage: asinh(x).operator()
             arcsinh
-            sage: latex(arcsinh(x))
-            {\rm arcsinh}\left(x\right)
+            sage: latex(asinh(x))
+            \operatorname{arsinh}\left(x\right)
             sage: asinh(x)._sympy_()
             asinh(x)
         """
-        GinacFunction.__init__(self, "arcsinh", latex_name=r"{\rm arcsinh}",
+        GinacFunction.__init__(self, "arcsinh",
+                latex_name=r"\operatorname{arsinh}",
                 conversions=dict(maxima='asinh', sympy='asinh', fricas='asinh',
                                 giac='asinh'))
 
@@ -448,15 +398,15 @@ class Function_arccosh(GinacFunction):
 
         EXAMPLES::
 
-            sage: arccosh(1/2)
+            sage: acosh(1/2)
             arccosh(1/2)
-            sage: arccosh(1 + I*1.0)
+            sage: acosh(1 + I*1.0)
             1.06127506190504 + 0.904556894302381*I
-            sage: float(arccosh(2))
+            sage: float(acosh(2))
             1.3169578969248168
-            sage: cosh(float(arccosh(2)))
+            sage: cosh(float(acosh(2)))
             2.0
-            sage: arccosh(complex(1, 2))  # abs tol 1e-15
+            sage: acosh(complex(1, 2))  # abs tol 1e-15
             (1.5285709194809982+1.1437177404024204j)
 
         .. warning::
@@ -468,58 +418,58 @@ class Function_arccosh(GinacFunction):
 
         ::
 
-            sage: arccosh(0.5)
+            sage: acosh(0.5)
             NaN
-            sage: arccosh(1/2)
+            sage: acosh(1/2)
             arccosh(1/2)
-            sage: arccosh(1/2).n()
+            sage: acosh(1/2).n()
             NaN
-            sage: arccosh(CC(0.5))
+            sage: acosh(CC(0.5))
             1.04719755119660*I
-            sage: arccosh(0)
+            sage: acosh(0)
             1/2*I*pi
-            sage: arccosh(-1)
+            sage: acosh(-1)
             I*pi
 
         To prevent automatic evaluation use the ``hold`` argument::
 
-            sage: arccosh(-1,hold=True)
+            sage: acosh(-1,hold=True)
             arccosh(-1)
 
-        To then evaluate again, we currently must use Maxima via
-        :meth:`sage.symbolic.expression.Expression.simplify`::
+        To then evaluate again, use the ``unhold`` method::
 
-            sage: arccosh(-1,hold=True).simplify()
+            sage: acosh(-1,hold=True).unhold()
             I*pi
 
         ``conjugate(arccosh(x))==arccosh(conjugate(x))`` unless on the branch
         cut which runs along the real axis from +1 to -inf.::
 
-            sage: conjugate(arccosh(x))
+            sage: conjugate(acosh(x))
             conjugate(arccosh(x))
             sage: var('y', domain='positive')
             y
-            sage: conjugate(arccosh(y))
+            sage: conjugate(acosh(y))
             conjugate(arccosh(y))
-            sage: conjugate(arccosh(y+I))
+            sage: conjugate(acosh(y+I))
             conjugate(arccosh(y + I))
-            sage: conjugate(arccosh(1/16))
+            sage: conjugate(acosh(1/16))
             conjugate(arccosh(1/16))
-            sage: conjugate(arccosh(2))
+            sage: conjugate(acosh(2))
             arccosh(2)
-            sage: conjugate(arccosh(I/2))
+            sage: conjugate(acosh(I/2))
             arccosh(-1/2*I)
 
         TESTS::
 
-            sage: arccosh(x).operator()
+            sage: acosh(x).operator()
             arccosh
-            sage: latex(arccosh(x))
-            {\rm arccosh}\left(x\right)
+            sage: latex(acosh(x))
+            \operatorname{arcosh}\left(x\right)
             sage: acosh(x)._sympy_()
             acosh(x)
         """
-        GinacFunction.__init__(self, "arccosh", latex_name=r"{\rm arccosh}",
+        GinacFunction.__init__(self, "arccosh",
+                latex_name=r"\operatorname{arcosh}",
                 conversions=dict(maxima='acosh', sympy='acosh', fricas='acosh',
                                 giac='acosh'))
 
@@ -533,52 +483,52 @@ class Function_arctanh(GinacFunction):
 
         EXAMPLES::
 
-            sage: arctanh(0.5)
+            sage: atanh(0.5)
             0.549306144334055
-            sage: arctanh(1/2)
-            arctanh(1/2)
-            sage: arctanh(1 + I*1.0)
+            sage: atanh(1/2)
+            1/2*log(3)
+            sage: atanh(1 + I*1.0)
             0.402359478108525 + 1.01722196789785*I
 
         To prevent automatic evaluation use the ``hold`` argument::
 
-            sage: arctanh(-1/2,hold=True)
+            sage: atanh(-1/2,hold=True)
             arctanh(-1/2)
 
-        To then evaluate again, we currently must use Maxima via
-        :meth:`sage.symbolic.expression.Expression.simplify`::
+        To then evaluate again, use the ``unhold`` method::
 
-            sage: arctanh(-1/2,hold=True).simplify()
-            -arctanh(1/2)
+            sage: atanh(-1/2,hold=True).unhold()
+            -1/2*log(3)
 
         ``conjugate(arctanh(x))==arctanh(conjugate(x))`` unless on the branch
         cuts which run along the real axis outside the interval [-1, +1].::
 
-            sage: conjugate(arctanh(x))
+            sage: conjugate(atanh(x))
             conjugate(arctanh(x))
             sage: var('y', domain='positive')
             y
-            sage: conjugate(arctanh(y))
+            sage: conjugate(atanh(y))
             conjugate(arctanh(y))
-            sage: conjugate(arctanh(y+I))
+            sage: conjugate(atanh(y+I))
             conjugate(arctanh(y + I))
-            sage: conjugate(arctanh(1/16))
-            arctanh(1/16)
-            sage: conjugate(arctanh(I/2))
+            sage: conjugate(atanh(1/16))
+            1/2*log(17/15)
+            sage: conjugate(atanh(I/2))
             arctanh(-1/2*I)
-            sage: conjugate(arctanh(-2*I))
+            sage: conjugate(atanh(-2*I))
             arctanh(2*I)
 
         TESTS::
 
-            sage: arctanh(x).operator()
+            sage: atanh(x).operator()
             arctanh
-            sage: latex(arctanh(x))
-            {\rm arctanh}\left(x\right)
+            sage: latex(atanh(x))
+            \operatorname{artanh}\left(x\right)
             sage: atanh(x)._sympy_()
             atanh(x)
         """
-        GinacFunction.__init__(self, "arctanh", latex_name=r"{\rm arctanh}",
+        GinacFunction.__init__(self, "arctanh",
+                latex_name=r"\operatorname{artanh}",
                 conversions=dict(maxima='atanh', sympy='atanh', fricas='atanh',
                                 giac='atanh'))
 
@@ -592,13 +542,13 @@ class Function_arccoth(GinacFunction):
 
         EXAMPLES::
 
-            sage: arccoth(2.0)
+            sage: acoth(2.0)
             0.549306144334055
-            sage: arccoth(2)
-            arccoth(2)
-            sage: arccoth(1 + I*1.0)
+            sage: acoth(2)
+            1/2*log(3)
+            sage: acoth(1 + I*1.0)
             0.402359478108525 - 0.553574358897045*I
-            sage: arccoth(2).n(200)
+            sage: acoth(2).n(200)
             0.54930614433405484569762261846126285232374527891137472586735
 
             sage: bool(diff(acoth(x), x) == diff(atanh(x), x))
@@ -606,30 +556,27 @@ class Function_arccoth(GinacFunction):
             sage: diff(acoth(x), x)
             -1/(x^2 - 1)
 
-        Using first the `.n(53)` method is slightly more precise than
-        converting directly to a ``float``::
-
-            sage: float(arccoth(2))  # abs tol 1e-16
-            0.5493061443340548
-            sage: float(arccoth(2).n(53))   # Correct result to 53 bits
+            sage: float(acoth(2))
             0.5493061443340549
-            sage: float(arccoth(2).n(100))  # Compute 100 bits and then round to 53
+            sage: float(acoth(2).n(53))   # Correct result to 53 bits
+            0.5493061443340549
+            sage: float(acoth(2).n(100))  # Compute 100 bits and then round to 53
             0.5493061443340549
 
         TESTS::
 
-            sage: latex(arccoth(x))
-            \operatorname{arccoth}\left(x\right)
+            sage: latex(acoth(x))
+            \operatorname{arcoth}\left(x\right)
             sage: acoth(x)._sympy_()
             acoth(x)
 
         Check if :trac:`23636` is fixed::
 
-            sage: arccoth(float(1.1))
+            sage: acoth(float(1.1))
             1.5222612188617113
         """
         GinacFunction.__init__(self, "arccoth",
-                latex_name=r"\operatorname{arccoth}",
+                latex_name=r"\operatorname{arcoth}",
                 conversions=dict(maxima='acoth', sympy='acoth', fricas='acoth'))
 
     def _eval_numpy_(self, x):
@@ -638,7 +585,7 @@ class Function_arccoth(GinacFunction):
 
             sage: import numpy
             sage: a = numpy.arange(2,5)
-            sage: arccoth(a)
+            sage: acoth(a)
             array([ 0.54930614,  0.34657359,  0.25541281])
         """
         return arctanh(1.0 / x)
@@ -653,26 +600,26 @@ class Function_arcsech(GinacFunction):
 
         EXAMPLES::
 
-            sage: arcsech(0.5)
+            sage: asech(0.5)
             1.31695789692482
-            sage: arcsech(1/2)
+            sage: asech(1/2)
             arcsech(1/2)
-            sage: arcsech(1 + I*1.0)
+            sage: asech(1 + I*1.0)
             0.530637530952518 - 1.11851787964371*I
-            sage: arcsech(1/2).n(200)
+            sage: asech(1/2).n(200)
             1.3169578969248167086250463473079684440269819714675164797685
-            sage: float(arcsech(1/2))
+            sage: float(asech(1/2))
             1.3169578969248168
 
             sage: diff(asech(x), x)
             -1/(sqrt(-x^2 + 1)*x)
-            sage: latex(arcsech(x))
-            \operatorname{arcsech}\left(x\right)
+            sage: latex(asech(x))
+            \operatorname{arsech}\left(x\right)
             sage: asech(x)._sympy_()
             asech(x)
         """
         GinacFunction.__init__(self, "arcsech",
-                latex_name=r"\operatorname{arcsech}",
+                latex_name=r"\operatorname{arsech}",
                 conversions=dict(maxima='asech', sympy='asech', fricas='asech'))
 
     def _eval_numpy_(self, x):
@@ -681,7 +628,7 @@ class Function_arcsech(GinacFunction):
 
             sage: import numpy
             sage: a = numpy.linspace(0,1,3)
-            sage: arcsech(a)
+            sage: asech(a)
             doctest:...: RuntimeWarning: divide by zero encountered in ...divide
             array([       inf,  1.3169579,  0.       ])
         """
@@ -697,32 +644,34 @@ class Function_arccsch(GinacFunction):
 
         EXAMPLES::
 
-            sage: arccsch(2.0)
+            sage: acsch(2.0)
             0.481211825059603
-            sage: arccsch(2)
+            sage: acsch(2)
             arccsch(2)
-            sage: arccsch(1 + I*1.0)
+            sage: acsch(1 + I*1.0)
             0.530637530952518 - 0.452278447151191*I
-            sage: arccsch(1).n(200)
+            sage: acsch(1).n(200)
             0.88137358701954302523260932497979230902816032826163541075330
-            sage: float(arccsch(1))
+            sage: float(acsch(1))
             0.881373587019543
 
             sage: diff(acsch(x), x)
             -1/(sqrt(x^2 + 1)*x)
-            sage: latex(arccsch(x))
-            \operatorname{arccsch}\left(x\right)
+            sage: latex(acsch(x))
+            \operatorname{arcsch}\left(x\right)
 
         TESTS:
 
         Check if :trac:`20818` is fixed::
 
-            sage: arccsch(float(0.1))
+            sage: acsch(float(0.1))
             2.99822295029797
+            sage: acsch(x)._sympy_()
+            acsch(x)
         """
         GinacFunction.__init__(self, "arccsch",
-                latex_name=r"\operatorname{arccsch}",
-                conversions=dict(maxima='acsch', sympy='asech', fricas='acsch'))
+                latex_name=r"\operatorname{arcsch}",
+                conversions=dict(maxima='acsch', sympy='acsch', fricas='acsch'))
 
     def _eval_numpy_(self, x):
         """
@@ -730,7 +679,7 @@ class Function_arccsch(GinacFunction):
 
             sage: import numpy
             sage: a = numpy.linspace(0,1,3)
-            sage: arccsch(a)
+            sage: acsch(a)
             doctest:...: RuntimeWarning: divide by zero encountered in ...divide
             array([        inf,  1.44363548,  0.88137359])
         """
