@@ -290,7 +290,7 @@ class PiecewiseFunction(BuiltinFunction):
 
     class EvaluationMethods(object):
 
-        def expression_at(cls, self, parameters, variable, point):
+        def expression_at(self, parameters, variable, point):
             """
             Return the expression defining the piecewise function at
             ``value``
@@ -324,7 +324,7 @@ class PiecewiseFunction(BuiltinFunction):
 
         which_function = expression_at
 
-        def domains(cls, self, parameters, variable):
+        def domains(self, parameters, variable):
             """
             Return the individual domains
 
@@ -344,7 +344,7 @@ class PiecewiseFunction(BuiltinFunction):
             """
             return tuple(dom for dom, fun in parameters)
 
-        def domain(cls, self, parameters, variable):
+        def domain(self, parameters, variable):
             """
             Return the domain
 
@@ -365,7 +365,7 @@ class PiecewiseFunction(BuiltinFunction):
                 intervals += list(domain)
             return RealSet(*intervals)
 
-        def __len__(cls, self, parameters, variable):
+        def __len__(self, parameters, variable):
             """
             Return the number of "pieces"
 
@@ -382,7 +382,7 @@ class PiecewiseFunction(BuiltinFunction):
             """
             return len(parameters)
 
-        def expressions(cls, self, parameters, variable):
+        def expressions(self, parameters, variable):
             """
             Return the individual domains
 
@@ -401,7 +401,7 @@ class PiecewiseFunction(BuiltinFunction):
             """
             return tuple(fun for dom, fun in parameters)
 
-        def items(cls, self, parameters, variable):
+        def items(self, parameters, variable):
             """
             Iterate over the pieces of the piecewise function
 
@@ -428,7 +428,7 @@ class PiecewiseFunction(BuiltinFunction):
             for pair in parameters:
                 yield pair
 
-        def __call__(cls, self, parameters, variable, value=None, **kwds):
+        def __call__(self, parameters, variable, value=None, **kwds):
             """
             Call the piecewise function
 
@@ -453,7 +453,7 @@ class PiecewiseFunction(BuiltinFunction):
                 substitution[variable] = value
             return self.subs(substitution)
 
-        def _fast_float_(cls, self, *args):
+        def _fast_float_(self, *args):
             """
             Do not support the old ``fast_float``
 
@@ -472,7 +472,7 @@ class PiecewiseFunction(BuiltinFunction):
             """
             raise NotImplementedError
 
-        def _fast_callable_(cls, self, parameters, variable, etb):
+        def _fast_callable_(self, parameters, variable, etb):
             """
             Override the ``fast_callable``
 
@@ -493,7 +493,7 @@ class PiecewiseFunction(BuiltinFunction):
             self = piecewise(parameters, var=variable)
             return etb.call(self, variable)
 
-        def restriction(cls, self, parameters, variable, restricted_domain):
+        def restriction(self, parameters, variable, restricted_domain):
             """
             Restrict the domain
 
@@ -521,7 +521,7 @@ class PiecewiseFunction(BuiltinFunction):
                 new_param.append((domain, func))
             return piecewise(new_param, var=variable)
 
-        def extension(cls, self, parameters, variable, extension, extension_domain=None):
+        def extension(self, parameters, variable, extension, extension_domain=None):
             """
             Extend the function
 
@@ -559,7 +559,7 @@ class PiecewiseFunction(BuiltinFunction):
             ext = ((extension_domain, SR(extension)),)
             return piecewise(parameters + ext, var=variable)
 
-        def unextend_zero(cls, self, parameters, variable):
+        def unextend_zero(self, parameters, variable):
             """
             Remove zero pieces.
 
@@ -579,7 +579,7 @@ class PiecewiseFunction(BuiltinFunction):
                       if func != 0]
             return piecewise(result, var=variable)
 
-        def pieces(cls, self, parameters, variable):
+        def pieces(self, parameters, variable):
             """
             Return the "pieces".
 
@@ -600,7 +600,7 @@ class PiecewiseFunction(BuiltinFunction):
                 result.append(piecewise([(domain, func)], var=variable))
             return tuple(result)
 
-        def end_points(cls, self, parameters, variable):
+        def end_points(self, parameters, variable):
             """
             Return a list of all interval endpoints for this function.
 
@@ -626,7 +626,7 @@ class PiecewiseFunction(BuiltinFunction):
             s.discard(infinity)
             return sorted(s)
 
-        def piecewise_add(cls, self, parameters, variable, other):
+        def piecewise_add(self, parameters, variable, other):
             """
             Return a new piecewise function with domain the union
             of the original domains and functions summed. Undefined
@@ -699,7 +699,7 @@ class PiecewiseFunction(BuiltinFunction):
                     funcs.append(ex)
             return piecewise(zip(domain, funcs))
 
-        def integral(cls, self, parameters, variable, x=None, a=None, b=None, definite=False):
+        def integral(self, parameters, variable, x=None, a=None, b=None, definite=False):
             r"""
             By default, return the indefinite integral of the function.
             If definite=True is given, returns the definite integral.
@@ -847,7 +847,7 @@ class PiecewiseFunction(BuiltinFunction):
             else:
                 return piecewise(new_pieces)
 
-        def critical_points(cls, self, parameters, variable):
+        def critical_points(self, parameters, variable):
             """
             Return the critical points of this piecewise function.
 
@@ -888,7 +888,7 @@ class PiecewiseFunction(BuiltinFunction):
                             crit_pts.append(root)
             return crit_pts
 
-        def convolution(cls, self, parameters, variable, other):
+        def convolution(self, parameters, variable, other):
             """
             Return the convolution function,
             `f*g(t)=\int_{-\infty}^\infty f(u)g(t-u)du`, for compactly
@@ -970,7 +970,7 @@ class PiecewiseFunction(BuiltinFunction):
                         z = z.piecewise_add(h)
                 return z.unextend_zero()
 
-        def trapezoid(cls, self, parameters, variable, N):
+        def trapezoid(self, parameters, variable, N):
             """
             Return the piecewise line function defined by the trapezoid rule
             for numerical integration based on a subdivision of each domain
@@ -1015,7 +1015,7 @@ class PiecewiseFunction(BuiltinFunction):
                         rsum += func(x0, x1)
             return piecewise(rsum)
 
-        def laplace(cls, self, parameters, variable, x='x', s='t'):
+        def laplace(self, parameters, variable, x='x', s='t'):
             r"""
             Returns the Laplace transform of self with respect to the variable
             var.
@@ -1068,7 +1068,7 @@ class PiecewiseFunction(BuiltinFunction):
             forget(s>0)
             return result
 
-        def fourier_series_cosine_coefficient(cls, self, parameters,
+        def fourier_series_cosine_coefficient(self, parameters,
                                               variable, n, L=None):
             r"""
             Return the `n`-th cosine coefficient of the Fourier series of
@@ -1165,7 +1165,7 @@ class PiecewiseFunction(BuiltinFunction):
                     result += (f*cos(pi*x*n/L)).integrate(x, a, b)
             return SR(result/L0).simplify_trig()
 
-        def fourier_series_sine_coefficient(cls, self, parameters, variable,
+        def fourier_series_sine_coefficient(self, parameters, variable,
                                             n, L=None):
             r"""
             Return the `n`-th sine coefficient of the Fourier series of
@@ -1256,7 +1256,7 @@ class PiecewiseFunction(BuiltinFunction):
                     result += (f*sin(pi*x*n/L)).integrate(x, a, b)
             return SR(result/L0).simplify_trig()
 
-        def fourier_series_partial_sum(cls, self, parameters, variable, N,
+        def fourier_series_partial_sum(self, parameters, variable, N,
                                        L=None):
             r"""
             Returns the partial sum up to a given order of the Fourier series
