@@ -655,17 +655,19 @@ def SL2R_to_SO21(A):
     a, b, c, d = (A/A.det().sqrt()).list()
 
     # Kill ~0 imaginary parts
-    B = matrix(3, map(real,
-                      [a*d + b*c, a*c - b*d, a*c + b*d, a*b - c*d,
-                       Integer(1)/Integer(2)*a**2 - Integer(1)/Integer(2)*b**2 -
-                       Integer(1)/Integer(2)*c**2 + Integer(1)/Integer(2)*d**2,
-                       Integer(1)/Integer(2)*a**2 + Integer(1)/Integer(2)*b**2 -
-                       Integer(1)/Integer(2)*c**2 - Integer(1)/Integer(2)*d**2,
-                       a*b + c*d, Integer(1)/Integer(2)*a**2 -
-                       Integer(1)/Integer(2)*b**2 + Integer(1)/Integer(2)*c**2 -
-                       Integer(1)/Integer(2)*d**2, Integer(1)/Integer(2)*a**2 +
-                       Integer(1)/Integer(2)*b**2 + Integer(1)/Integer(2)*c**2 +
-                       Integer(1)/Integer(2)*d**2]))
+    components = [
+        a*d + b*c, a*c - b*d, a*c + b*d, a*b - c*d,
+        Integer(1)/Integer(2)*a**2 - Integer(1)/Integer(2)*b**2 -
+                Integer(1)/Integer(2)*c**2 + Integer(1)/Integer(2)*d**2,
+        Integer(1)/Integer(2)*a**2 + Integer(1)/Integer(2)*b**2 -
+                Integer(1)/Integer(2)*c**2 - Integer(1)/Integer(2)*d**2,
+        a*b + c*d, Integer(1)/Integer(2)*a**2 -
+                Integer(1)/Integer(2)*b**2 + Integer(1)/Integer(2)*c**2 -
+        Integer(1)/Integer(2)*d**2, Integer(1)/Integer(2)*a**2 +
+                Integer(1)/Integer(2)*b**2 + Integer(1)/Integer(2)*c**2 +
+        Integer(1)/Integer(2)*d**2
+    ]
+    B = matrix(3, [real(c) for c in components])
 
     #B = B.apply_map(attrcall('real'))
     if A.det() > 0:
