@@ -18,13 +18,11 @@ The methods defined here appear in :mod:`sage.graphs.graph_generators`.
 from __future__ import absolute_import, division
 from six.moves import range
 
-from copy import copy
-from math import sin, cos, pi
 from sage.graphs.graph import Graph
-from sage.graphs import graph
 from sage.arith.all import is_prime_power
 from sage.rings.finite_rings.finite_field_constructor import FiniteField
 
+
 def SymplecticPolarGraph(d, q, algorithm=None):
     r"""
     Returns the Symplectic Polar Graph `Sp(d,q)`.
@@ -34,7 +32,7 @@ def SymplecticPolarGraph(d, q, algorithm=None):
     made adjacent if `f(u,v)=0`.
 
     See the page `on symplectic graphs on Andries Brouwer's website
-    <http://www.win.tue.nl/~aeb/graphs/Sp.html>`_.
+    <https://www.win.tue.nl/~aeb/graphs/Sp.html>`_.
 
     INPUT:
 
@@ -124,7 +122,7 @@ def AffineOrthogonalPolarGraph(d,q,sign="+"):
 
     For more information on Affine Polar graphs, see `Affine Polar
     Graphs page of Andries Brouwer's website
-    <http://www.win.tue.nl/~aeb/graphs/VO.html>`_.
+    <https://www.win.tue.nl/~aeb/graphs/VO.html>`_.
 
     INPUT:
 
@@ -153,7 +151,7 @@ def AffineOrthogonalPolarGraph(d,q,sign="+"):
         True
 
     Some examples from `Brouwer's table or strongly regular graphs
-    <http://www.win.tue.nl/~aeb/graphs/srg/srgtab.html>`_::
+    <https://www.win.tue.nl/~aeb/graphs/srg/srgtab.html>`_::
 
         sage: g = graphs.AffineOrthogonalPolarGraph(6,2,"-"); g
         Affine Polar Graph VO^-(6,2): Graph on 64 vertices
@@ -184,7 +182,6 @@ def AffineOrthogonalPolarGraph(d,q,sign="+"):
             raise ValueError("d must be odd when sign==None")
         s = 0
 
-    from sage.interfaces.gap import gap
     from sage.modules.free_module import VectorSpace
     from sage.matrix.constructor import Matrix
     from sage.libs.gap.libgap import libgap
@@ -209,7 +206,7 @@ def _orthogonal_polar_graph(m, q, sign="+", point_type=[0]):
     A helper function to build ``OrthogonalPolarGraph`` and ``NO2,3,5`` graphs.
 
     See the `page of
-    Andries Brouwer's website <http://www.win.tue.nl/~aeb/graphs/srghub.html>`_.
+    Andries Brouwer's website <https://www.win.tue.nl/~aeb/graphs/srghub.html>`_.
 
     INPUT:
 
@@ -287,7 +284,6 @@ def _orthogonal_polar_graph(m, q, sign="+", point_type=[0]):
     from sage.modules.free_module_element import free_module_element as vector
     from sage.matrix.constructor import Matrix
     from sage.libs.gap.libgap import libgap
-    from itertools import combinations
 
     if m % 2 == 0:
         if sign != "+" and sign != "-":
@@ -330,7 +326,7 @@ def OrthogonalPolarGraph(m, q, sign="+"):
     Returns the Orthogonal Polar Graph `O^{\epsilon}(m,q)`.
 
     For more information on Orthogonal Polar graphs, see the `page of
-    Andries Brouwer's website <http://www.win.tue.nl/~aeb/graphs/srghub.html>`_.
+    Andries Brouwer's website <https://www.win.tue.nl/~aeb/graphs/srghub.html>`_.
 
     INPUT:
 
@@ -401,7 +397,7 @@ def NonisotropicOrthogonalPolarGraph(m, q, sign="+", perp=None):
       Note that for `q=2` one will get a complete graph.
 
     For more information, see Sect. 9.9 of [BH12]_ and [BvL84]_. Note that the `page of
-    Andries Brouwer's website <http://www.win.tue.nl/~aeb/graphs/srghub.html>`_
+    Andries Brouwer's website <https://www.win.tue.nl/~aeb/graphs/srghub.html>`_
     uses different notation.
 
     INPUT:
@@ -520,14 +516,13 @@ def NonisotropicOrthogonalPolarGraph(m, q, sign="+", perp=None):
         deg = (q**n-e)*(q**(n-1)+e)   # k
         S=map(lambda x: libgap.Elements(libgap.Basis(x))[0], \
             libgap.Elements(libgap.Subspaces(W,1)))
-        V = filter(lambda x: len(x)==nvert, libgap.Orbits(g,S,libgap.OnLines))
-        assert len(V)==1
-        V = V[0]
+        (V,) = [x for x in libgap.Orbits(g, S, libgap.OnLines)
+                if len(x) == nvert]
         gp = libgap.Action(g,V,libgap.OnLines)  # make a permutation group
         h = libgap.Stabilizer(gp,1)
-        Vh = filter(lambda x: len(x)==deg, libgap.Orbits(h,libgap.Orbit(gp,1)))
-        assert len(Vh)==1
-        Vh = Vh[0][0]
+        (Vh,) = [x for x in libgap.Orbits(h, libgap.Orbit(gp, 1))
+                 if len(x) == deg]
+        Vh = Vh[0]
         L = libgap.Orbit(gp, [1, Vh], libgap.OnSets)
         G = Graph()
         G.add_edges(L)
@@ -592,7 +587,7 @@ def UnitaryPolarGraph(m, q, algorithm="gap"):
     Returns the Unitary Polar Graph `U(m,q)`.
 
     For more information on Unitary Polar graphs, see the `page of
-    Andries Brouwer's website <http://www.win.tue.nl/~aeb/graphs/srghub.html>`_.
+    Andries Brouwer's website <https://www.win.tue.nl/~aeb/graphs/srghub.html>`_.
 
     INPUT:
 
@@ -637,7 +632,7 @@ def UnitaryPolarGraph(m, q, algorithm="gap"):
         def P(x, y):
             return sum(x[j] * y[m - 1 - j] ** q for j in range(m)) == 0
 
-        V = filter(lambda x: P(x,x), PG)
+        V = [x for x in PG if P(x,x)]
         G = Graph([V,lambda x,y:  # bottleneck is here, of course:
                      P(x,y)], loops=False)
     else:
@@ -877,7 +872,6 @@ def TaylorTwographDescendantSRG(q, clique_partition=None):
     if k==0 or p==2:
        raise ValueError('q must be an odd prime power')
     from sage.schemes.projective.projective_space import ProjectiveSpace
-    from sage.modules.free_module_element import free_module_element as vector
     from sage.rings.finite_rings.integer_mod import mod
     from six.moves.builtins import sum
     Fq = FiniteField(q**2, 'a')
@@ -886,7 +880,7 @@ def TaylorTwographDescendantSRG(q, clique_partition=None):
     def S(x, y):
         return sum(x[j] * y[2 - j] ** q for j in range(3))
 
-    V = filter(lambda x: S(x,x)==0, PG) # the points of the unital
+    V = [x for x in PG if S(x,x) == 0] # the points of the unital
     v0 = V[0]
     V.remove(v0)
     if mod(q,4)==1:
@@ -895,12 +889,13 @@ def TaylorTwographDescendantSRG(q, clique_partition=None):
         G = Graph([V,lambda y,z:     (S(v0,y)*S(y,z)*S(z,v0)).is_square()], loops=False)
     G.name("Taylor two-graph descendant SRG")
     if clique_partition:
-        lines = map(lambda x: filter(lambda t: t[0]+x*t[1]==0, V),
-                     filter(lambda z: z != 0, Fq))
+        lines = [[t for t in V if t[0] + z * t[1] == 0]
+                 for z in Fq if z]
         return (G, lines, v0)
     else:
         return G
 
+
 def TaylorTwographSRG(q):
     r"""
     constructing a strongly regular graph from the Taylor's two-graph for `U_3(q)`, `q` odd
@@ -1066,7 +1061,6 @@ def T2starGeneralizedQuadrangleGraph(q, dual=False, hyperoval=None, field=None,
     """
     from sage.combinat.designs.incidence_structures import IncidenceStructure
     from sage.combinat.designs.block_design import ProjectiveGeometryDesign as PG
-    from sage.modules.free_module_element import free_module_element as vector
 
     p, k = is_prime_power(q,get_data=True)
     if k==0 or p!=2:
@@ -1187,7 +1181,7 @@ def HaemersGraph(q, hyperoval=None, hyperoval_matching=None, field=None, check_h
         raise ValueError('q must be a power of 2')
 
     if hyperoval_matching is None:
-        hyperoval_matching = [(2 * k + 1, 2 * k) for k in range(1 + q // 2)]
+        hyperoval_matching = [(2 * K + 1, 2 * K) for K in range(1 + q // 2)]
     if field is None:
         F = GF(q, 'a')
     else:
@@ -1204,8 +1198,8 @@ def HaemersGraph(q, hyperoval=None, hyperoval_matching=None, field=None, check_h
     P = map(lambda x: normalize(x[0]-x[1]), G.vertices())
     O = list(set(map(tuple,P)))
     I_ks = {x:[] for x in range(q+2)} # the partition into I_k's
-    for i in range(len(P)):
-        I_ks[O.index(tuple(P[i]))].append(i)
+    for i, Pi in enumerate(P):
+        I_ks[O.index(tuple(Pi))].append(i)
 
     # perform the adjustment of the edges, as described.
     G.relabel()
@@ -1219,6 +1213,7 @@ def HaemersGraph(q, hyperoval=None, hyperoval_matching=None, field=None, check_h
     G.name('Haemers('+str(q)+')')
     return G
 
+
 def CossidentePenttilaGraph(q):
     r"""
     Cossidente-Penttila `((q^3+1)(q+1)/2,(q^2+1)(q-1)/2,(q-3)/2,(q-1)^2/2)`-strongly regular graph
@@ -1284,12 +1279,10 @@ def CossidentePenttilaGraph(q):
     if k==0 or p==2:
         raise ValueError('q(={}) must be an odd prime power'.format(q))
 
+    from sage.features.gap import GapPackage
+    GapPackage("grape", spkg="gap_packages").require()
+
     from sage.libs.gap.libgap import libgap
-    from sage.misc.package import is_package_installed, PackageNotFoundError
-
-    if not is_package_installed('gap_packages'):
-        raise PackageNotFoundError('gap_packages')
-
     adj_list=libgap.function_factory("""function(q)
         local z, e, so, G, nu, G1, G0, B, T, s, O1, O2, x;
         LoadPackage("grape");
@@ -1411,7 +1404,6 @@ def Nowhere0WordsTwoWeightCodeGraph(q, hyperoval=None, field=None, check_hyperov
 
     """
     from sage.combinat.designs.block_design import ProjectiveGeometryDesign as PG
-    from sage.modules.free_module_element import free_module_element as vector
     from sage.matrix.constructor import matrix
 
     p, k = is_prime_power(q,get_data=True)
