@@ -45,19 +45,18 @@ REFERENCES:
 # Distributed  under  the  terms  of  the  GNU  General  Public  License (GPL)
 #                         http://www.gnu.org/licenses/
 ################################################################################
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import print_function, absolute_import
 
 from . import graph
 import os
 import re
 from sage.rings.integer import Integer
-from sqlite3 import dbapi2 as sqlite # if anyone would like to explain why dbapi2...
 from sage.databases.sql_db import SQLDatabase, SQLQuery
 from sage.env import GRAPHS_DATA_DIR
 from sage.graphs.graph import Graph
 dblocation = os.path.join(GRAPHS_DATA_DIR,'graphs.db')
 
+
 def degseq_to_data(degree_sequence):
     """
     Takes a degree sequence list (of Integers) and converts to a sorted
@@ -73,6 +72,7 @@ def degseq_to_data(degree_sequence):
     degree_sequence.sort()
     return sum(degree_sequence[i]*10**i for i in range(len(degree_sequence)))
 
+
 def data_to_degseq(data, graph6=None):
     """
     Takes the database integer data type (one digit per vertex
@@ -206,8 +206,8 @@ def graph_db_info(tablename=None):
 
     EXAMPLES::
 
-        sage: graph_db_info().keys()
-        ['graph_data', 'degrees', 'spectrum', 'misc', 'aut_grp']
+        sage: sorted(graph_db_info())
+        ['aut_grp', 'degrees', 'graph_data', 'misc', 'spectrum']
 
     ::
 
@@ -638,7 +638,7 @@ class GraphQuery(GenericGraphQuery):
 
     def get_graphs_list(self):
         """
-        Returns a list of Sage Graph objects that satisfy the query.
+        Return a list of Sage Graph objects that satisfy the query.
 
         EXAMPLES::
 
@@ -649,8 +649,6 @@ class GraphQuery(GenericGraphQuery):
             sage: len(L)
             35
         """
-        from sage.graphs.graph_list import from_graph6
-
         s = self.__query_string__
         re.sub('SELECT.*FROM ', 'SELECT graph6 FROM ', s)
         q = GenericGraphQuery(s, self.__database__, self.__param_tuple__)
