@@ -133,7 +133,7 @@ This decomposition turns out to be very easy to implement :-)
   Characterizations of derived graphs,
   Journal of Combinatorial Theory,
   Vol. 9(2), pages 129-135, 1970
-  http://dx.doi.org/10.1016/S0021-9800(70)80019-9
+  :doi:`10.1016/S0021-9800(70)80019-9`
 
 Functions
 ---------
@@ -574,13 +574,14 @@ def root_graph(g, verbose = False):
             print("Added clique", S)
 
     # Deal with even triangles
-    for u,v,w in even_triangles:
+    for u, v, w in even_triangles:
 
-        # According to Beineke, we must go through all even triangles, and for
-        # each triangle uvw consider its three pairs of adjacent verties uv, vw,
-        # wu. For all pairs xy among those such that xy do not appear together
-        # in any clique we have found so far, we add xy to the list of cliques
-        # describing our covering.
+        # According to Beineke, we must go through all even triangles,
+        # and for each triangle uvw consider its three pairs of
+        # adjacent vertices uv, vw, wu. For all pairs xy among those
+        # such that xy do not appear together in any clique we have
+        # found so far, we add xy to the list of cliques describing
+        # our covering.
 
         for x,y in [(u,v), (v,w), (w,u)]:
 
