@@ -13,6 +13,7 @@ etc.). It also implements some iterators over all these orientations.
     :delim: |
 
     :meth:`strong_orientations_iterator` | Return an iterator over all strong orientations of a graph `G`
+    :meth:`random_orientation` | Return a random orientation of a graph `G`
 
 
 Authors
@@ -24,11 +25,11 @@ Authors
 Methods
 -------
 """
-
-
+from copy import copy
 from sage.graphs.spanning_tree import kruskal
 from sage.graphs.digraph import DiGraph
 
+
 def strong_orientations_iterator(G):
     r"""
     Returns an iterator over all strong orientations of a graph `G`.
@@ -237,3 +238,61 @@ def _strong_orientations_of_a_mixed_graph(Dg, V, E):
         E.append((u,v))
     Dg.add_edges(boundEdges)
     E.extend(boundEdges)
+
+
+def random_orientation(G):
+    r"""
+    Return a random orientation of a graph `G`.
+
+    An *orientation* of an undirected graph is a directed graph such that every
+    edge is assigned a direction. Hence there are `2^m` oriented digraphs for a
+    simple graph with `m` edges.
+
+    INPUT:
+
+    - ``G`` -- a Graph.
+
+    EXAMPLES::
+
+        sage: from sage.graphs.orientations import random_orientation
+        sage: G = graphs.PetersenGraph()
+        sage: D = random_orientation(G)
+        sage: D.order() == G.order(), D.size() == G.size()
+        (True, True)
+
+    TESTS:
+
+    Giving anything else than a Graph::
+
+        sage: random_orientation([])
+        Traceback (most recent call last):
+        ...
+        ValueError: the input parameter must be a Graph
+
+    .. SEEALSO::
+
+        - :meth:`~Graph.orientations`
+    """
+    from sage.graphs.graph import Graph
+    if not isinstance(G, Graph):
+        raise ValueError("the input parameter must be a Graph")
+
+    D = DiGraph(data=[G.vertices(), []],
+                format='vertices_and_edges',
+                multiedges=G.allows_multiple_edges(),
+                loops=G.allows_loops(),
+                weighted=G.weighted(),
+                pos=G.get_pos(),
+                name="Random orientation of {}".format(G.name()) )
+    if hasattr(G, '_embedding'):
+        D._embedding = copy(G._embedding)
+
+    from sage.misc.prandom import getrandbits
+    rbits = getrandbits(G.size())
+    for u,v,l in G.edge_iterator():
+        if rbits % 2:
+            D.add_edge(u, v, l)
+        else:
+            D.add_edge(v, u, l)
+        rbits >>= 1
+    return D
