@@ -527,6 +527,27 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
             return False
         return G.gap().IsSubsemigroup(self).sage()
 
+    def _subgroup_constructor(self, libgap_subgroup):
+        r"""
+        Create a subgroup from the input.
+
+        See :class:`~sage.groups.libgap_wrapper`. Override this in derived
+        classes.
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: A = AbelianGroupGap([2,3,4,5])
+            sage: S = A.subgroup(A.gens()[:1])
+            sage: T = A._subgroup_constructor(S.gap())
+            sage: S is T
+            True
+        """
+        ambient = self.ambient()
+        generators = libgap_subgroup.GeneratorsOfGroup()
+        generators = tuple([ambient(g) for g in generators])
+        return AbelianGroupSubgroup_gap(ambient, generators)
+
     def subgroup(self, gens):
         r"""
         Return the subgroup of this group generated by ``gens``.
@@ -637,7 +658,7 @@ class AbelianGroupGap(AbelianGroup_gap):
         AbelianGroup_gap.__init__(self, G, category=category)
 
     def _latex_(self):
-        """
+        r"""
         Return a latex representation of this group.
 
         EXAMPLES::
@@ -645,9 +666,11 @@ class AbelianGroupGap(AbelianGroup_gap):
             sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
             sage: G = AbelianGroupGap([2,6])
             sage: G._latex_()
-            'Abelian group with gap, generator orders $(2, 6)$'
+            \text{\texttt{Abelian group with gap, generator orders }} \left(2, 6\right)
         """
-        return "Abelian group with gap, generator orders ${}$".format(self.gens_orders())
+        from sage.misc.latex import latex
+        base = r"\text{\texttt{Abelian group with gap, generator orders }}"
+        return base + latex(self.gens_orders())
 
     def _repr_(self):
         r"""
