@@ -36,7 +36,8 @@ seed, but currently there is no facility to do so.
 #                   http://www.gnu.org/licenses/
 ###############################################################################
 from __future__ import print_function
-from six import iteritems
+
+from six import iteritems, PY2
 
 import os
 import re
@@ -206,7 +207,17 @@ class ECM(SageObject):
             '1234'
         """
         from subprocess import Popen, PIPE
-        p = Popen(cmd, stdout=PIPE, stdin=PIPE, stderr=PIPE)
+
+        if PY2:
+            enc_kwds = {}
+        else:
+            # Under normal usage this program only returns ASCII; anything
+            # else mixed is garbage and an error
+            # So just accept latin-1 without encoding errors, and let the
+            # output parser deal with the rest
+            enc_kwds = {'encoding': 'latin-1'}
+
+        p = Popen(cmd, stdout=PIPE, stdin=PIPE, stderr=PIPE, **enc_kwds)
         out, err = p.communicate(input=str(n))
         if err != '':
             raise ValueError(err)
