@@ -40,8 +40,11 @@ AUTHORS:
 #*****************************************************************************
 from __future__ import print_function, absolute_import
 from six import string_types
+from six import reraise as raise_
 
+import io
 import os
+import re
 import signal
 import sys
 import weakref
@@ -55,7 +58,7 @@ import pexpect
 from pexpect import ExceptionPexpect
 from sage.interfaces.sagespawn import SageSpawn
 from sage.interfaces.interface import (Interface, InterfaceElement,
-        InterfaceFunction, InterfaceFunctionElement, AsciiArtString)
+            InterfaceFunction, InterfaceFunctionElement, AsciiArtString)
 
 from sage.structure.element import RingElement
 
@@ -64,7 +67,7 @@ from sage.env import SAGE_EXTCODE, LOCAL_IDENTIFIER
 from sage.misc.object_multiplexer import Multiplex
 from sage.docs.instancedoc import instancedoc
 
-from six import reraise as raise_
+from sage.cpython.string import str_to_bytes, bytes_to_str
 
 BAD_SESSION = -2
 
@@ -153,7 +156,7 @@ class Expect(Interface):
         self.set_server_and_command(server, command, server_tmpdir, ulimit)
         self._env = env
         self.__do_cleaner = do_cleaner
-        self._prompt = prompt
+        self._change_prompt(prompt)
         self._restart_on_ctrlc = restart_on_ctrlc
         if path is not None:
             self.__path = os.path.abspath(path)
@@ -253,14 +256,18 @@ class Expect(Interface):
             if alternate_prompt is None:
                 E.expect(self._prompt, timeout=wait)
             else:
-                E.expect(alternate_prompt, timeout=wait)
+                E.expect(str_to_bytes(alternate_prompt), timeout=wait)
         except pexpect.TIMEOUT:
-            return False, E.before
+            # TODO: In case an unexpected error occurred it's possible that the
+            # contents of E.before, if consisting of multi-byte encoded text,
+            # may be incomplete and contain errors, so merely calling
+            # bytes_to_str here is probably not sufficient.
+            return False, self._before()
         except pexpect.EOF:
-            return True, E.before
+            return True, self._before()
         except Exception:   # weird major problem!
-            return True, E.before
-        return True, E.before
+            return True, self._before()
+        return True, self._before()
 
     def _send(self, cmd):
         if self._expect is None:
@@ -313,6 +320,12 @@ class Expect(Interface):
         return self.__path
 
     def _change_prompt(self, prompt):
+        if isinstance(prompt, str):
+            prompt = str_to_bytes(prompt)
+        elif (isinstance(prompt, type(re.compile(''))) and
+                isinstance(prompt.pattern, str)):
+            prompt = re.compile(str_to_bytes(prompt.pattern),
+                                prompt.flags & ~re.U)
         self._prompt = prompt
 
     def path(self):
@@ -445,9 +458,12 @@ If this all works, you can then make calls like:
                 logs = os.path.join(DOT_SAGE, 'pexpect_logs')
                 sage_makedirs(logs)
 
-                self.__logfilename = '%s/%s-%s-%s-%s.log'%(logs, self.name(), os.getpid(), id(self), self._session_number)
+                filename = '{name}-{pid}-{id}-{session}'.format(
+                        name=self.name(), pid=os.getpid(), id=id(self),
+                        session=self._session_number)
+                self.__logfilename = os.path.join(logs, filename)
             if self.__logfilename is not None:
-                self.__logfile = open(self.__logfilename, 'w')
+                self.__logfile = open(self.__logfilename, 'wb')
 
         cmd = self.__command
 
@@ -932,7 +948,7 @@ If this all works, you can then make calls like:
             if len(line)>0:
                 try:
                     if isinstance(wait_for_prompt, string_types):
-                        E.expect(wait_for_prompt)
+                        E.expect(str_to_bytes(wait_for_prompt))
                     else:
                         E.expect(self._prompt)
                 except pexpect.EOF as msg:
@@ -956,9 +972,9 @@ If this all works, you can then make calls like:
                             pass
                     raise RuntimeError("%s\n%s crashed executing %s"%(msg,self, line))
                 if self._terminal_echo:
-                    out = E.before
+                    out = self._before()
                 else:
-                    out = E.before.rstrip('\n\r')
+                    out = self._before().rstrip('\n\r')
             else:
                 if self._terminal_echo:
                     out = '\n\r'
@@ -1013,10 +1029,15 @@ If this all works, you can then make calls like:
     # BEGIN Synchronization code.
     ###########################################################################
 
-    def _before(self):
+    def _before(self, encoding=None, errors=None):
         r"""
         Return the previous string that was sent through the interface.
 
+        Returns ``str`` objects on both Python 2 and Python 3.
+
+        The ``encoding`` and ``errors`` arguments are passed to
+        :func:`sage.misc.cpython.bytes_to_str`.
+
         EXAMPLES::
 
             sage: singular('2+3')
@@ -1024,7 +1045,49 @@ If this all works, you can then make calls like:
             sage: singular._before()
             '5\r\n'
         """
-        return self._expect.before
+        return bytes_to_str(self._expect.before, encoding, errors)
+
+    def _after(self, encoding=None, errors=None):
+        r"""
+        Return trailing data in the buffer after the text matched by the expect
+        interface.
+
+        When the ``spawn.after`` attribute contains bytes, this returns ``str``
+        objects on both Python 2 and Python 3.  There are also cases (such as
+        exceptions) where the ``.after`` attribute contains either an exception
+        type or ``None``, in which case those values are returned.
+
+        The ``encoding`` and ``errors`` arguments are passed to
+        :func:`sage.misc.cpython.bytes_to_str`.
+
+        EXAMPLES::
+
+            sage: singular('2+3')
+            5
+            sage: singular._after()
+            '> '
+        """
+        after = self._expect.after
+        if isinstance(after, bytes):
+            return bytes_to_str(after, encoding, errors)
+
+        return after
+
+    def _readline(self, size=-1, encoding=None, errors=None):
+        r"""
+        Wraps ``spawn.readline`` to pass the return values through
+        ``bytes_to_str``, like `Expect._before` and `Expect._after`.
+
+        EXAMPLES::
+
+            sage: a = singular(1)
+            sage: singular._expect.sendline('1+1;')
+            5
+            sage: singular._readline()
+            '2\r\n'
+        """
+
+        return bytes_to_str(self._expect.readline(size=size), encoding, errors)
 
     def _interrupt(self):
         for i in range(15):
@@ -1123,7 +1186,7 @@ If this all works, you can then make calls like:
             else:
                 i = self._expect.expect(expr)
             if i > 0:
-                v = self._expect.before
+                v = self._before()
                 self.quit()
                 raise ValueError("%s\nComputation failed due to a bug in %s -- NOTE: Had to restart."%(v, self))
         except KeyboardInterrupt:
@@ -1157,7 +1220,7 @@ If this all works, you can then make calls like:
         if self._expect is None:
             self._start()
         try:
-            os.write(self._expect.child_fd, string)
+            os.write(self._expect.child_fd, str_to_bytes(string))
         except OSError:
             self._crash_msg()
             self.quit()
@@ -1221,8 +1284,8 @@ If this all works, you can then make calls like:
         self._sendstr(cmd)
         try:
             self._expect_expr(timeout=0.5)
-            if not s in self._expect.before:
-                self._expect_expr(s,timeout=0.5)
+            if not s in self._before():
+                self._expect_expr(s, timeout=0.5)
                 self._expect_expr(timeout=0.5)
         except pexpect.TIMEOUT:
             self._interrupt()
@@ -1379,7 +1442,7 @@ class ExpectElement(InterfaceElement):
             # coercion to work properly.
             except (RuntimeError, ValueError) as x:
                 self._session_number = -1
-                raise_(TypeError, x, sys.exc_info()[2])
+                raise_(TypeError, TypeError(*x.args), sys.exc_info()[2])
             except BaseException:
                 self._session_number = -1
                 raise
@@ -1415,7 +1478,7 @@ class ExpectElement(InterfaceElement):
         except ValueError:
             return
         try:
-            if hasattr(self,'_name'):
+            if hasattr(self, '_name'):
                 P = self.parent()
                 if P is not None:
                     P.clear(self._name)
@@ -1471,10 +1534,16 @@ class StdOutContext:
         if self.interface._expect is None:
             self.interface._start()
         self._logfile_backup = self.interface._expect.logfile
-        if self.interface._expect.logfile:
-            self.interface._expect.logfile = Multiplex(self.interface._expect.logfile, self.stdout)
+
+        if isinstance(sys.stdout, io.TextIOWrapper):
+            stdout = sys.stdout.buffer
         else:
-            self.interface._expect.logfile = Multiplex(self.stdout)
+            stdout = sys.stdout
+
+        if self.interface._expect.logfile:
+            self.interface._expect.logfile = Multiplex(self.interface._expect.logfile, stdout)
+        else:
+            self.interface._expect.logfile = Multiplex(stdout)
         return self.interface
 
     def __exit__(self, typ, value, tb):
