@@ -175,6 +175,7 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 from __future__ import absolute_import, print_function
+import six
 from six import string_types
 
 from .expect import Expect, ExpectElement, FunctionElement, ExpectFunction
@@ -182,7 +183,6 @@ from .gap_workspace import gap_workspace_file, prepare_workspace_dir
 from sage.cpython.string import bytes_to_str
 from sage.env import SAGE_LOCAL, SAGE_EXTCODE
 from sage.misc.misc import is_in_string
-from sage.misc.superseded import deprecation
 from sage.misc.cachefunc import cached_method
 from sage.docs.instancedoc import instancedoc
 from sage.interfaces.tab_completion import ExtraTabCompletion
@@ -596,9 +596,9 @@ class Gap_generic(ExtraTabCompletion, Expect):
         except OSError:
             raise RuntimeError("Error evaluating %s in %s"%(line, self))
         if not wait_for_prompt:
-            return ('','')
+            return (b'',b'')
         if len(line)==0:
-            return ('','')
+            return (b'',b'')
         try:
             terminal_echo = []   # to be discarded
             normal_outputs = []  # GAP stdout
@@ -608,13 +608,18 @@ class Gap_generic(ExtraTabCompletion, Expect):
                 x = E.expect_list(self._compiled_full_pattern)
                 current_outputs.append(E.before)
                 if x == 0:   # @p
-                    if E.after != '@p1.':
+                    if E.after != b'@p1.':
                         print("Warning: possibly wrong version of GAP package interface\n")
                         print("Crossing fingers and continuing\n")
                 elif x == 1: #@@
-                    current_outputs.append('@')
+                    current_outputs.append(b'@')
                 elif x == 2: #special char
-                    current_outputs.append(chr(ord(E.after[1:2])-ord('A')+1))
+                    c = ord(E.after[1:2]) - ord(b'A') + 1
+                    if six.PY2:
+                        s = chr(c)
+                    else:
+                        s = bytes([c])
+                    current_outputs.append(s)
                 elif x == 3: # garbage collection info, ignore
                     pass
                 elif x == 4: # @e -- break loop
@@ -646,7 +651,7 @@ class Gap_generic(ExtraTabCompletion, Expect):
                 raise RuntimeError("Unexpected EOF from %s executing %s"%(self,line))
         except IOError:
             raise RuntimeError("IO Error from %s executing %s"%(self,line))
-        return ("".join(normal_outputs),"".join(error_outputs))
+        return (b"".join(normal_outputs), b"".join(error_outputs))
 
     def _keyboard_interrupt(self):
         """
@@ -742,6 +747,12 @@ class Gap_generic(ExtraTabCompletion, Expect):
             (normal, error) = self._execute_line(line, wait_for_prompt=wait_for_prompt,
                                                  expect_eof= (self._quit_string() in line))
 
+            # The internal method _execute_line returns bytes but the bytes it
+            # returns should contain text (any terminal commands and other
+            # garbage should be filtered out by this point); here we decode
+            # them (on Python 3), currently just using the default encoding
+            normal, error = bytes_to_str(normal), bytes_to_str(error)
+
             if len(error):
                 if 'Error, Rebuild completion files!' in error:
                     error += "\nRunning gap_reset_workspace()..."
@@ -865,7 +876,7 @@ class Gap_generic(ExtraTabCompletion, Expect):
         EXAMPLES::
 
             sage: print(gap.version())
-            4.8...
+            4...
         """
         return self.eval('VERSION')[1:-1]
 
@@ -1355,13 +1366,14 @@ class Gap(Gap_generic):
             (sline,) = match.groups()
             if self.is_remote():
                 self._get_tmpfile()
-            F = io.open(self._local_tmpfile(), "r", encoding=gap_encoding)
-            help = F.read()
-            if pager:
-                from IPython.core.page import page
-                page(help, start = int(sline)-1)
-            else:
-                return help
+            with io.open(self._local_tmpfile(), "r",
+                         encoding=gap_encoding) as fobj:
+                help = fobj.read()
+                if pager:
+                    from IPython.core.page import page
+                    page(help, start=int(sline) - 1)
+                else:
+                    return help
 
     def set(self, var, value):
         """
@@ -1827,11 +1839,15 @@ def gap_console():
 
     TESTS::
 
-        sage: import subprocess
+        sage: import subprocess as sp
         sage: from sage.interfaces.gap import gap_command
         sage: cmd = 'echo "quit;" | ' + gap_command(use_workspace_cache=False)[0]
-        sage: gap_startup = subprocess.check_output(cmd, shell=True, stderr=subprocess.STDOUT)
-        sage: 'http://www.gap-system.org' in gap_startup
+        sage: gap_startup = sp.check_output(cmd, shell=True,  # py2
+        ....:                               stderr=sp.STDOUT)
+        sage: gap_startup = sp.check_output(cmd, shell=True,  # py3
+        ....:                               stderr=sp.STDOUT,
+        ....:                               encoding='latin1')
+        sage: 'www.gap-system.org' in gap_startup
         True
         sage: 'Error' not in gap_startup
         True
