@@ -953,7 +953,7 @@ class MathematicaElement(ExpectElement):
     def str(self):
         return str(self)
 
-    def __cmp__(self, other):
+    def _cmp_(self, other):
         #if not (isinstance(other, ExpectElement) and other.parent() is self.parent()):
         #    return coerce.cmp(self, other)
         P = self.parent()
