@@ -8,16 +8,19 @@ workspaces.
 
 import os
 import glob
+from sage.env import GAP_ROOT_DIR
+from sage.interfaces.gap import GAP_BINARY
 from sage.interfaces.gap_workspace import gap_workspace_file
 
 
 def timestamp():
     """
-    Return a time stamp for libgap
+    Return a time stamp for (lib)gap
 
     OUTPUT:
 
-    Float. Unix timestamp of the most recently changed LibGAP file.
+    Float. Unix timestamp of the most recently changed GAP/LibGAP file(s). In particular, the
+    timestamp increases whenever a gap package is added.
 
     EXAMPLES::
 
@@ -28,7 +31,9 @@ def timestamp():
         <... 'float'>
     """
     libgap_dir = os.path.dirname(__file__)
-    files = glob.glob(os.path.join(libgap_dir, '*'))
+    libgap_files = glob.glob(os.path.join(libgap_dir, '*'))
+    gap_packages = glob.glob(os.path.join(GAP_ROOT_DIR, 'pkg', '*'))
+    files = libgap_files + [GAP_BINARY] + gap_packages
     if len(files) == 0:
         print('Unable to find LibGAP files.')
         return float('inf')
