@@ -1186,8 +1186,8 @@ class AffineConnection(SageObject):
         if index_labels is None and isinstance(frame, CoordFrame) and \
           coordinate_labels:
             ch = frame.chart()
-            index_labels = map(str, ch[:])
-            index_latex_labels = map(latex, ch[:])
+            index_labels = [str(z) for z in ch[:]]
+            index_latex_labels = [latex(z) for z in ch[:]]
         return self.coef(frame=frame).display(symbol,
               latex_symbol=latex_symbol, index_positions='udd',
               index_labels=index_labels, index_latex_labels=index_latex_labels,
