@@ -253,16 +253,19 @@ class MultivectorModule(UniqueRepresentation, Parent):
         name = "A^{}(".format(degree) + domain._name
         latex_name = r"A^{{{}}}\left({}".format(degree,
                                                 domain._latex_name)
-        if dest_map is domain.identity_map():
-            name += ")"
-            latex_name += r"\right)"
-        else:
-            name += "," + dest_map._name + ")"
-            latex_name += "," + dest_map._latex_name + r"\right)"
+        if dest_map is not domain.identity_map():
+            dm_name = dest_map._name
+            dm_latex_name = dest_map._latex_name
+            if dm_name is None:
+                dm_name = "unnamed map"
+            if dm_latex_name is None:
+                dm_latex_name = r"\mathrm{unnamed\; map}"
+            name += "," + dm_name
+            latex_name += "," + dm_latex_name
+        self._name = name + ")"
+        self._latex_name = latex_name + r"\right)"
         self._vmodule = vector_field_module
         self._degree = degree
-        self._name = name
-        self._latex_name = latex_name
         # the member self._ring is created for efficiency (to avoid
         # calls to self.base_ring()):
         self._ring = domain.scalar_field_algebra()
@@ -683,12 +686,17 @@ class MultivectorFreeModule(ExtPowerFreeModule):
         name = "A^{}(".format(degree) + domain._name
         latex_name = r"A^{{{}}}\left({}".format(degree,
                                                 domain._latex_name)
-        if dest_map is domain.identity_map():
-            name += ")"
-            latex_name += r"\right)"
-        else:
-            name += "," + dest_map._name + ")"
-            latex_name += "," + dest_map._latex_name + r"\right)"
+        if dest_map is not domain.identity_map():
+            dm_name = dest_map._name
+            dm_latex_name = dest_map._latex_name
+            if dm_name is None:
+                dm_name = "unnamed map"
+            if dm_latex_name is None:
+                dm_latex_name = r"\mathrm{unnamed\; map}"
+            name += "," + dm_name
+            latex_name += "," + dm_latex_name
+        name += ")"
+        latex_name += r"\right)"
         ExtPowerFreeModule.__init__(self, vector_field_module, degree,
                                     name=name, latex_name=latex_name)
         self._domain = domain
