@@ -1218,6 +1218,29 @@ class VectorFieldFreeModule(FiniteRankFreeModule):
 
         sage: TestSuite(XIM).run()
 
+    Let us introduce an open subset of `J\subset I` and the vector field module
+    corresponding to the restriction of `\Phi` to it::
+
+        sage: J = I.open_subset('J', coord_def= {canon: t<pi})
+        sage: XJM = J.vector_field_module(dest_map=Phi.restrict(J)); XJM
+        Free module X(J,Phi) of vector fields along the Open subset J of the
+         1-dimensional differentiable manifold I mapped into the 2-dimensional
+         differentiable manifold R^2
+
+    We have then::
+
+        sage: XJM.default_basis()
+        Vector frame (J, (d/dx,d/dy)) with values on the 2-dimensional
+         differentiable manifold R^2
+        sage: XJM.default_basis() is XIM.default_basis().restrict(J)
+        True
+        sage: v.restrict(J)
+        Vector field along the Open subset J of the 1-dimensional
+         differentiable manifold I with values on the 2-dimensional
+         differentiable manifold R^2
+        sage: v.restrict(J).display()
+        t d/dx + t^2 d/dy
+
     Let us now consider the module of vector fields on the circle `S^1`; we
     start by constructing the `S^1` manifold::
 
@@ -1362,8 +1385,33 @@ class VectorFieldFreeModule(FiniteRankFreeModule):
         self._induced_bases = {}
         if self._dest_map != self._domain.identity_map():
             for frame in self._ambient_domain._top_frames:
-                basis = self.basis(from_frame=frame)
-                self._induced_bases[frame] = basis
+                if (frame.destination_map() ==
+                    self._ambient_domain.identity_map()):
+                    basis = self.basis(from_frame=frame)
+                    self._induced_bases[frame] = basis
+
+                    # basis is added to the restrictions of bases on a larger
+                    # domain
+                    for dom in domain._supersets:
+                        if dom is not domain:
+                            for supbase in dom._frames:
+                                if (supbase.domain() is dom and
+                                        supbase.destination_map().restrict(domain)
+                                        is self._dest_map and
+                                        domain not in supbase._restrictions):
+                                    supbase._restrictions[domain] = basis
+                                    supbase._subframes.add(basis)
+                                    basis._superframes.add(supbase)
+
+                    # basis is added as a superframe of smaller domain
+                    for superframe in basis._superframes:
+                        for subframe in superframe._subframes:
+                            if subframe.domain() is not domain and subframe.domain().is_subset(
+                                    self._domain) and self._dest_map.restrict(
+                                    subframe.domain()) is subframe.destination_map():
+                                subframe._superframes.update(basis._superframes)
+                                basis._subframes.update(subframe._subframes)
+                                basis._restrictions.update(subframe._restrictions)
 
         # Initialization of the components of the zero element:
         zero = self.zero()
