@@ -47,7 +47,6 @@ from sage.env import SAGE_ROOT, SAGE_PKGS
 
 import json
 import os
-import re
 import subprocess
 try:
     # Python 3.3+
@@ -319,6 +318,15 @@ def is_package_installed(package, exclude_pip=True):
         sage: from sage.misc.package import list_packages
         sage: for pkg in list_packages('pip', local=True):
         ....:     assert not is_package_installed(pkg)
+
+    .. NOTE::
+
+        Do not use this function to check whether you can use a feature from an
+        external library. This only checks whether something was installed with
+        ``sage -i`` but it may have been installed by other means (for example
+        if this copy of Sage has been installed as part of a distribution.)
+        Use the framework provided by :mod:`sage.features` to check
+        whether a library is installed and functional.
     """
     return any(p.split('-')[0] == package for p in installed_packages(exclude_pip))
 
@@ -349,7 +357,7 @@ def package_versions(package_type, local=False):
         sage: std = package_versions('standard', local=True)
         sage: 'gap' in std
         True
-        sage: std['zn_poly']
+        sage: std['zn_poly'] # random
         ('0.9.p11', '0.9.p11')
     """
     return {pkg['name']: (pkg['installed_version'], pkg['remote_version']) for pkg in list_packages(package_type, local=local).values()}
