@@ -27,7 +27,7 @@ from sage.misc.lazy_import import lazy_import
 lazy_import('sage.modular.arithgroup.congroup_sl2z', 'SL2Z')
 from sage.structure.element import parent
 
-from .arithgroup_element import ArithmeticSubgroupElement
+from .arithgroup_element import ArithmeticSubgroupElement, M2Z as Mat2Z
 
 def is_ArithmeticSubgroup(x):
     r"""
@@ -196,12 +196,8 @@ class ArithmeticSubgroup(Group):
 
         EXAMPLES::
 
-            sage: Gamma0(11).__hash__()
-            118770652 # 32-bit
-            3713075136762760156 # 64-bit
-            sage: Gamma1(11).__hash__()
-            201042552 # 32-bit
-            3713075136845032056 # 64-bit
+            sage: h = hash(Gamma0(11))
+            sage: h = hash(Gamma1(11))
 
         TESTS:
 
@@ -213,14 +209,25 @@ class ArithmeticSubgroup(Group):
             Congruence Subgroup Gamma_H(37) with H generated by [4, 7]
             sage: G1 == G2
             True
-            sage: G1.__hash__() == G2.__hash__()
+            sage: hash(G1) == hash(G2)
             True
             sage: set([G1,G2])
             {Congruence Subgroup Gamma_H(37) with H generated by [4]}
-
         """
         return hash((self.level(), self.index()))
 
+    def matrix_space(self):
+        """
+        Return the parent space of the matrices, which is always
+        ``MatrixSpace(ZZ, 2)``.
+
+        EXAMPLES::
+
+            sage: Gamma(3).matrix_space()
+            Full MatrixSpace of 2 by 2 dense matrices over Integer Ring
+        """
+        return Mat2Z
+
     def is_parent_of(self, x):
         r"""
         Check whether this group is a valid parent for the element x. Required
