@@ -66,14 +66,15 @@ from sage.arith.misc import divisors, gcd, euler_phi, moebius, is_prime
 from sage.arith.misc import gauss_sum, kronecker_symbol
 from sage.combinat.integer_vector_weighted import WeightedIntegerVectors
 from sage.functions.generalized import sgn
-from sage.functions.other import floor
+from sage.functions.log import log
+from sage.functions.other import floor, ceil
 from sage.misc.cachefunc import cached_method
 from sage.misc.functional import cyclotomic_polynomial
 from sage.misc.misc_c import prod
 from sage.rings.fraction_field import FractionField
 from sage.rings.finite_rings.integer_mod_ring import IntegerModRing
 from sage.rings.integer_ring import ZZ
-from sage.rings.padics.factory import Zp
+from sage.rings.padics.factory import Qp
 from sage.rings.padics.misc import gauss_sum as padic_gauss_sum
 from sage.rings.polynomial.polynomial_ring import polygen
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
@@ -928,7 +929,7 @@ class HypergeometricData(object):
                    for a in set(alpha))
 
     @cached_method
-    def padic_H_value(self, p, f, t, prec=20):
+    def padic_H_value(self, p, f, t, prec=None):
         """
         Return the `p`-adic trace of Frobenius, computed using the
         Gross-Koblitz formula.
@@ -977,27 +978,36 @@ class HypergeometricData(object):
         beta = self._beta
         if 0 in alpha:
             H = self.swap_alpha_beta()
-            return(H.padic_H_value(p, f, ~t, prec))
+            return H.padic_H_value(p, f, ~t, prec)
         t = QQ(t)
         gamma = self.gamma_array()
         q = p ** f
 
-        m = {r: beta.count(QQ((r, q - 1))) for r in range(q - 1)}
+#        m = {r: beta.count(QQ((r, q - 1))) for r in range(q - 1)}
+        m = defaultdict(lambda: 0)
+        for r in range(q-1):
+            u = QQ((r, q-1))
+            if u in beta:
+                m[r] = beta.count(u)
         M = self.M_value()
         D = -min(self.zigzag(x, flip_beta=True) for x in alpha + beta)
         # also: D = (self.weight() + 1 - m[0]) // 2
 
-        gauss_table = [padic_gauss_sum(r, p, f, prec, factored=True) for r in range(q - 1)]
-
-        p_ring = Zp(p, prec=prec)
+        if prec is None:
+            prec = (self.weight()*f)//2 + ceil(log(self.degree(),p)) + 1
+        # For some reason, working in Qp instead of Zp is much faster;
+        # it appears to avoid some costly conversions.
+        p_ring = Qp(p, prec=prec)
         teich = p_ring.teichmuller(M / t)
-        sigma = sum(q**(D + m[0] - m[r]) *
-                    (-p)**(sum(gauss_table[(v * r) % (q - 1)][0] * gv
-                               for v, gv in gamma.items()) // (p - 1)) *
-                    prod(gauss_table[(v * r) % (q - 1)][1] ** gv
-                         for v, gv in gamma.items()) *
-                    teich ** r
-                    for r in range(q - 1))
+
+        gauss_table = [padic_gauss_sum(r, p, f, prec, factored=True, algorithm='sage', parent=p_ring)
+                       for r in range(q-1)]
+
+        sigma = sum( ((-p)**(sum(gauss_table[(v * r) % (q - 1)][0] * gv
+                                for v, gv in gamma.items()) // (p - 1)) * 
+                     prod(gauss_table[(v * r) % (q - 1)][1] ** gv
+                          for v, gv in gamma.items()) * teich ** r)
+                     << (f*(D+m[0]-m[r])) for r in range(q-1))
         resu = ZZ(-1) ** m[0] / (1 - q) * sigma
         return IntegerModRing(p**prec)(resu).lift_centered()
 
@@ -1062,7 +1072,7 @@ class HypergeometricData(object):
         beta = self._beta
         if 0 in alpha:
             H = self.swap_alpha_beta()
-            return(H.H_value(p, f, ~t, ring))
+            return H.H_value(p, f, ~t, ring)
         if ring is None:
             ring = UniversalCyclotomicField()
         t = QQ(t)
@@ -1096,8 +1106,42 @@ class HypergeometricData(object):
             resu = resu.real_part().round()
         return resu
 
+    def sign(self, t, p):
+        """
+        Return the sign of the functional equation for the Euler factor of the motive `H_t` at the prime `p`.
+
+        For odd weight, the sign of the functional equation is +1. For even
+        weight, the sign is computed by a recipe found in 11.1 of [Watkins]_.
+
+        EXAMPLES::
+
+            sage: from sage.modular.hypergeometric_motive import HypergeometricData as Hyp
+            sage: H = Hyp(cyclotomic=([6,2],[1,1,1]))
+            sage: H.weight(), H.degree()
+            (2, 3)
+            sage: [H.sign(1/4,p) for p in [5,7,11,13,17,19]]
+            [1, 1, -1, -1, 1, 1]
+
+            sage: H = Hyp(alpha_beta=([1/12,5/12,7/12,11/12],[0,1/2,1/2,1/2]))
+            sage: H.weight(), H.degree()
+            (2, 4)
+            sage: t = -5
+            sage: [H.sign(1/t,p) for p in [11,13,17,19,23,29]]
+            [-1, -1, -1, 1, 1, 1]
+        """
+        d = self.degree()
+        w = self.weight()
+
+        if w % 2:  # sign is always +1 for odd weight
+            sign = 1
+        elif d % 2:
+            sign = -kronecker_symbol((1 - t) * self._sign_param, p)
+        else:
+            sign = kronecker_symbol(t * (t - 1) * self._sign_param, p)
+        return sign
+    
     @cached_method
-    def euler_factor(self, t, p, degree=0):
+    def euler_factor(self, t, p):
         """
         Return the Euler factor of the motive `H_t` at prime `p`.
 
@@ -1107,8 +1151,6 @@ class HypergeometricData(object):
 
         - `p` -- prime number of good reduction
 
-        - ``degree`` -- optional integer (default 0)
-
         OUTPUT:
 
         a polynomial
@@ -1180,7 +1222,7 @@ class HypergeometricData(object):
         alpha = self._alpha
         if 0 in alpha:
             H = self.swap_alpha_beta()
-            return(H.euler_factor(~t, p, degree))
+            return H.euler_factor(~t, p)
 
         if t not in QQ or t in [0, 1]:
             raise ValueError('wrong t')
@@ -1191,20 +1233,12 @@ class HypergeometricData(object):
         if (t.valuation(p) or (t - 1).valuation(p) > 0):
             raise NotImplementedError('p is tame')
         # now p is good
-        if degree == 0:
-            d = self.degree()
+        d = self.degree()
         bound = d // 2
         traces = [self.padic_H_value(p, i + 1, t) for i in range(bound)]
 
         w = self.weight()
-
-        if w % 2:  # sign is always +1 for odd weight
-            sign = 1
-        elif d % 2:
-            sign = -kronecker_symbol((1 - t) * self._sign_param, p)
-        else:
-            sign = kronecker_symbol(t * (t - 1) * self._sign_param, p)
-
+        sign = self.sign(t, p)
         return characteristic_polynomial_from_traces(traces, d, p, w, sign)
 
     def canonical_scheme(self, t=None):
