@@ -157,6 +157,7 @@ def ModularForms_clear_cache():
 def ModularForms(group  = 1,
                  weight = 2,
                  base_ring = None,
+                 eis_only=False,
                  use_cache = True,
                  prec = defaults.DEFAULT_PRECISION):
     r"""
@@ -277,16 +278,12 @@ def ModularForms(group  = 1,
     forms; but we can still work with the Eisenstein series.
 
         sage: M = ModularForms(Gamma1(57), 1); M
-        Modular Forms space of dimension (unknown) for Congruence Subgroup Gamma1(57) of weight 1 over Rational Field
-        sage: M.basis()
-        <repr(<sage.structure.sequence.Sequence_generic at 0x...>) failed: NotImplementedError: Computation of dimensions of weight 1 cusp forms spaces not implemented in general>
-        sage: M.cuspidal_subspace().basis()
         Traceback (most recent call last):
         ...
         NotImplementedError: Computation of dimensions of weight 1 cusp forms spaces not implemented in general
 
-        sage: E = M.eisenstein_subspace(); E
-        Eisenstein subspace of dimension 36 of Modular Forms space of dimension (unknown) for Congruence Subgroup Gamma1(57) of weight 1 over Rational Field
+        sage: E = EisensteinForms(Gamma1(57), 1); E
+        Eisenstein subspace of dimension 36 of Modular Forms space for Congruence Subgroup Gamma1(57) of weight 1 over Rational Field
         sage: (E.0 + E.2).q_expansion(40)
         1 + q^2 + 1473/2*q^36 - 1101/2*q^37 + q^38 - 373/2*q^39 + O(q^40)
 
@@ -303,7 +300,7 @@ def ModularForms(group  = 1,
     else:
         level = group
 
-    key = canonical_parameters(group, level, weight, base_ring)
+    key = canonical_parameters(group, level, weight, base_ring) + (eis_only,)
 
     if use_cache and key in _cache:
          M = _cache[key]()
@@ -311,7 +308,7 @@ def ModularForms(group  = 1,
              M.set_precision(prec)
              return M
 
-    (level, group, weight, base_ring) = key
+    (level, group, weight, base_ring, eis_only) = key
 
     M = None
     if arithgroup.is_Gamma0(group):
@@ -320,12 +317,12 @@ def ModularForms(group  = 1,
             M = ambient_R.ModularFormsAmbient_R(M, base_ring)
 
     elif arithgroup.is_Gamma1(group):
-        M = ModularFormsAmbient_g1_Q(group.level(), weight)
+        M = ModularFormsAmbient_g1_Q(group.level(), weight, eis_only)
         if base_ring != rings.QQ:
             M = ambient_R.ModularFormsAmbient_R(M, base_ring)
 
     elif arithgroup.is_GammaH(group):
-        M = ModularFormsAmbient_gH_Q(group, weight)
+        M = ModularFormsAmbient_gH_Q(group, weight, eis_only)
         if base_ring != rings.QQ:
             M = ambient_R.ModularFormsAmbient_R(M, base_ring)
 
@@ -341,7 +338,7 @@ def ModularForms(group  = 1,
             return ModularForms(eps.modulus(), weight, base_ring,
                                 use_cache = use_cache,
                                 prec = prec)
-        M = ModularFormsAmbient_eps(eps, weight)
+        M = ModularFormsAmbient_eps(eps, weight, eis_only=eis_only)
         if base_ring != eps.base_ring():
             M = M.base_extend(base_ring) # ambient_R.ModularFormsAmbient_R(M, base_ring)
 
@@ -389,7 +386,11 @@ def EisensteinForms(group  = 1,
         sage: EisensteinForms(11,2)
         Eisenstein subspace of dimension 1 of Modular Forms space of dimension 2 for Congruence Subgroup Gamma0(11) of weight 2 over Rational Field
     """
-    return ModularForms(group, weight, base_ring,
+    if weight==1:
+        return ModularForms(group, weight, base_ring,
+                        use_cache=use_cache, eis_only=True, prec=prec).eisenstein_submodule()
+    else:    
+        return ModularForms(group, weight, base_ring,
                         use_cache=use_cache, prec=prec).eisenstein_submodule()
 
 
