@@ -17,9 +17,8 @@ from six import integer_types
 from sage.misc.all import verbose, cputime
 import sage.modular.dirichlet as dirichlet
 from sage.modular.arithgroup.congroup_gammaH import GammaH_class
-from sage.rings.all import Integer, CyclotomicField, ZZ, QQ, Integer
+from sage.rings.all import Integer, CyclotomicField, ZZ, QQ
 from sage.arith.all import bernoulli, divisors, is_squarefree, lcm
-from sage.rings.finite_rings.finite_field_constructor import is_FiniteField
 from sage.rings.power_series_ring import PowerSeriesRing
 from .eis_series_cython import eisenstein_series_poly, Ek_ZZ
 
@@ -256,7 +255,6 @@ def __find_eisen_chars(character, k):
     #
     # See [Miyake, Modular Forms] Lemma 7.1.1.
 
-    K = G.base_ring()
     C = {}
 
     t0 = cputime()
@@ -418,8 +416,6 @@ def eisenstein_series_lseries(weight, prec=53,
     """
     f = eisenstein_series_qexp(weight,prec)
     from sage.lfunctions.all import Dokchitser
-    from sage.symbolic.constants import pi
-    key = (prec, max_imaginary_part, max_asymp_coeffs)
     j = weight
     L = Dokchitser(conductor = 1,
                    gammaV = [0,1],
