@@ -13,17 +13,17 @@ Numerical computation of newforms
 #*****************************************************************************
 from six import integer_types
 
+from sage.arith.all              import prime_range
+from sage.matrix.constructor     import matrix
+from sage.misc.misc              import verbose
+from sage.misc.prandom           import randint
+from sage.modular.arithgroup.all import Gamma0
+from sage.modular.modsym.all     import ModularSymbols
+from sage.modules.all            import vector
+from sage.rings.all              import CDF, Integer, QQ
+from sage.structure.richcmp      import richcmp_method, richcmp
 from sage.structure.sage_object  import SageObject
 from sage.structure.sequence     import Sequence
-from sage.structure.richcmp import richcmp_method, richcmp
-from sage.modular.modsym.all     import ModularSymbols
-from sage.modular.arithgroup.all import Gamma0
-from sage.modules.all            import vector
-from sage.misc.misc              import verbose
-from sage.rings.all import CDF, Integer, QQ
-from sage.arith.all import next_prime, prime_range
-from sage.misc.prandom           import randint
-from sage.matrix.constructor     import matrix
 
 # This variable controls importing the SciPy library sparingly
 scipy=None
@@ -224,7 +224,6 @@ class NumericalEigenforms(SageObject):
             pass
         verbose('Finding eigenvector basis')
         M = self.modular_symbols()
-        N = self.level()
 
         tp = self._tp
         p = tp[0]
