@@ -13,7 +13,8 @@ We represent boundary modular symbols as a sum of Manin symbols of the form
 modular symbols naturally embeds into a vector space `B_k(G)` (see Stein,
 section 8.4, or Merel, section 1.4, where this space is called `\CC[\Gamma
 \backslash \QQ]_k`, for a definition), which is a finite dimensional `\QQ`
-vector space of dimension equal to the number of cusps for `G`. The embedding
+vector space, of dimension equal to the number of cusps for `G` (if `k` is
+even), or the number of regular cusps (if `k` is odd). The embedding
 takes `[P, u/v]` to `P(u,v)\cdot [(u,v)]`. We represent the basis vectors by
 pairs `[(u,v)]` with u, v coprime. On `B_k(G)`, we have the relations
 
@@ -104,8 +105,6 @@ import sage.modular.hecke.all as hecke
 from sage.modular.modsym.manin_symbol import ManinSymbol
 
 import sage.rings.all as rings
-import sage.arith.all as arith
-
 
 from . import element
 
@@ -175,8 +174,7 @@ class BoundarySpaceElement(hecke.HeckeModuleElement):
             sage: (-6*ModularSymbols(Gamma0(11), 2).boundary_space()(Cusp(0)))._repr_()
             '-6*[0]'
         """
-        g = self.parent()._known_gens_repr
-        return repr_lincomb([ (g[i], c) for i,c in self.__x.items() ])
+        return repr_lincomb([ ('[' + repr(self.parent()._known_gens[i]) + ']', c) for i,c in self.__x.items() ])
 
     # can't inherit arithmetic operations from HeckeModule, because basis
     # dimension might change!
@@ -327,8 +325,7 @@ class BoundarySpace(hecke.HeckeModule_generic):
           self.__sign, self.__base_ring) = (group, weight,
                                              character, sign, base_ring)
         self._known_gens = []
-        self._known_gens_repr = []
-        self._is_zero = []
+        self._zero_cusps = []
         hecke.HeckeModule_generic.__init__(self, base_ring, group.level())
 
     def __richcmp__(self, other, op):
@@ -351,7 +348,7 @@ class BoundarySpace(hecke.HeckeModule_generic):
 
     def _known_cusps(self):
         """
-        Return the list of cusps found so far.
+        Return the list of non-vanishing cusps found so far.
 
         EXAMPLES::
 
@@ -446,23 +443,6 @@ class BoundarySpace(hecke.HeckeModule_generic):
             raise ValueError("only %s generators known for %s"%(len(self._known_gens), self))
         return BoundarySpaceElement(self, {i:1})
 
-    def __len__(self):
-        """
-        Return the length of self, i.e. the dimension of the underlying
-        vector space.
-
-        EXAMPLES::
-
-            sage: B = ModularSymbols(Gamma0(36),4,sign=1).boundary_space()
-            sage: B.__len__()
-            0
-            sage: len(B)
-            0
-            sage: x = B(Cusp(0)) ; y = B(Cusp(oo)) ; len(B)
-            2
-        """
-        return len(self._known_gens)
-
     def free_module(self):
         """
         Return the underlying free module for self.
@@ -473,7 +453,7 @@ class BoundarySpace(hecke.HeckeModule_generic):
             sage: B.free_module()
             Sparse vector space of dimension 0 over Rational Field
             sage: x = B(Cusp(0)) ; y = B(Cusp(1/7)) ; B.free_module()
-            Sparse vector space of dimension 2 over Rational Field
+            Sparse vector space of dimension 1 over Rational Field
         """
         return free_module.FreeModule(self.__base_ring, len(self._known_gens), sparse=True)
 
@@ -496,6 +476,15 @@ class BoundarySpace(hecke.HeckeModule_generic):
             sage: _ = [ B(x) for x in M.basis() ]
             sage: B.rank()
             16
+
+        Test that :trac:`7837` is fixed::
+
+            sage: ModularSymbols(Gamma1(4),7).boundary_map().codomain().dimension()
+            2
+            sage: ModularSymbols(Gamma1(4),7, sign=1).boundary_map().codomain().dimension()
+            1
+            sage: ModularSymbols(Gamma1(4),7, sign=-1).boundary_map().codomain().dimension()
+            1
         """
         return len(self._known_gens)
 
@@ -596,9 +585,14 @@ class BoundarySpace(hecke.HeckeModule_generic):
 
     def _cusp_index(self, cusp):
         """
-        Return the index of the first cusp in self._known_cusps()
-        equivalent to cusp, or -1 if cusp is not equivalent to any cusp
-        found so far.
+        Return the index of the (unique) cusp in self._known_cusps()
+        equivalent to cusp, or one of the following special values:
+
+        - ``-1`` if ``cusp`` is not equivalent to any cusp
+          found so far.
+        - ``-2`` if ``cusp`` is equivalent to a cusp that's known to vanish
+          from the relations in this space.
+
 
         EXAMPLES::
 
@@ -611,10 +605,11 @@ class BoundarySpace(hecke.HeckeModule_generic):
             1
         """
         g = self._known_gens
-        N = self.level()
         for i in range(len(g)):
             if self._is_equiv(cusp, g[i]):
                 return i
+        if any(self._is_equiv(cusp, x) for x in self._zero_cusps):
+            return -2
         return -1
 
 class BoundarySpace_wtk_g0(BoundarySpace):
@@ -693,12 +688,11 @@ class BoundarySpace_wtk_g0(BoundarySpace):
         """
         if self.weight()%2 != 0:
             return self(0)
-        N = self.level()
 
         # see if we've already found this cusp
         i = self._cusp_index(c)
         if i != -1:
-            if i in self._is_zero:
+            if i == -2:
                 return self(0)
             return BoundarySpaceElement(self, {i:1})
 
@@ -707,14 +701,14 @@ class BoundarySpace_wtk_g0(BoundarySpace):
         if sign != 0:
             i2 = self._cusp_index(-c)
             if i2 != -1:
-                if i2 in self._is_zero:
+                if i2 == -2:
                     return self(0)
-                return BoundarySpaceElement(self, {i2:sign})
+                else:
+                    return BoundarySpaceElement(self, {i2:sign})
 
         # found a new cusp class
         g = self._known_gens
         g.append(c)
-        self._known_gens_repr.append("[%s]"%c)
 
         # See if the new cusp is killed by sign relations. The
         # relevant relations (for cusps other than 0 and Infinity)
@@ -742,7 +736,8 @@ class BoundarySpace_wtk_g0(BoundarySpace):
             # (It's important to recall that for Gamma0, odd weight
             # spaces are 0.)
             if self._is_equiv(c, -c):
-                self._is_zero.append(len(g)-1)
+                self._zero_cusps.append(c)
+                del self._known_gens[-1]
                 return self(0)
 
         return BoundarySpaceElement(self, {(len(g)-1):1})
@@ -836,7 +831,8 @@ class BoundarySpace_wtk_g1(BoundarySpace):
         self._known_cusps() which is equivalent to cusp, and t is 1 or -1
         as cusp is Gamma1-equivalent to plus or minus
         self._known_cusps()[i]. If cusp is not equivalent to any known
-        cusp, return (-1, 0).
+        cusp, return (-1, 0); if cusp is equivalent to a cusp that is known to
+        vanish, return (-2, 0).
 
         EXAMPLES::
 
@@ -853,11 +849,12 @@ class BoundarySpace_wtk_g1(BoundarySpace):
             (0, -1)
         """
         g = self._known_gens
-        N = self.level()
         for i in range(len(g)):
             t, eps = self._is_equiv(cusp, g[i])
             if t:
                 return i, eps
+        if any(self._is_equiv(cusp, c)[0] for c in self._zero_cusps):
+            return (-2, 0)
         return -1, 0
 
     def _coerce_cusp(self, c):
@@ -904,14 +901,15 @@ class BoundarySpace_wtk_g1(BoundarySpace):
         sign = self.sign()
         i, eps = self._cusp_index(c)
         if i != -1:
-            if i in self._is_zero:
+            if i == -2:
                 return self(0)
-            return BoundarySpaceElement(self, {i : eps**k})
+            else:
+                return BoundarySpaceElement(self, {i : eps**k})
 
         if sign != 0:
             i2, eps = self._cusp_index(-c)
             if i2 != -1:
-                if i2 in self._is_zero:
+                if i2 == -2:
                     return self(0)
                 else:
                     return BoundarySpaceElement(self, {i2:sign*(eps**k)})
@@ -919,16 +917,15 @@ class BoundarySpace_wtk_g1(BoundarySpace):
         # found a new cusp class
         g = self._known_gens
         g.append(c)
-        self._known_gens_repr.append("[%s]"%c)
 
-        # Does cusp class vanish because of - relations? (See note at top
-        # of file.)
-        if k % 2 != 0:
-            (u, v) = (c.numerator(), c.denominator())
-            if (2*v) % N == 0:
-                if (2*u) % v.gcd(N) == 0:
-                    self._is_zero.append(len(g)-1)
-                    return self(0)
+        # Does cusp class vanish because of irregularity? For Gamma1 groups
+        # this occurs if and only if N = 4 and c is equivalent to 1/2.
+
+        if N == 4 and k % 2 != 0:
+            if self._is_equiv(c, (1,2))[0]:
+                self._zero_cusps.append(c)
+                del self._known_gens[-1]
+                return self(0)
 
         # Does class vanish because of sign relations?  The relevant
         # relations are
@@ -948,19 +945,17 @@ class BoundarySpace_wtk_g1(BoundarySpace):
         #    (-1)^k.
         #
         if sign:
-            if c.is_infinity():
-                if sign != (-1)**self.weight():
-                    self._is_zero.append(len(g)-1)
+            if (c.is_infinity() and sign != (-1)**self.weight()) or \
+                (c.is_zero() and sign== -1):
+                    self._zero_cusps.append(c)
+                    del self._known_gens[-1]
                     return self(0)
-            elif c.is_zero():
-                if (sign == -1):
-                    self._is_zero.append(len(g)-1)
-                    return self(0)
-            else:
+            elif (not c.is_infinity() and not c.is_zero()):
                 t, eps = self._is_equiv(c, -c)
                 if t and ((eps == 1 and sign == -1) or \
                           (eps == -1 and sign != (-1)**self.weight())):
-                    self._is_zero.append(len(g)-1)
+                    self._zero_cusps.append(c)
+                    del self._known_gens[-1]
                     return self(0)
 
         return BoundarySpaceElement(self, {(len(g)-1):1})
@@ -989,6 +984,17 @@ class BoundarySpace_wtk_gamma_h(BoundarySpace):
             Boundary Modular Symbols space for Congruence Subgroup Gamma_H(13) with H generated by [3] of weight 2 over Rational Field
             sage: B == loads(dumps(B))
             True
+
+        A test case from :trac:`6072`::
+
+            sage: ModularSymbols(GammaH(8,[5]), 3).boundary_map()
+            Hecke module morphism boundary map defined by the matrix
+            [-1  0  0  0]
+            [ 0 -1  0  0]
+            [ 0  0 -1  0]
+            [ 0  0  0 -1]
+            Domain: Modular Symbols space of dimension 4 for Congruence Subgroup ...
+            Codomain: Boundary Modular Symbols space for Congruence Subgroup Gamma_H(8) ...
         """
         sign = int(sign)
         if not sign in [-1,0,1]:
@@ -1034,10 +1040,10 @@ class BoundarySpace_wtk_gamma_h(BoundarySpace):
     def _cusp_index(self, cusp):
         """
         Returns a pair (i, t), where i is the index of the first cusp in
-        self._known_cusps() which is equivalent to cusp, and t is 1 or -1
-        as cusp is GammaH-equivalent to plus or minus
-        self._known_cusps()[i]. If cusp is not equivalent to any known
-        cusp, return (-1, 0).
+        self._known_cusps() which is equivalent to cusp, and t is 1 or -1 as
+        cusp is GammaH-equivalent to plus or minus self._known_cusps()[i]. If
+        cusp is not equivalent to any known cusp, return (-1, 0); if cusp is
+        equivalent to a cusp known to vanish, return (-2, 0).
 
         EXAMPLES::
 
@@ -1052,11 +1058,12 @@ class BoundarySpace_wtk_gamma_h(BoundarySpace):
             (3, 1)
         """
         g = self._known_gens
-        N = self.level()
         for i in range(len(g)):
             t, eps = self._is_equiv(cusp, g[i])
             if t:
                 return i, eps
+        if any(self._is_equiv(cusp, c)[0] for c in self._zero_cusps):
+            return -2, 0
         return -1, 0
 
     def _coerce_cusp(self, c):
@@ -1111,36 +1118,58 @@ class BoundarySpace_wtk_gamma_h(BoundarySpace):
             -[1/11],
             [1/11],
             -[1/11]]
+
+        Test that :trac:`6072` is fixed. ::
+
+            sage: G = GammaH(8,[3])
+
+            sage: B2 = G.modular_symbols(weight=2).boundary_space()
+            sage: B2._coerce_cusp(Cusp(1/4))
+            [1/4]
+
+            sage: B3 = G.modular_symbols(weight=3).boundary_space()
+            sage: B3._coerce_cusp(Cusp(1/4))
+            0
+
+            sage: G = GammaH(10, [9])
+            sage: B3 = G.modular_symbols(weight=3).boundary_space()
+            sage: [B3(x) for x in G.cusps()]
+            [0, 0, 0, 0, 0, 0, 0, 0]
+            sage: B3.rank()
+            0
+
+        Test that :trac:`25268` is fixed::
+
+            sage: G = GammaH(20, [13])
+            sage: A = ModularSymbols(G, 3)
+            sage: S = A.cuspidal_submodule()
+            sage: S.dimension()
+            8
         """
-        N    = self.level()
         k    = self.weight()
         sign = self.sign()
         i, eps = self._cusp_index(c)
         if i != -1:
-            if i in self._is_zero:
-                return self(0)
-            return BoundarySpaceElement(self, {i : eps**k})
+            if i == -2: return self(0)
+            else: return BoundarySpaceElement(self, {i : eps**k})
 
         if sign != 0:
             i2, eps = self._cusp_index(-c)
             if i2 != -1:
-                if i2 in self._is_zero:
-                    return self(0)
-                return BoundarySpaceElement(self, {i2:sign*(eps**k)})
+                if i2 == -2: return self(0)
+                else: return BoundarySpaceElement(self, {i2:sign*(eps**k)})
 
         # found a new cusp class
         g = self._known_gens
         g.append(c)
-        self._known_gens_repr.append("[%s]"%c)
 
-        # Does cusp class vanish because of - relations? (See note at top
-        # of file.)
+        # Does the cusp class vanish because the cusp is irregular?
+
         if k % 2 != 0:
-            (u, v) = (c.numerator(), c.denominator())
-            if (2*v) % N == 0:
-                if (2*u) % v.gcd(N) == 0:
-                    self._is_zero.append(len(g)-1)
-                    return self(0)
+            if self.group().is_even() or not self.group().is_regular_cusp(c):
+                self._zero_cusps.append(c)
+                del self._known_gens[-1]
+                return self(0)
 
         # Does class vanish because of sign relations?  The relevant
         # relations are
@@ -1165,19 +1194,17 @@ class BoundarySpace_wtk_gamma_h(BoundarySpace):
         # when H is larger than {1}.)
         #
         if sign:
-            if c.is_infinity():
-                if sign != (-1)**self.weight():
-                    self._is_zero.append(len(g)-1)
-                    return self(0)
-            elif c.is_zero():
-                if (sign == -1):
-                    self._is_zero.append(len(g)-1)
-                    return self(0)
-            else:
+            if (c.is_infinity() and sign != (-1)**self.weight()) or \
+               (c.is_zero() and sign == -1):
+                self._zero_cusps.append(c)
+                del self._known_gens[-1]
+                return self(0)
+            elif (not c.is_infinity() and not c.is_zero()):
                 t, eps = self._is_equiv(c, -c)
                 if t and ((eps == 1 and sign == -1) or \
                           (eps == -1 and sign != (-1)**self.weight())):
-                    self._is_zero.append(len(g)-1)
+                    self._zero_cusps.append(c)
+                    del self._known_gens[-1]
                     return self(0)
 
         return BoundarySpaceElement(self, {(len(g)-1):1})
@@ -1258,10 +1285,10 @@ class BoundarySpace_wtk_eps(BoundarySpace):
     def _cusp_index(self, cusp):
         """
         Returns a pair (i, s), where i is the index of the first cusp in
-        self._known_cusps() which is equivalent to cusp, and such that
-        cusp is Gamma0-equivalent to self.character()(s) times
-        self._known_cusps()[i]. If cusp is not equivalent to any known
-        cusp, return (-1, 0).
+        self._known_cusps() which is equivalent to cusp, and such that cusp is
+        Gamma0-equivalent to self.character()(s) times self._known_cusps()[i].
+        If cusp is not equivalent to any known cusp, return (-1, 0); if cusp is
+        equivalent to a cusp known to vanish, return (-2, 0).
 
         EXAMPLES::
 
@@ -1278,11 +1305,12 @@ class BoundarySpace_wtk_eps(BoundarySpace):
             (1, -zeta10^2)
         """
         g = self._known_gens
-        N = self.level()
         for i in range(len(g)):
             t, s = self._is_equiv(cusp, g[i])
             if t:
                 return i, self.__eps(s)
+        if any(self._is_equiv(cusp, c)[0] for c in self._zero_cusps):
+            return (-2, 0)
         return -1, 0
 
     def _coerce_cusp(self, c):
@@ -1337,47 +1365,30 @@ class BoundarySpace_wtk_eps(BoundarySpace):
             sage: B._coerce_cusp(Cusp(0))
             0
         """
-        N    = self.level()
-        k    = self.weight()
         sign = self.sign()
         i, eps = self._cusp_index(c)
         if i != -1:
-            if i in self._is_zero:
+            if i == -2:
                 return self(0)
-            return BoundarySpaceElement(self, {i : eps})
+            else:
+                return BoundarySpaceElement(self, {i : eps})
 
         if sign != 0:
             i2, eps = self._cusp_index(-c)
             if i2 != -1:
-                if i2 in self._is_zero:
-                    return self(0)
-                return BoundarySpaceElement(self, {i2:sign*eps})
+                if i2 == -2: return self(0)
+                else: return BoundarySpaceElement(self, {i2:sign*eps})
 
         # found a new cusp class
         g = self._known_gens
         g.append(c)
-        self._known_gens_repr.append("[%s]"%c)
 
-        ###############################################################
-        # TODO?: This is a very dumb way to check for solutions to an
-        # equation (see Prop 2.30 of Stein's Ph.D. thesis for which
-        # equation); however, computing the cusp equivalence for the
-        # boundary map takes much less time than computing the kernel
-        # of the boundary map, so it's not worth optimizing this now.
-        ###############################################################
-
-        (u, v) = (c.numerator(), c.denominator())
-        gcd = arith.gcd
-        d = gcd(v,N)
-        x = N//d
-
-        for j in range(d):
-            alpha = 1 - j*x
-            if gcd(alpha, N) == 1:
-                if (v*(1-alpha))%N == 0 and (u*(1-alpha))%d == 0:
-                    if self.__eps(alpha) != 1:
-                        self._is_zero.append(len(g)-1)
-                        return self(0)
+        # Does cusp vanish because of stabiliser?
+        s = arithgroup.Gamma0(self.level()).cusp_data(c)[0]
+        if self.__eps(s[1,1]) != 1:
+            self._zero_cusps.append(c)
+            del self._known_gens[-1]
+            return self(0)
 
         # Does class vanish because of sign relations?  The relevant
         # relations are
@@ -1396,17 +1407,20 @@ class BoundarySpace_wtk_eps(BoundarySpace):
         if sign:
             if c.is_zero():
                 if sign == -1:
-                    self._is_zero.append(len(g)-1)
+                    self._zero_cusps.append(c)
+                    del self._known_gens[-1]
                     return self(0)
             elif c.is_infinity():
                 if sign != (-1)**self.weight():
-                    self._is_zero.append(len(g)-1)
+                    self._zero_cusps.append(c)
+                    del self._known_gens[-1]
                     return self(0)
             else:
                 t, s = self._is_equiv(c, -c)
                 if t:
                     if sign != self.__eps(s):
-                        self._is_zero.append(len(g)-1)
+                        self._zero_cusps.append(c)
+                        del self._known_gens[-1]
                         return self(0)
 
         return BoundarySpaceElement(self, {(len(g)-1):1})
