@@ -492,9 +492,9 @@ class FGP_Homset_class(Homset):
         Set of Morphisms from Finitely generated module V/W over Integer Ring with invariants (4, 12) to Finitely generated module V/W over Integer Ring with invariants (4, 12) in Category of modules over Integer Ring
         sage: type(H)
         <class 'sage.modules.fg_pid.fgp_morphism.FGP_Homset_class_with_category'>
-
     """
     Element = FGP_Morphism
+
     def __init__(self, X, Y, category=None):
         """
         EXAMPLES::
@@ -512,8 +512,6 @@ class FGP_Homset_class(Homset):
                 from sage.all import Modules
                 category = Modules(X.base_ring())
         Homset.__init__(self, X, Y, category)
-        self._populate_coercion_lists_(element_constructor = FGP_Morphism,
-                                       coerce_list = [])
 
     def _coerce_map_from_(self, S):
         """
