@@ -27,11 +27,13 @@ from six import iteritems, integer_types
 
 from sage.rings.integer import Integer
 from sage.structure.element import MonoidElement
+from sage.structure.richcmp import richcmp, richcmp_not_equal
 
 
 def is_FreeMonoidElement(x):
     return isinstance(x, FreeMonoidElement)
 
+
 class FreeMonoidElement(MonoidElement):
     """
     Element of a free monoid.
@@ -118,14 +120,16 @@ class FreeMonoidElement(MonoidElement):
         v = self._element_list
         x = self.parent().variable_names()
         for i in range(len(v)):
-            if len(s) > 0: s += "*"
+            if len(s) > 0:
+                s += "*"
             g = x[int(v[i][0])]
             e = v[i][1]
             if e == 1:
                 s += "%s"%g
             else:
                 s += "%s^%s"%(g,e)
-        if len(s) == 0: s = "1"
+        if len(s) == 0:
+            s = "1"
         return s
 
     def _latex_(self):
@@ -152,7 +156,8 @@ class FreeMonoidElement(MonoidElement):
                 s += "%s"%(g,)
             else:
                 s += "%s^{%s}"%(g,e)
-        if len(s) == 0: s = "1"
+        if len(s) == 0:
+            s = "1"
         return s
 
     def __call__(self, *x, **kwds):
@@ -276,56 +281,36 @@ class FreeMonoidElement(MonoidElement):
             s += x[1]
         return s
 
-    def __cmp__(self,y):
-##         """
-##         The comparison operator, defined via x = self:
-##             x < y <=> x.__cmp__(y) == -1
-##             x == y <=> x.__cmp__(y) == 0
-##             x > y <=> x.__cmp__(y) == 1
-##         It is not possible to use __cmp__ to define a
-##         non-totally ordered poset.
-##         Question: How can the operators <, >, ==, !=,
-##         <=, and >= be defined for a general poset?
-##         N.B. An equal operator __equal__ may or may not
-##         have been introduced to define == and != but can
-##         not be used in conjunction with __cmp__.
-##        """
-        if not isinstance(y,FreeMonoidElement) or y.parent() != self.parent():
-            #raise TypeError, "Argument y (= %s) is of the wrong type."%y
-            return 1
-        n = len(self)
-        m = len(y)
-        if n < m:
-            return -1
-        elif m < n:
-            return 1
-        elif n == 0:
-            return 0 # n = m = 0 hence x = y = 1
-        x_elt = self._element_list
-        y_elt = y._element_list
-        for i in range(len(x_elt)):
-            k = x_elt[i][0]
-            l = y_elt[i][0]
-            if k < l:
-                return -1
-            elif k > l:
-                return 1
-            e = x_elt[i][1]
-            f = y_elt[i][1]
-            if e < f:
-                # x_elt is longer so compare next index
-                if x_elt[i+1][0] < l:
-                    return -1
-                else:
-                    return 1
-            elif f < e:
-                # y_elt is longer so compare next index
-                if k < y_elt[i+1][0]:
-                    return -1
-                else:
-                    return 1
-        return 0 # x = self and y are equal
+    def _richcmp_(self, other, op):
+        """
+        Compare two free monoid elements with the same parents.
 
+        The ordering is first by increasing length, then lexicographically
+        on the underlying word.
+
+        EXAMPLES::
+
+            sage: S = FreeMonoid(3, 'a')
+            sage: (x,y,z) = S.gens()
+            sage: x * y < y * x
+            True
+
+            sage: a = FreeMonoid(5, 'a').gens()
+            sage: x = a[0]*a[1]*a[4]**3
+            sage: x < x
+            False
+            sage: x == x
+            True
+            sage: x >= x*x
+            False
+        """
+        m = sum(i for x, i in self._element_list)
+        n = sum(i for x, i in other._element_list)
+        if m != n:
+            return richcmp_not_equal(m, n, op)
+        v = tuple([x for x, i in self._element_list for j in range(i)])
+        w = tuple([x for x, i in other._element_list for j in range(i)])
+        return richcmp(v, w, op)
 
     def _acted_upon_(self, x, self_on_left):
         """
