@@ -41,9 +41,8 @@ TACHYON_PIXEL = 1/200.0
 
 from .shapes import Text, Sphere
 
-from sage.structure.element import is_Vector
-
 
+@rename_keyword(alpha='opacity')
 def line3d(points, thickness=1, radius=None, arrow_head=False, **kwds):
     r"""
     Draw a 3d line joining a sequence of points.
@@ -162,6 +161,7 @@ def line3d(points, thickness=1, radius=None, arrow_head=False, **kwds):
         w._set_extra_kwds(kwds)
         return w
 
+@rename_keyword(alpha='opacity')
 @options(opacity=1, color="blue", aspect_ratio=[1,1,1], thickness=2)
 def bezier3d(path, **options):
     """
@@ -281,13 +281,18 @@ def polygon3d(points, **options):
 
     A bent transparent green triangle::
 
+        sage: polygon3d([[1, 2, 3], [0,1,0], [1,0,1], [3,0,0]], color=(0,1,0), opacity=0.7)
+        Graphics3d Object
+
+    This is the same as using ``alpha=0.7``::
+
         sage: polygon3d([[1, 2, 3], [0,1,0], [1,0,1], [3,0,0]], color=(0,1,0), alpha=0.7)
         Graphics3d Object
     """
     from sage.plot.plot3d.index_face_set import IndexFaceSet
     return IndexFaceSet([range(len(points))], points, **options)
 
-
+@rename_keyword(alpha='opacity')
 @options(opacity=1, color=(0,0,1))
 def polygons3d(faces, points, **options):
     """
@@ -330,9 +335,6 @@ def frame3d(lower_left, upper_right, **kwds):
     - ``upper_right`` -- the upper right corner of the frame, as a
       list, tuple, or vector.
 
-    Type ``line3d.options`` for a dictionary of the default
-    options for lines, which are also available.
-
     EXAMPLES:
 
     A frame::
@@ -390,9 +392,6 @@ def frame_labels(lower_left, upper_right,
     - ``eps`` -- (default: 1) a parameter for how far away from the frame
       to put the labels.
 
-    Type ``line3d.options`` for a dictionary of the default
-    options for lines, which are also available.
-
     EXAMPLES:
 
     We can use it directly::
@@ -482,9 +481,6 @@ def ruler(start, end, ticks=4, sub_ticks=4, absolute=False, snap=False, **kwds):
     - ``snap`` -- (default: ``False``) if ``True``, snaps to an implied
       grid.
 
-    Type ``line3d.options`` for a dictionary of the default
-    options for lines, which are also available.
-
     EXAMPLES:
 
     A ruler::
@@ -591,9 +587,6 @@ def ruler_frame(lower_left, upper_right, ticks=4, sub_ticks=4, **kwds):
     - ``sub_ticks`` -- (default: 4) the number of shown
       subdivisions between each major tick.
 
-    Type ``line3d.options`` for a dictionary of the default
-    options for lines, which are also available.
-
     EXAMPLES:
 
     A ruler frame::
@@ -616,7 +609,7 @@ def ruler_frame(lower_left, upper_right, ticks=4, sub_ticks=4, **kwds):
 
 ###########################
 
-
+@rename_keyword(alpha='opacity')
 def sphere(center=(0,0,0), size=1, **kwds):
     r"""
     Return a plot of a sphere of radius ``size`` centered at
@@ -981,23 +974,24 @@ class Line(PrimitiveObject):
         corners = set(corners)
         cmds = []
         cmd = None
+        name = ''
         for P in self.points:
             TP = P if T is None else T(P)
             if P in corners:
                 if cmd:
                     cmds.append(cmd + " {%s %s %s} " % TP)
-                    cmds.append(self.texture.jmol_str('$'+name))
+                    cmds.append(self.texture.jmol_str('$' + name))
                 type = 'arrow' if self.arrow_head and P is last_corner else 'curve'
                 name = render_params.unique_name('line')
                 cmd = "draw %s diameter %s %s {%s %s %s} " % (name, int(self.thickness), type, TP[0], TP[1], TP[2])
             else:
                 cmd += " {%s %s %s} " % TP
         cmds.append(cmd)
-        cmds.append(self.texture.jmol_str('$'+name))
+        cmds.append(self.texture.jmol_str('$' + name))
         return cmds
 
     def corners(self, corner_cutoff=None, max_len=None):
-        """
+        r"""
         Figure out where the curve turns too sharply to pretend it is
         smooth.
 
@@ -1093,7 +1087,7 @@ class Line(PrimitiveObject):
                 count += 1
             return corners
 
-
+@rename_keyword(alpha='opacity')
 def point3d(v, size=5, **kwds):
     """
     Plot a point or list of points in 3d space.
@@ -1166,7 +1160,7 @@ def point3d(v, size=5, **kwds):
     if l == 3:
         try:
             # check if the first element can be changed to a float
-            tmp = RDF(v[0])
+            RDF(v[0])
             return Point(v, size, **kwds)
         except TypeError:
             pass
