@@ -13,8 +13,9 @@ from __future__ import print_function
 from sage.misc.all import prod
 from sage.arith.all import LCM
 from sage.matrix.matrix_space import MatrixSpace
+from sage.matrix.constructor import matrix
 from sage.rings.integer_ring import IntegerRing
-from sage.rings.rational_field import RationalField
+from sage.rings.rational_field import RationalField, QQ
 from sage.rings.integer import Integer
 from sage.rings.finite_rings.finite_field_constructor import FiniteField
 import copy
@@ -118,24 +119,20 @@ def is_GlobalGenus(G):
     for loc in G._local_symbols:
         p = loc._prime
         sym = loc._symbol
-        v = sum([ s[0]*s[1] for s in sym ])
+        v = sum([ss[0] * ss[1] for ss in sym])
         a = D // (p**v)
-        b = Integer(prod([ s[2] for s in sym ]))
+        b = Integer(prod([ss[2] for ss in sym]))
         if p == 2:
             if not is_2_adic_genus(sym):
-                # print "False in is_2_adic_genus(sym)"
                 return False
             if (a*b).kronecker(p) != 1:
-                # print "False in (%s*%s).kronecker(%s)"%(a,b,p)
                 return False
             oddity -= loc.excess()
         else:
             if a.kronecker(p) != b:
-                # print "False in %s.kronecker(%s) != *%s"%(a,p,b)
                 return False
             oddity += loc.excess()
-    if oddity%8 != 0:
-        # print "False in oddity"
+    if oddity % 8 != 0:
         return False
     return True
 
@@ -446,7 +443,6 @@ def canonical_2_adic_reduction(genus_symbol_quintuple_list):
         for i in compart:
             genus_symbol_quintuple_list[i][4] = 0
         genus_symbol_quintuple_list[compart[0]][4] = oddity
-    #print "End oddity fusion:", canonical_symbol
     # Sign walking:
     trains = canonical_2_adic_trains(genus_symbol_quintuple_list)
     for train in trains:
@@ -460,13 +456,9 @@ def canonical_2_adic_reduction(genus_symbol_quintuple_list):
                     if t1-1 in compart or t1 in compart:
                         o = canonical_symbol[compart[0]][4]
                         canonical_symbol[compart[0]][4] = (o+4) % 8
-    #print "End sign walking:", canonical_symbol
     return canonical_symbol
 
 
-
-
-
 def basis_complement(B):
     """
     Given an echelonized basis matrix (over a field), calculate a
@@ -1084,9 +1076,7 @@ class Genus_Symbol_p_adic_ring(object):
         else:
             for s in self._symbol:
                 CS_string += " {%s}^{%s}" % (p**s[0], s[2]*s[1])
-        return "\\mbox{Genus symbol at } %s\mbox{: }%s" % (p,CS_string)
-
-
+        return "\\mbox{Genus symbol at } %s\\mbox{: }%s" % (p,CS_string)
 
     def __eq__(self, other):
         """
@@ -1243,6 +1233,41 @@ class Genus_Symbol_p_adic_ring(object):
             return self._symbol
 
 
+    def gram_matrix(self, check=True):
+        r"""
+        Return a gram matrix of a representative of this local genus.
+
+        INPUT:
+
+        - check (default: ``True``) -- double check the result
+
+        EXAMPLES::
+
+            sage: from sage.quadratic_forms.genera.genus import p_adic_symbol
+            sage: from sage.quadratic_forms.genera.genus import Genus_Symbol_p_adic_ring
+            sage: A = DiagonalQuadraticForm(ZZ, [1,2,3,4]).Hessian_matrix()
+            sage: p = 2
+            sage: G2 = Genus_Symbol_p_adic_ring(p, p_adic_symbol(A, p, 2));
+            sage: G2.gram_matrix()
+            [2 0|0|0]
+            [0 6|0|0]
+            [---+-+-]
+            [0 0|4|0]
+            [---+-+-]
+            [0 0|0|8]
+        """
+        G = []
+        p = self._prime
+        symbol = self.symbol_tuple_list()
+        for block in symbol:
+            G.append(_gram_from_jordan_block(p, block))
+        G = matrix.block_diagonal(G)
+        # check calculation
+        if check:
+            symG = p_adic_symbol(G, p, symbol[-1][0])
+            assert Genus_Symbol_p_adic_ring(p, symG) == self, "oops"
+        return G
+
 
     def symbol_tuple_list(self):
         """
@@ -1836,3 +1861,151 @@ class GenusSymbol_global_ring(object):
         """
         r, s = self.signature_pair_of_matrix()
         return (-1)**s*prod([ G.determinant() for G in self._local_symbols ])
+
+
+    def discriminant_form(self):
+        r"""
+        Return the discriminant form associated to this genus.
+
+        EXAMPLES::
+
+            sage: from sage.quadratic_forms.genera.genus import GenusSymbol_global_ring
+            sage: A = matrix.diagonal(ZZ, [2,-4,6,8])
+            sage: GS = GenusSymbol_global_ring(A)
+            sage: GS.discriminant_form()
+            Finite quadratic module over Integer Ring with invariants (2, 2, 4, 24)
+            Gram matrix of the quadratic form with values in Q/2Z:
+            [ 1/2    0    0    0]
+            [   0  3/2    0    0]
+            [   0    0  7/4    0]
+            [   0    0    0 7/24]
+            sage: A = matrix.diagonal(ZZ, [1,-4,6,8])
+            sage: GS = GenusSymbol_global_ring(A)
+            sage: GS.discriminant_form()
+            Finite quadratic module over Integer Ring with invariants (2, 4, 24)
+            Gram matrix of the quadratic form with values in Q/Z:
+            [ 1/2    0    0]
+            [   0  3/4    0]
+            [   0    0 7/24]
+        """
+        from sage.modules.torsion_quadratic_module import TorsionQuadraticForm
+        qL = []
+        for gs in self._local_symbols:
+            p = gs._prime
+            for block in gs.symbol_tuple_list():
+                qL.append(_gram_from_jordan_block(p, block, True))
+        q = matrix.block_diagonal(qL)
+        return TorsionQuadraticForm(q)
+
+def _gram_from_jordan_block(p, block, discr_form=False):
+    r"""
+    Return the gram matrix of this jordan block.
+
+    This is a helper for :meth:`discriminant_form` and :meth:`gram_matrix`.
+    No input checks.
+
+    INPUT:
+
+    - ``p`` -- a prime number
+
+    - ``block`` -- a list of 3 integers or 5 integers if `p` is `2`
+
+    - ``discr_form`` -- bool (default: ``False``); if ``True`` invert the scales
+      to obtain a gram matrix for the discriminant form instead.
+
+    EXAMPLES::
+
+        sage: from sage.quadratic_forms.genera.genus import _gram_from_jordan_block
+        sage: block = [1, 3, 1]
+        sage: _gram_from_jordan_block(5, block)
+        [5 0 0]
+        [0 5 0]
+        [0 0 5]
+        sage: block = [1, 4, 7, 1, 2]
+        sage: _gram_from_jordan_block(2, block)
+        [0 2 0 0]
+        [2 0 0 0]
+        [0 0 2 0]
+        [0 0 0 2]
+
+    For the discriminant form we obtain::
+
+        sage: block = [1, 3, 1]
+        sage: _gram_from_jordan_block(5, block, True)
+        [4/5   0   0]
+        [  0 2/5   0]
+        [  0   0 2/5]
+        sage: block = [1, 4, 7, 1, 2]
+        sage: _gram_from_jordan_block(2, block, True)
+        [  0 1/2   0   0]
+        [1/2   0   0   0]
+        [  0   0 1/2   0]
+        [  0   0   0 1/2]
+        """
+    from sage.quadratic_forms.genera.normal_form import _min_nonsquare
+    level = block[0]
+    rk = block[1]
+    det = block[2]
+    if p == 2:
+        o = block[3]
+        t = block[4]
+        U = matrix(QQ,2,[0,1,1,0])
+        V = matrix(QQ,2,[2,1,1,2])
+        W = matrix(QQ,1,[1])
+        if o == 0:
+            if det in [1, 7]:
+                qL = (rk // 2) * [U]
+            else:
+                qL = (rk//2 - 1)*[U] + [V]
+        if o == 1:
+            if rk % 2 == 1:
+                qL = max(0, (rk - 3) // 2) * [U]
+                if t*det % 8 in [3, 5]:
+                    qL += [V]
+                elif rk >= 3:
+                    qL += [U]
+                qL += [t * W]
+            else:
+                if det in [3, 5]:
+                    det = -1
+                else:
+                    det = 1
+                qL = max(0, (rk - 4) // 2) * [U]
+                if (det , t) == (1, 0):
+                    qL += [U, 1 * W, 7 * W]
+                if (det , t) == (1, 2):
+                    qL += [U, 1 * W, 1 * W]
+                if (det , t) == (1, 4):
+                    qL += [V, 1 * W, 3 * W]
+                if (det , t) == (1, 6):
+                    qL += [U, 7 * W, 7 * W]
+                if (det , t) == (-1, 0):
+                    qL += [V, 1 * W, 7 * W]
+                if (det , t) == (-1, 2):
+                    qL += [U, 3 * W, 7 * W]
+                if (det , t) == (-1, 4):
+                    qL += [U, 1 * W, 3 * W]
+                if (det , t) == (-1, 6):
+                    qL += [U, 1 * W, 5 * W]
+                # if the rank is 2 there is a U too much
+                if rk == 2:
+                    qL = qL[-2:]
+        q = matrix.block_diagonal(qL)
+        if discr_form:
+            q = q / 2**level
+        else:
+            q = q * 2**level
+    if p != 2 and discr_form:
+        q = matrix.identity(QQ, rk)
+        d = 2**(rk % 2)
+        if Integer(d).kronecker(p) != det:
+            u = _min_nonsquare(p)
+            q[0,0] = u
+        q = q * (2 / p**level)
+    if p != 2 and not discr_form:
+        q = matrix.identity(QQ, rk)
+        if det != 1:
+            u = _min_nonsquare(p)
+            q[0,0] = u
+        q = q * p**level
+    return q
