@@ -87,11 +87,12 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
-from sage.rings.all import Zp, ZZ, GF, QQ
+from sage.rings.all import Zp, ZZ, GF
 from sage.matrix.constructor import Matrix
 from copy import copy
 from sage.rings.finite_rings.integer_mod import mod
 
+
 def collect_small_blocks(G):
     r"""
     Return the blocks as list.
@@ -680,7 +681,6 @@ def _jordan_2_adic(G):
             pivot = _find_min_p(D, cnt)
             piv1 = pivot[1]
             piv2 = pivot[2]
-            minval_last = minval
             minval = pivot[0]
             # the smallest valuation is on the diagonal
             if piv1 == piv2:
@@ -1068,7 +1068,6 @@ def _partial_normal_form_of_block(G):
         [0 0 0 0 0 0 0 0 0 0 0 7]
     """
     D = copy(G)
-    R = D.base_ring()
     n = D.ncols()
     B = copy(G.parent().identity_matrix())     # the transformation matrix
     blocks = _get_small_block_indices(D)
@@ -1086,7 +1085,6 @@ def _partial_normal_form_of_block(G):
                 U += [i,i+1]
         if len(W) == 3:
             # W W W transforms to W U or W V
-            T = _relations(D[W,W], 2)
             B[W,:] = _relations(D[W,W],2) * B[W,:]
             D = B * G * B.T
             if mod(D[W[1:], W[1:]].det().unit_part(), 8) == 3:
@@ -1105,6 +1103,7 @@ def _partial_normal_form_of_block(G):
     D = B * G * B.T
     return D, B, len(W)
 
+
 def _relations(G,n):
     r"""
     Return relations of `2`-adic quadratic forms.
@@ -1320,9 +1319,6 @@ def _relations(G,n):
         e1 = G[0,0].unit_part()
         e2 = G[1,1].unit_part()
         e3 = G[2,2].unit_part()
-        s1 = e1 + e2 + e3
-        s2 = e1*e2 + e1*e3 + e2*e3
-        s3 = e1*e2*e3
         B = Matrix(R,3,[1,1,1,e2,-e1,0,e3,0,-e1])
     if n == 3:
         B = Matrix(R,4,[1,1,1,0, 1,1,0,1, 1,0,-1,-1, 0,1,-1,-1])
@@ -1370,6 +1366,7 @@ def _relations(G,n):
     D, B1 = _normalize(B*G*B.T)
     return B1*B
 
+
 def _two_adic_normal_forms(G, partial=False):
     r"""
     Return the 2-adic normal form of a symmetric matrix.
