@@ -173,7 +173,7 @@ class BackendBase(SageObject):
         internally by the display manager.
 
         You may return backend-specific subclasses of existing output
-        containers. This allows you to attach backend-specifc
+        containers. This allows you to attach backend-specific
         functionality to the output container.
 
         EXAMPLES::
@@ -207,7 +207,7 @@ class BackendBase(SageObject):
             False
         """
         return False
-    
+
     def max_width(self):
         """
         Return the number of characters that fit into one output line
@@ -309,14 +309,14 @@ class BackendBase(SageObject):
             OutputPlainText container
             sage: out.text
             buffer containing 139 bytes
-            sage: out.text.get()
+            sage: out.text.get_str()
             '[0,\n 1,\n 2,\n 3,\n 4,\n 5,\n 6,\n 7,\n 8,\n 9,\n
             10,\n 11,\n 12,\n 13,\n 14,\n 15,\n 16,\n 17,\n 18,\n
             19,\n 20,\n 21,\n 22,\n 23,\n 24,\n 25,\n 26,\n 27,\n
             28,\n 29]'
 
             sage: out = backend.plain_text_formatter(list(range(20)), concatenate=True)
-            sage: out.text.get()
+            sage: out.text.get_str()
             '0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19'
        """
         from sage.repl.display.pretty_print import SagePrettyPrinter
@@ -359,13 +359,13 @@ class BackendBase(SageObject):
             OutputAsciiArt container
             sage: out.ascii_art
             buffer containing 114 bytes
-            sage: print(out.ascii_art.get())
+            sage: print(out.ascii_art.get_str())
             [ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
             <BLANKLINE>
              22, 23, 24, 25, 26, 27, 28, 29 ]
-            sage: backend.ascii_art_formatter([1,2,3], concatenate=False).ascii_art.get()
+            sage: backend.ascii_art_formatter([1,2,3], concatenate=False).ascii_art.get_str()
             '[ 1, 2, 3 ]'
-            sage: backend.ascii_art_formatter([1,2,3], concatenate=True ).ascii_art.get()
+            sage: backend.ascii_art_formatter([1,2,3], concatenate=True).ascii_art.get_str()
             '1 2 3'
         """
         from sage.typeset.ascii_art import ascii_art, empty_ascii_art
@@ -407,14 +407,14 @@ class BackendBase(SageObject):
             OutputUnicodeArt container
             sage: out.unicode_art
             buffer containing 114 bytes
-            sage: print(out.unicode_art.get())
+            sage: print(out.unicode_art.get_str())
             [ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
             <BLANKLINE>
             22, 23, 24, 25, 26, 27, 28, 29 ]
 
-            sage: backend.unicode_art_formatter([1,2,3], concatenate=False).unicode_art.get()
+            sage: backend.unicode_art_formatter([1,2,3], concatenate=False).unicode_art.get_str()
             '[ 1, 2, 3 ]'
-            sage: backend.unicode_art_formatter([1,2,3], concatenate=True ).unicode_art.get()
+            sage: backend.unicode_art_formatter([1,2,3], concatenate=True).unicode_art.get_str()
             '1 2 3'
         """
         from sage.typeset.unicode_art import unicode_art, empty_unicode_art
@@ -456,23 +456,23 @@ class BackendBase(SageObject):
             OutputLatex container
             sage: out.latex
             buffer containing 45 bytes
-            sage: out.latex.get()
+            sage: out.latex.get_str()
             '\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{1}{2}'
             sage: out.mathjax()
             '<html><script type="math/tex; mode=display">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{1}{2}</script></html>'
 
             sage: out = backend.latex_formatter([1/2, x, 3/4, ZZ], concatenate=False)
-            sage: out.latex.get()
+            sage: out.latex.get_str()
             '\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[\\frac{1}{2}, x, \\frac{3}{4}, \\Bold{Z}\\right]'
             sage: out = backend.latex_formatter([1/2, x, 3/4, ZZ], concatenate=True)
-            sage: out.latex.get()
+            sage: out.latex.get_str()
             '\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{1}{2} x \\frac{3}{4} \\Bold{Z}'
 
         TESTS::
 
-            sage: backend.latex_formatter([], concatenate=False).latex.get()
+            sage: backend.latex_formatter([], concatenate=False).latex.get_str()
             '\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[\\right]'
-            sage: backend.latex_formatter([], concatenate=True).latex.get()
+            sage: backend.latex_formatter([], concatenate=True).latex.get_str()
             '\\newcommand{\\Bold}[1]{\\mathbf{#1}}'
         """
         concatenate = kwds.get('concatenate', False)
@@ -666,5 +666,4 @@ class BackendSimple(BackendBase):
             sage: backend.display_immediately(plain_text, plain_text)
             Example plain text output
         """
-        print(rich_output.text.get())
-
+        print(rich_output.text.get_str())
