@@ -24,14 +24,14 @@ EXAMPLES::
     The Sage display manager using the doctest backend
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2015 Volker Braun <vbraun.name@gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
 #                  http://www.gnu.org/licenses/
-#*****************************************************************************
+# ****************************************************************************
 
 
 import warnings
@@ -57,6 +57,7 @@ class DisplayException(Exception):
     """
     pass
 
+
 class OutputTypeException(DisplayException):
     """
     Wrong Output container.
@@ -78,6 +79,7 @@ class OutputTypeException(DisplayException):
     """
     pass
 
+
 class RichReprWarning(UserWarning):
     """
     Warning that is throws if a call to ``_rich_repr_`` fails.
@@ -471,7 +473,7 @@ class DisplayManager(SageObject):
         return output
 
     def _preferred_text_formatter(self, obj, plain_text=None, **kwds):
-        """
+        r"""
         Return the preferred textual representation
 
         INPUT:
@@ -540,7 +542,7 @@ class DisplayManager(SageObject):
             if type(plain_text) is not OutputPlainText:
                 raise OutputTypeException('backend returned wrong output type, require PlainText')
             return plain_text
-        out =  self._backend.plain_text_formatter(obj, **kwds)
+        out = self._backend.plain_text_formatter(obj, **kwds)
         if type(out) is not OutputPlainText:
             raise OutputTypeException('backend returned wrong output type, require PlainText')
         return out
@@ -744,7 +746,7 @@ class DisplayManager(SageObject):
         """
         if online:
             from sage.misc.package import installed_packages
-            version = installed_packages()['threejs']
+            version = installed_packages()['threejs'].split('.')[0]
             return """
 <script src="https://cdn.rawgit.com/mrdoob/three.js/{0}/build/three.min.js"></script>
 <script src="https://cdn.rawgit.com/mrdoob/three.js/{0}/examples/js/controls/OrbitControls.js"></script>
@@ -834,6 +836,4 @@ class DisplayManager(SageObject):
         self._backend.display_immediately(plain_text, rich_output)
 
 
-
-
 get_display_manager = DisplayManager.get_instance
