@@ -602,8 +602,7 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic):
         else:
             raise MemoryError("creating the list would exhaust memory")
         N = self.__order
-        H = [i for i in range(N) if gcd(i, N) == 1]
-        return H
+        return [i for i in range(N) if gcd(i, N) == 1]
 
     @cached_method
     def multiplicative_subgroups(self):
@@ -1008,7 +1007,7 @@ In the latter case, please inform the developers.""".format(self.order()))
         return factor(self.__order, int_=(self.__order < 2**31))
 
     def factored_unit_order(self):
-        """
+        r"""
         Return a list of :class:`Factorization` objects, each the factorization
         of the order of the units in a `\ZZ / p^n \ZZ` component of this group
         (using the Chinese Remainder Theorem).
@@ -1196,7 +1195,7 @@ In the latter case, please inform the developers.""".format(self.order()))
             i = i + 1
 
     def _coerce_map_from_(self, S):
-        """
+        r"""
         EXAMPLES::
 
             sage: R = Integers(15)
@@ -1509,8 +1508,8 @@ In the latter case, please inform the developers.""".format(self.order()))
                     orders.append(o)
         elif algorithm == 'pari':
             _, orders, gens = self.order().__pari__().znstar()
-            gens = map(self, gens)
-            orders = map(integer.Integer, orders)
+            gens = [self(g) for g in gens]
+            orders = [integer.Integer(o) for o in orders]
         else:
             raise ValueError('unknown algorithm %r for computing the unit group' % algorithm)
         return AbelianGroupWithValues(gens, orders, values_group=self)
@@ -1585,7 +1584,7 @@ Integers = IntegerModRing
 
 # Register unpickling methods for backward compatibility.
 
-from sage.structure.sage_object import register_unpickle_override
+from sage.misc.persist import register_unpickle_override
 register_unpickle_override('sage.rings.integer_mod_ring', 'IntegerModRing_generic', IntegerModRing_generic)
 
 def crt(v):
