@@ -85,7 +85,6 @@ from sage.structure.parent import Parent
 from sage.structure.coerce import py_scalar_to_element
 from sage.structure.coerce_maps import CallableConvertMap, DefaultConvertMap_unique
 from sage.categories.basic import QuotientFields, Rings
-from sage.categories.morphism import Morphism
 from sage.categories.map import Section
 
 
@@ -295,7 +294,6 @@ class FractionField_generic(ring.Field):
             sage: 1/(R.gen(0) + R.gen(1))
             1/(x + y)
         """
-        from sage.rings.integer_ring import ZZ
         from sage.rings.rational_field import QQ
         from sage.rings.number_field.number_field_base import NumberField
         from sage.rings.polynomial.laurent_polynomial_ring import \
@@ -441,7 +439,7 @@ class FractionField_generic(ring.Field):
         return "Fraction Field of %s" % self._R
 
     def _latex_(self):
-        """
+        r"""
         Return a latex representation of ``self``.
 
         EXAMPLES::
@@ -690,6 +688,23 @@ class FractionField_generic(ring.Field):
         """
         return not (self == other)
 
+    def __hash__(self):
+        """
+        Compute the hash of ``self``.
+
+        EXAMPLES::
+
+            sage: h0 = hash(Frac(ZZ['x']))
+            sage: h1 = hash(Frac(ZZ['x']))
+            sage: h2 = hash(Frac(QQ['x']))
+            sage: h3 = hash(ZZ['x'])
+            sage: h0 == h1 and h1 != h2 and h1 != h3
+            True
+        """
+        # to avoid having exactly the same hash as the base ring,
+        # we change this hash using a random number
+        return hash(self._R) ^ 147068341996611
+
     def ngens(self):
         """
         This is the same as for the parent object.
@@ -783,7 +798,6 @@ class FractionField_generic(ring.Field):
                                    self._R._random_nonzero_element(*args, **kwds),
                                    coerce=False, reduce=True)
 
-
     def some_elements(self):
         r"""
         Return some elements in this field.
@@ -812,6 +826,43 @@ class FractionField_generic(ring.Field):
                     ret.append(self(a)/self(b))
         return ret
 
+    def _gcd_univariate_polynomial(self, f, g):
+        r"""
+        Helper method used to compute polynomial gcds over this field.
+
+        See :meth:`sage.rings.polynomial.polynomial_element.Polynomial.gcd`.
+
+        TESTS::
+
+            sage: A.<x,y> = ZZ[]
+            sage: C.<z> = Frac(A)[]
+            sage: c = (2*y^2 - 11*x - 2*y + 1)/(-x^2 + x*y - 2*y^2)
+            sage: p = (c*z^2 + x^10*z + 1)^6
+            sage: q = (z^2 + c*x^10*z + 1)^6
+            sage: g = p.gcd(q)
+            sage: g
+            1
+            sage: g.parent() is p.parent()
+            True
+            sage: (p*(z-x)).gcd(q*(z-x))
+            z - x
+            sage: C.zero().gcd(2*z)
+            z
+            sage: (x*z).gcd(0)
+            z
+            sage: C.zero().gcd(0)
+            0
+        """
+        if g.is_zero():
+            if f.is_zero():
+                return f
+            else:
+                return f.monic()
+        Pol = f.parent()
+        Num = Pol.change_ring(self.base())
+        f1 = Num(f.numerator())
+        g1 = Num(g.numerator())
+        return Pol(f1.gcd(g1)).monic()
 
 class FractionField_1poly_field(FractionField_generic):
     """
@@ -916,7 +967,7 @@ class FractionField_1poly_field(FractionField_generic):
             sage: K = R.fraction_field()
             sage: L = K.function_field()
             sage: f = K.coerce_map_from(L); f # indirect doctest
-            Isomorphism morphism:
+            Isomorphism:
               From: Rational function field in t over Finite Field of size 5
               To:   Fraction Field of Univariate Polynomial Ring in t over Finite Field of size 5
             sage: f(~L.gen())
