@@ -966,3 +966,304 @@ class LocalGeneric(CommutativeRing):
                 tester.assertEqual(y.valuation(), 0)
             z = y.residue()
             tester.assertEqual(x, z)
+
+    def _matrix_smith_form(self, M, transformation, integral, exact):
+        r"""
+        Return the Smith normal form of the matrix `M`.
+
+        This method gets called by
+        :meth:`sage.matrix.matrix2.Matrix.smith_form` to compute the Smith
+        normal form over local rings and fields.
+
+        The entries of the Smith normal form are normalized such that non-zero
+        entries of the diagonal are powers of the distinguished uniformizer.
+
+        INPUT:
+
+        - ``M`` -- a matrix over this ring
+
+        - ``transformation`` -- a boolean; whether the transformation matrices
+        are returned
+
+        - ``integral`` -- a subring of the base ring or ``True``; the entries
+        of the transformation matrices are in this ring.  If ``True``, the
+        entries are in the ring of integers of the base ring.
+
+        - ``exact`` -- boolean.  If ``True``, the diagonal smith form will
+          be exact, or raise a ``PrecisionError`` if this is not posssible.
+          If ``False``, the diagonal entries will be inexact, but the
+          transformation matrices will be exact.
+
+        EXAMPLES::
+
+            sage: A = Zp(5, prec=10, print_mode="digits")
+            sage: M = matrix(A, 2, 2, [2, 7, 1, 6])
+
+            sage: S, L, R = M.smith_form()  # indirect doctest
+            sage: S
+            [ ...1     0]
+            [    0 ...10]
+            sage: L
+            [...222222223          ...]
+            [...444444444         ...2]
+            sage: R
+            [...0000000001 ...2222222214]
+            [            0 ...0000000001]
+
+        If not needed, it is possible to avoid the computation of
+        the transformations matrices `L` and `R`::
+
+            sage: M.smith_form(transformation=False)  # indirect doctest
+            [ ...1     0]
+            [    0 ...10]
+
+        This method works for rectangular matrices as well::
+
+            sage: M = matrix(A, 3, 2, [2, 7, 1, 6, 3, 8])
+            sage: S, L, R = M.smith_form()  # indirect doctest
+            sage: S
+            [ ...1     0]
+            [    0 ...10]
+            [    0     0]
+            sage: L
+            [...222222223          ...          ...]
+            [...444444444         ...2          ...]
+            [...444444443         ...1         ...1]
+            sage: R
+            [...0000000001 ...2222222214]
+            [            0 ...0000000001]
+
+        If some of the elementary divisors have valuation larger than the
+        minimum precision of any entry in the matrix, then they are
+        reported as an inexact zero::
+
+            sage: A = ZpCA(5, prec=10)
+            sage: M = matrix(A, 2, 2, [5, 5, 5, 5])
+            sage: M.smith_form(transformation=False, exact=False)  # indirect doctest
+            [5 + O(5^10)     O(5^10)]
+            [    O(5^10)     O(5^10)]
+
+        However, an error is raised if the precision on the entries is
+        not enough to determine which column to use as a pivot at some point::
+
+            sage: M = matrix(A, 2, 2, [A(0,5), A(5^6,10), A(0,8), A(5^7,10)]); M
+            [       O(5^5) 5^6 + O(5^10)]
+            [       O(5^8) 5^7 + O(5^10)]
+            sage: M.smith_form(transformation=False, exact=False)  # indirect doctest
+            Traceback (most recent call last):
+            ...
+            PrecisionError: not enough precision to compute Smith normal form
+
+        TESTS::
+
+            sage: A = ZpCR(5, prec=10)
+            sage: M = zero_matrix(A, 2)
+            sage: M.smith_form(transformation=False)  # indirect doctest
+            [0 0]
+            [0 0]
+
+            sage: M = matrix(2, 2, [ A(0,10), 0, 0, 0] )
+            sage: M.smith_form(transformation=False)  # indirect doctest
+            Traceback (most recent call last):
+            ...
+            PrecisionError: some elementary divisors indistinguishable from zero (try exact=False)
+            sage: M.smith_form(transformation=False, exact=False)  # indirect doctest
+            [O(5^10) O(5^10)]
+            [O(5^10) O(5^10)]
+        """
+        from sage.rings.all import infinity
+        from sage.matrix.constructor import matrix
+        from .precision_error import PrecisionError
+        from copy import copy
+        n = M.nrows()
+        m = M.ncols()
+        if m > n:
+            ## It's easier below if we can always deal with precision on left.
+            if transformation:
+                d, u, v = self._matrix_smith_form(M.transpose(), True, integral, exact)
+                return d.transpose(), v.transpose(), u.transpose()
+            else:
+                return self._matrix_smith_form(M.transpose(), False, integral, exact).transpose()
+        smith = M.parent()(0)
+        S = copy(M)
+        Z = self.integer_ring()
+        if integral is None or integral is self or integral is (not self.is_field()):
+            integral = not self.is_field()
+            R = self
+        elif integral is True or integral is Z:
+            # This is a field, but we want the integral smith form
+            # The diagonal matrix may not be integral, but the transformations should be
+            R = Z
+            integral = True
+        elif integral is False or integral is self.fraction_field():
+            # This is a ring, but we want the field smith form
+            # The diagonal matrix should be over this ring, but the transformations should not
+            R = self.fraction_field()
+            integral = False
+        else:
+            raise NotImplementedError("Smith normal form over this subring")
+        ## the difference between ball_prec and inexact_ring is just for lattice precision.
+        ball_prec = R._prec_type() in ['capped-rel','capped-abs']
+        inexact_ring = R._prec_type() not in ['fixed-mod','floating-point']
+        precM = min(x.precision_absolute() for x in M.list())
+
+        if transformation:
+            from sage.matrix.special import identity_matrix
+            left = identity_matrix(R,n)
+            right = identity_matrix(R,m)
+
+        if ball_prec and precM is infinity: # capped-rel and M = 0 exactly
+            return (smith, left, right) if transformation else smith
+
+        val = -infinity
+        for piv in range(m): # m <= n
+            curval = infinity
+            pivi = pivj = piv
+            # allzero tracks whether every possible pivot is zero.
+            # if so, we can stop.  allzero is also used in detecting some
+            # precision problems: if we can't determine what pivot has
+            # the smallest valuation, or if exact=True and some elementary
+            # divisor is zero modulo the working precision
+            allzero = True
+            # allexact is tracked because there is one case where we can correctly
+            # deduce the exact smith form even with some elementary divisors zero:
+            # if the bottom right block consists entirely of exact zeros.
+            allexact = True
+            for i in range(piv,n):
+                for j in range(piv,m):
+                    Sij = S[i,j]
+                    v = Sij.valuation()
+                    allzero = allzero and Sij.is_zero()
+                    if exact: # we only care in this case
+                        allexact = allexact and Sij.precision_absolute() is infinity
+                    if v < curval:
+                        pivi = i; pivj = j
+                        curval = v
+                        if v == val: break
+                else: continue
+                break
+            val = curval
+
+            if inexact_ring and not allzero and val >= precM:
+                if ball_prec:
+                    raise PrecisionError("not enough precision to compute Smith normal form")
+                precM = min([ S[i,j].precision_absolute() for i in range(piv,n) for j in range(piv,m) ])
+                if val >= precM:
+                    raise PrecisionError("not enough precision to compute Smith normal form")
+
+            if allzero:
+                if exact:
+                    if allexact:
+                        # We need to finish checking allexact since we broke out of the loop early
+                        for i in range(i,n):
+                            for j in range(piv,m):
+                                allexact = allexact and S[i,j].precision_absolute() is infinity
+                                if not allexact: break
+                            else: continue
+                            break
+                    if not allexact:
+                        raise PrecisionError("some elementary divisors indistinguishable from zero (try exact=False)")
+                break
+
+            # We swap the lowest valuation pivot into position
+            S.swap_rows(pivi,piv)
+            S.swap_columns(pivj,piv)
+            if transformation:
+                left.swap_rows(pivi,piv)
+                right.swap_columns(pivj,piv)
+
+            # ... and clear out this row and column.  Note that we
+            # will deal with precision later, thus the call to lift_to_precision
+            smith[piv,piv] = self(1) << val
+            inv = (S[piv,piv] >> val).inverse_of_unit()
+            if ball_prec:
+                inv = inv.lift_to_precision()
+            for i in range(piv+1,n):
+                scalar = -inv * Z(S[i,piv] >> val)
+                if ball_prec:
+                    scalar = scalar.lift_to_precision()
+                S.add_multiple_of_row(i,piv,scalar,piv+1)
+                if transformation:
+                    left.add_multiple_of_row(i,piv,scalar)
+            if transformation:
+                left.rescale_row(piv,inv)
+                for j in range(piv+1,m):
+                    scalar = -inv * Z(S[piv,j] >> val)
+                    if ball_prec:
+                        scalar = scalar.lift_to_precision()
+                    right.add_multiple_of_column(j,piv,scalar)
+        else:
+            # We use piv as an upper bound on a range below, and need to set it correctly
+            # in the case that we didn't break out of the loop
+            piv = m
+        # We update the precision on left
+        # The bigoh measures the effect of multiplying by row operations
+        # on the left in order to clear out the digits in the smith form
+        # with valuation at least precM
+        if ball_prec and exact and transformation:
+            for j in range(n):
+                delta = min(left[i,j].valuation() - smith[i,i].valuation() for i in range(piv))
+                if delta is not infinity:
+                    for i in range(n):
+                        left[i,j] = left[i,j].add_bigoh(precM + delta)
+        ## Otherwise, we update the precision on smith
+        if ball_prec and not exact:
+            smith = smith.apply_map(lambda x: x.add_bigoh(precM))
+        ## We now have to adjust the elementary divisors (and precision) in the non-integral case
+        if not integral:
+            for i in range(piv):
+                v = smith[i,i].valuation()
+                if transformation:
+                    for j in range(n):
+                        left[i,j] = left[i,j] >> v
+                if exact:
+                    smith[i,i] = self(1)
+                else:
+                    for j in range(n):
+                        smith[i,j] = smith[i,j] >> v
+        if transformation:
+            return smith, left, right
+        else:
+            return smith
+
+    def _test_matrix_smith(self, **options):
+        r"""
+        Test that :meth:`_matrix_smith_form` works correctly.
+
+        EXAMPLES::
+
+            sage: ZpCA(5, 15)._test_matrix_smith()
+
+        """
+        tester = self._tester(**options)
+        tester.assertEqual(self.residue_field().characteristic(), self.residue_characteristic())
+
+        from itertools import chain
+        from sage.all import MatrixSpace
+        from .precision_error import PrecisionError
+        matrices = chain(*[MatrixSpace(self, n, m).some_elements() for n in (1,3,7) for m in (1,4,7)])
+        for M in tester.some_elements(matrices):
+            bases = [self]
+            if self is not self.integer_ring():
+                bases.append(self.integer_ring())
+            for base in bases:
+                try:
+                    S,U,V = M.smith_form(integral=base)
+                except PrecisionError:
+                    continue
+
+                if self.is_exact() or self._prec_type() not in ['fixed-mod','floating-point']:
+                    tester.assertEqual(U*M*V, S)
+
+                tester.assertEqual(U.nrows(), U.ncols())
+                tester.assertEqual(U.base_ring(), base)
+
+                tester.assertEqual(V.nrows(), V.ncols())
+                tester.assertEqual(V.base_ring(), base)
+
+                for d in S.diagonal():
+                    if not d.is_zero():
+                        tester.assertTrue(d.unit_part().is_one())
+
+                for (d,dd) in zip(S.diagonal(), S.diagonal()[1:]):
+                    tester.assertTrue(d.divides(dd))
