@@ -211,9 +211,6 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
         """
         return self._printer._print_mode()
 
-    #def element_class(self):
-    #    return self._element_class
-
     def characteristic(self):
         r"""
         Returns the characteristic of self, which is always 0.
@@ -373,6 +370,26 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
         """
         return [self(i) for i in self.residue_class_field()]
 
+    def _fraction_field_key(self, print_mode=None):
+        """
+        Changes print_mode from a dictionary to a tuple and raises a deprecation warning if it is present.
+
+        EXAMPLES::
+
+            sage: Zp(5)._fraction_field_key()
+            sage: Zp(5)._fraction_field_key({"pos":False})
+            doctest:warning
+            ...
+            DeprecationWarning: Use the change method if you want to change print options in fraction_field()
+            See http://trac.sagemath.org/23227 for details.
+            (('pos', False),)
+        """
+        if print_mode is not None:
+            from sage.misc.superseded import deprecation
+            deprecation(23227, "Use the change method if you want to change print options in fraction_field()")
+            return tuple(sorted(print_mode.items()))
+
+    @cached_method(key=_fraction_field_key)
     def fraction_field(self, print_mode=None):
         r"""
         Returns the fraction field of this ring or field.
@@ -399,12 +416,35 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
             sage: K = R.fraction_field(); repr(K(1/3))[3:]
             '31313131313131313132'
             sage: L = R.fraction_field({'max_ram_terms':4}); repr(L(1/3))[3:]
+            doctest:warning
+            ...
+            DeprecationWarning: Use the change method if you want to change print options in fraction_field()
+            See http://trac.sagemath.org/23227 for details.
             '3132'
             sage: U.<a> = Zq(17^4, 6, print_mode='val-unit', print_max_terse_terms=3)
             sage: U.fraction_field()
             Unramified Extension in a defined by x^4 + 7*x^2 + 10*x + 3 with capped relative precision 6 over 17-adic Field
             sage: U.fraction_field({"pos":False}) == U.fraction_field()
             False
+
+        TESTS::
+
+            sage: R = ZpLC(2); R
+            doctest:...: FutureWarning: This class/method/function is marked as experimental. It, its functionality or its interface might change without a formal deprecation.
+            See http://trac.sagemath.org/23505 for details.
+            2-adic Ring with lattice-cap precision
+            sage: K = R.fraction_field(); K
+            2-adic Field with lattice-cap precision
+
+            sage: K = QpLC(2); K2 = K.fraction_field({'mode':'terse'})
+            sage: K2 is K
+            False
+            sage: K = QpLC(2, label='test'); K
+            2-adic Field with lattice-cap precision (label: test)
+            sage: K.fraction_field()
+            2-adic Field with lattice-cap precision (label: test)
+            sage: K.fraction_field({'mode':'series'}) is K
+            True
         """
         if self.is_field() and print_mode is None:
             return self
@@ -436,12 +476,37 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
             sage: R = K.integer_ring(); repr(R(1/3))[3:]
             '31313131313131313132'
             sage: S = K.integer_ring({'max_ram_terms':4}); repr(S(1/3))[3:]
+            doctest:warning
+            ...
+            DeprecationWarning: Use the change method if you want to change print options in integer_ring()
+            See http://trac.sagemath.org/23227 for details.
             '3132'
             sage: U.<a> = Qq(17^4, 6, print_mode='val-unit', print_max_terse_terms=3)
             sage: U.integer_ring()
             Unramified Extension in a defined by x^4 + 7*x^2 + 10*x + 3 with capped relative precision 6 over 17-adic Ring
-            sage: U.fraction_field({"pos":False}) == U.fraction_field()
+            sage: U.fraction_field({"print_mode":"terse"}) == U.fraction_field()
+            doctest:warning
+            ...
+            DeprecationWarning: Use the change method if you want to change print options in fraction_field()
+            See http://trac.sagemath.org/23227 for details.
             False
+
+        TESTS::
+
+            sage: K = QpLC(2); K
+            2-adic Field with lattice-cap precision
+            sage: R = K.integer_ring(); R
+            2-adic Ring with lattice-cap precision
+
+            sage: R = ZpLC(2); R2 = R.integer_ring({'mode':'terse'})
+            sage: R2 is R
+            False
+            sage: R = ZpLC(2, label='test'); R
+            2-adic Ring with lattice-cap precision (label: test)
+            sage: R.integer_ring()
+            2-adic Ring with lattice-cap precision (label: test)
+            sage: R.integer_ring({'mode':'series'}) is R
+            True
         """
         #Currently does not support fields with non integral defining polynomials.  This should change when the padic_general_extension framework gets worked out.
         if not self.is_field() and print_mode is None:
@@ -449,6 +514,8 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
         if print_mode is None:
             return self.change(field=False)
         else:
+            from sage.misc.superseded import deprecation
+            deprecation(23227, "Use the change method if you want to change print options in integer_ring()")
             return self.change(field=False, **print_mode)
 
     def teichmuller(self, x, prec = None):
@@ -640,13 +707,15 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
             z = x + y
             tester.assertIs(z.parent(), self)
             zprec = min(x.precision_absolute(), y.precision_absolute())
-            if not self.is_floating_point():
+            if self.is_lattice_prec():
+                tester.assertGreaterEqual(z.precision_absolute(), zprec)
+            elif not self.is_floating_point():
                 tester.assertEqual(z.precision_absolute(), zprec)
             tester.assertGreaterEqual(z.valuation(), min(x.valuation(),y.valuation()))
             if x.valuation() != y.valuation():
                 tester.assertEqual(z.valuation(), min(x.valuation(),y.valuation()))
-            tester.assert_(y.is_equal_to(z-x,zprec))
-            tester.assert_(x.is_equal_to(z-y,zprec))
+            tester.assertTrue(y.is_equal_to(z-x,zprec))
+            tester.assertTrue(x.is_equal_to(z-y,zprec))
 
     def _test_sub(self, **options):
         """
@@ -678,13 +747,15 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
             z = x - y
             tester.assertIs(z.parent(), self)
             zprec = min(x.precision_absolute(), y.precision_absolute())
-            if not self.is_floating_point():
+            if self.is_lattice_prec():
+                tester.assertGreaterEqual(z.precision_absolute(), zprec)
+            elif not self.is_floating_point():
                 tester.assertEqual(z.precision_absolute(), zprec)
             tester.assertGreaterEqual(z.valuation(), min(x.valuation(),y.valuation()))
             if x.valuation() != y.valuation():
                 tester.assertEqual(z.valuation(), min(x.valuation(),y.valuation()))
-            tester.assert_((-y).is_equal_to(z - x,zprec))
-            tester.assert_(x.is_equal_to(z + y,zprec))
+            tester.assertTrue((-y).is_equal_to(z - x,zprec))
+            tester.assertTrue(x.is_equal_to(z + y,zprec))
 
     def _test_invert(self, **options):
         """
@@ -788,8 +859,10 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
                 else:
                     tester.assertFalse(y.is_zero())
                     tester.assertIs(z.parent(), self if self.is_fixed_mod() else self.fraction_field())
-                    tester.assertEqual(z.precision_relative(), min(x.precision_relative(), y.precision_relative()))
-                    tester.assertEqual(z.valuation(), x.valuation() - y.valuation())
+                    # The following might be false if there is an absolute cap
+                    # tester.assertEqual(z.precision_relative(), min(x.precision_relative(), y.precision_relative()))
+                    if not x.is_zero():
+                        tester.assertEqual(z.valuation(), x.valuation() - y.valuation())
                     tester.assertEqual(xx, x)
 
     def _test_neg(self, **options):
@@ -1010,6 +1083,44 @@ class pAdicGeneric(PrincipalIdealDomain, LocalGeneric):
         """
         pass
 
+    def valuation(self):
+        r"""
+        Return the `p`-adic valuation on this ring.
+
+        OUTPUT:
+
+        a valuation that is normalized such that the rational prime `p` has
+        valuation 1.
+
+        EXAMPLES::
+
+            sage: K = Qp(3)
+            sage: R.<a> = K[]
+            sage: L.<a> = K.extension(a^3 - 3)
+            sage: v = L.valuation(); v
+            3-adic valuation
+            sage: v(3)
+            1
+            sage: L(3).valuation()
+            3
+
+        The normalization is chosen such that the valuation restricts to the
+        valuation on the base ring::
+
+            sage: v(3) == K.valuation()(3)
+            True
+            sage: v.restriction(K) == K.valuation()
+            True
+
+        .. SEEALSO::
+
+            :meth:`NumberField_generic.valuation() <sage.rings.number_field.number_field.NumberField_generic.valuation>`,
+            :meth:`Order.valuation() <sage.rings.number_field.order.Order.valuation>`
+
+        """
+        from sage.rings.padics.padic_valuation import pAdicValuation
+        return pAdicValuation(self)
+
 class ResidueReductionMap(Morphism):
     """
     Reduction map from a p-adic ring or field to its residue field or ring.
