@@ -5,21 +5,24 @@ AUTHOR:
 
 - Xavier Caruso (2018-02): initial version
 
-TESTS::
+TESTS:
+
+We create some rings and run the test suite for them. We skip the Smith form
+tests because they take a few minutes as of mid 2018, see :trac:`25431`::
 
     sage: R = ZpLC(2)
     doctest:...: FutureWarning: This class/method/function is marked as experimental. It, its functionality or its interface might change without a formal deprecation.
     See http://trac.sagemath.org/23505 for details.
-    sage: TestSuite(R).run(skip=['_test_teichmuller'])
+    sage: TestSuite(R).run(skip=['_test_teichmuller', '_test_matrix_smith']) # long time
 
     sage: R = ZpLF(2)
-    sage: TestSuite(R).run(skip=['_test_teichmuller'])
+    sage: TestSuite(R).run(skip=['_test_teichmuller', '_test_matrix_smith']) # long time
 
     sage: R = QpLC(2)
-    sage: TestSuite(R).run(skip=['_test_teichmuller'])
+    sage: TestSuite(R).run(skip=['_test_teichmuller', '_test_matrix_smith']) # long time
 
     sage: R = QpLF(2)
-    sage: TestSuite(R).run(skip=['_test_teichmuller'])
+    sage: TestSuite(R).run(skip=['_test_teichmuller', '_test_matrix_smith']) # long time
 """
 
 # ****************************************************************************
@@ -430,7 +433,6 @@ class pAdicLatticeElement(pAdicGenericElement):
             ...
             PrecisionError: Not enough precision
         """
-        p = self._parent.prime()
         val = self._value.valuation()
         prec = self.precision_absolute()
         if val < prec: 
@@ -1045,7 +1047,7 @@ class pAdicLatticeElement(pAdicGenericElement):
             sage: x - y
             O(2^20)
 
-        This function can also be used for coersion/conversion as follows::
+        This function can also be used for coercion/conversion as follows::
 
             sage: K = QpLC(2)
             sage: y = x._copy(K)
@@ -1166,7 +1168,6 @@ class pAdicLatticeElement(pAdicGenericElement):
         """
         if lift_mode != 'simple':
             raise NotImplementedError("Other modes than 'simple' are not implemented yet")
-        p = self._parent.prime()
         prec = self.precision_absolute()
         val = self.valuation()
         expansion = self._value.list(prec)
