@@ -66,9 +66,11 @@ from sage.structure.sequence import Sequence
 from .multi_polynomial import MPolynomial
 from sage.categories.morphism import Morphism
 
+
 def is_MPolynomial(x):
     return isinstance(x, MPolynomial)
 
+
 class MPolynomial_element(MPolynomial):
     def __init__(self, parent, x):
         """
@@ -97,7 +99,7 @@ class MPolynomial_element(MPolynomial):
     ####################
 
     def __call__(self, *x, **kwds):
-        """
+        r"""
         Evaluate this multi-variate polynomial at `x`, where
         `x` is either the tuple of values to substitute in, or one
         can use functional notation `f(a_0,a_1,a_2, \ldots)` to
@@ -150,9 +152,9 @@ class MPolynomial_element(MPolynomial):
             y += c*prod([ x[i]**m[i] for i in range(n) if m[i] != 0])
         return y
 
-    def __cmp__(self, right):
+    def _richcmp_(self, right, op):
         """
-        Compares right to self with respect to the term order of
+        Compare ``self`` to ``right`` with respect to the term order of
         self.parent().
 
         EXAMPLES::
@@ -179,11 +181,8 @@ class MPolynomial_element(MPolynomial):
             sage: x^4*y^7*z^1 < x^4*y^2*z^3
             False
         """
-        try:
-            return self.__element.compare(right.__element,
-                                          self.parent().term_order().sortkey)
-        except AttributeError:
-            return self.__element.compare(right.__element)
+        return self.__element.rich_compare(right.__element, op,
+                                           self.parent().term_order().sortkey)
 
     def _im_gens_(self, codomain, im_gens):
         """
@@ -901,7 +900,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             else:
                 return [tuple(e) for e in exp]
         except AttributeError:
-            self.__exponents = self.element().dict().keys()
+            self.__exponents = list(self.element().dict())
             try:
                 self.__exponents.sort(key=self.parent().term_order().sortkey,
                                       reverse=True)
@@ -914,12 +913,12 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
     def inverse_of_unit(self):
         d = self.element().dict()
-        k = d.keys()
+        k = list(d)
         if self.is_unit():
             if len(k) != 1:
                 raise NotImplementedError
             return ~d[k[0]]
-        raise ArithmeticError("is not a unit")        
+        raise ArithmeticError("is not a unit")
 
     def is_homogeneous(self):
         """
@@ -1413,7 +1412,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             return self.__lc
 
     def lt(self):
-        """
+        r"""
         Returns the leading term of self i.e., self.lc()\*self.lm(). The
         notion of "leading term" depends on the ordering defined in the
         parent ring.
@@ -1436,7 +1435,6 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: f=x+y
             sage: f.lt()
             x
-
         """
         try:
             return self.__lt
@@ -1649,17 +1647,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        - ``proof'' - insist on provably correct results (ignored, always ``True``)
-
-        ALGORITHM: Use univariate factorization code.
-
-        If a polynomial is univariate, the appropriate univariate
-        factorization code is called::
-
-            sage: R.<z> = PolynomialRing(CC,1)
-            sage: f = z^4 - 6*z + 3
-            sage: f.factor()
-            (z - 1.60443920904349) * (z - 0.511399619393097) * (z + 1.05791941421830 - 1.59281852704435*I) * (z + 1.05791941421830 + 1.59281852704435*I)
+        - ``proof'' - insist on provably correct results (default: ``True``)
 
         TESTS:
 
@@ -1700,6 +1688,30 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: R.<x,y> = PolynomialRing(FractionField(K))
             sage: factor(x)
             x
+
+        In the example below, we set the special method
+        ``_factor_multivariate_polynomial()`` in the base ring which is called to
+        factor multivariate polynomials.  This facility can be used to easily
+        extend polynomial factorization to work over new rings you introduce::
+
+             sage: R.<x, y> = PolynomialRing(QQ['z'])
+             sage: (x*y).factor()
+             Traceback (most recent call last):
+             ...
+             NotImplementedError: ...
+             sage: R.base_ring()._factor_multivariate_polynomial = lambda f, **kwargs: f.change_ring(QQ).factor()
+             sage: (x*y).factor()
+             y * x
+             sage: del R.base_ring()._factor_multivariate_polynomial # clean up
+
+        Check that a "multivariate" polynomial in one variable is factored
+        correctly::
+
+            sage: R.<z> = PolynomialRing(CC,1)
+            sage: f = z^4 - 6*z + 3
+            sage: f.factor()
+            (z - 1.60443920904349) * (z - 0.511399619393097) * (z + 1.05791941421830 - 1.59281852704435*I) * (z + 1.05791941421830 + 1.59281852704435*I)
+
         """
         R = self.parent()
 
@@ -1716,6 +1728,10 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
                 F = base_ring(self).factor()
                 return Factorization([(R(f),m) for f,m in F], unit=F.unit())
 
+        base_ring = self.base_ring()
+        if hasattr(base_ring, '_factor_multivariate_polynomial'):
+            return base_ring._factor_multivariate_polynomial(self, proof=proof)
+
         # try to use univariate factoring
         try:
             F = self.univariate_polynomial().factor()
@@ -2017,13 +2033,13 @@ def degree_lowest_rational_function(r,x):
     f = r.numerator()
     g = r.denominator()
     M = f.dict()
-    keys = list(M.keys())
+    keys = list(M)
     numtermsf = len(M)
     degreesf = [keys[j][ix] for j in range(numtermsf)]
     lowdegf = min(degreesf)
     cf = M[keys[degreesf.index(lowdegf)]] ## constant coeff of lowest degree term
     M = g.dict()
-    keys = list(M.keys())
+    keys = list(M)
     numtermsg = len(M)
     degreesg = [keys[j][ix] for j in range(numtermsg)]
     lowdegg = min(degreesg)
