@@ -50,6 +50,8 @@ AUTHORS:
 - Travis Scrimshaw (2012-10-18): Added additional docstrings for full coverage.
   Removed duplicates of ``discriminant()`` and ``signature()``.
 
+- Anna Haensch (2018-03): Added function ``quadratic_defect()``
+
 """
 from __future__ import print_function, absolute_import
 
@@ -69,6 +71,7 @@ from sage.structure.sequence import Sequence
 import sage.rings.number_field.number_field_base as number_field_base
 from sage.misc.fast_methods import Singleton
 
+
 class RationalField(Singleton, number_field_base.NumberField):
     r"""
     The class ``RationalField`` represents the field `\QQ` of rational numbers.
@@ -276,7 +279,7 @@ class RationalField(Singleton, number_field_base.NumberField):
             sage: latex(QQ) # indirect doctest
             \Bold{Q}
         """
-        return "\Bold{Q}"
+        return r"\Bold{Q}"
 
     def __reduce__(self):
         r"""
@@ -333,7 +336,7 @@ class RationalField(Singleton, number_field_base.NumberField):
         """
         from sage.rings.infinity import Infinity
         if p == Infinity:
-            from sage.rings.real_mpfr import create_RealField
+            from sage.rings.real_field import create_RealField
             return create_RealField(prec, **extras)
         else:
             from sage.rings.padics.factory import Qp
@@ -999,7 +1002,7 @@ class RationalField(Singleton, number_field_base.NumberField):
             yield Rational((-b, a))
 
     def random_element(self, num_bound=None, den_bound=None, *args, **kwds):
-        """
+        r"""
         Return an random element of `\QQ`.
 
         Elements are constructed by randomly choosing integers
@@ -1040,7 +1043,6 @@ class RationalField(Singleton, number_field_base.NumberField):
             0
             sage: QQ.random_element(distribution='1/n')
             -1
-
         """
         global ZZ
         if ZZ is None:
@@ -1186,6 +1188,57 @@ class RationalField(Singleton, number_field_base.NumberField):
             yield prod((p**e for p,e in zip(KSgens, ev)), one)
 
 
+    def quadratic_defect(self, a, p, check=True):
+        r"""
+        Return the valuation of the quadratic defect of `a` at `p`.
+
+        INPUT:
+
+        - ``a`` -- an element of ``self``
+        - ``p`` -- a prime ideal or a prime number
+        - ``check`` -- (default: ``True``); check if `p` is prime
+
+        REFERENCE:
+
+        [Kir2016]_
+
+        EXAMPLES::
+
+            sage: QQ.quadratic_defect(0, 7)
+            +Infinity
+            sage: QQ.quadratic_defect(5, 7)
+            0
+            sage: QQ.quadratic_defect(5, 2)
+            2
+            sage: QQ.quadratic_defect(5, 5)
+            1
+        """
+        from sage.rings.all import Infinity
+        from sage.arith.misc import legendre_symbol
+        if not a in self:
+            raise TypeError(str(a) + " must be an element of " + str(self))
+        if p.parent() == ZZ.ideal_monoid():
+            p = p.gen()
+        if check and not p.is_prime():
+            raise ValueError(str(p) + " must be prime")
+        if a.is_zero():
+            return Infinity
+        v, u = self(a).val_unit(p)
+        if v % 2 == 1:
+            return v
+        if p != 2:
+            if legendre_symbol(u, p) == 1:
+                return Infinity
+            else:
+                return v
+        if p == 2:
+            if u % 8 == 1:
+                return Infinity
+            if u % 8 == 5:
+                return v + 2
+            if u % 8 in [3, 7]:
+                return v + 1
+
     #################################
     ## Coercions to interfaces
     #################################
