@@ -806,13 +806,13 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         - ``kind`` -- ``first`` or ``second`` specifying which kind of chebyshev the user would like
           to generate. Defaults to ``first``.
 
-        OUTPUT: :class:`SchemeMorphism_polynomial_affine_space`
+        OUTPUT: :class:`DynamicalSystem_affine`
 
         EXAMPLES::
 
             sage: A.<x> = AffineSpace(QQ, 1)
             sage: A.chebyshev_polynomial(5, 'first')
-            Scheme endomorphism of Affine Space of dimension 1 over Rational Field
+            Dynamical System of Affine Space of dimension 1 over Rational Field
             Defn: Defined on coordinates by sending (x) to
             (16*x^5 - 20*x^3 + 5*x)
 
@@ -820,7 +820,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
             sage: A.<x> = AffineSpace(QQ, 1)
             sage: A.chebyshev_polynomial(3, 'second')
-            Scheme endomorphism of Affine Space of dimension 1 over Rational Field
+            Dynamical System of Affine Space of dimension 1 over Rational Field
             Defn: Defined on coordinates by sending (x) to
             (8*x^3 - 4*x)
 
@@ -853,11 +853,11 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         n = ZZ(n)
         if (n < 0):
             raise ValueError("first parameter 'n' must be a non-negative integer")
-        H = End(self)
+        from sage.dynamics.arithmetic_dynamics.affine_ds import DynamicalSystem_affine
         if kind == 'first':
-            return H([chebyshev_T(n, self.gen(0))])
+            return DynamicalSystem_affine([chebyshev_T(n, self.gen(0))], domain=self)
         elif kind == 'second':
-            return H([chebyshev_U(n, self.gen(0))])
+            return DynamicalSystem_affine([chebyshev_U(n, self.gen(0))], domain=self)
         else:
             raise ValueError("keyword 'kind' must have a value of either 'first' or 'second'")
 
@@ -893,28 +893,40 @@ class AffineSpace_field(AffineSpace_generic):
         """
         return SchemeMorphism_polynomial_affine_space_field(*args, **kwds)
 
-    def points_of_bounded_height(self,bound):
+    def points_of_bounded_height(self, **kwds):
         r"""
         Returns an iterator of the points in this affine space of
         absolute height of at most the given bound.
 
         Bound check  is strict for the rational field.
         Requires this space to be affine space over a number field. Uses the
-        Doyle-Krumm algorithm for computing algebraic numbers up
-        to a given height [Doyle-Krumm]_.
+        Doyle-Krumm algorithm 4 (algorithm 5 for imaginary quadratic) for
+        computing algebraic numbers up to a given height [Doyle-Krumm]_.
+
+        The algorithm requires floating point arithmetic, so the user is
+        allowed to specify the precision for such calculations.
+        Additionally, due to floating point issues, points
+        slightly larger than the bound may be returned. This can be controlled
+        by lowering the tolerance.
 
         INPUT:
 
-        - ``bound`` - a real number.
+        kwds:
+
+        - ``bound`` - a real number
+
+        - ``tolerance`` - a rational number in (0,1] used in doyle-krumm algorithm-4
+
+        - ``precision`` - the precision to use for computing the elements of bounded height of number fields
 
         OUTPUT:
 
-        - an iterator of points in self.
+        - an iterator of points in self
 
         EXAMPLES::
 
             sage: A.<x,y> = AffineSpace(QQ, 2)
-            sage: list(A.points_of_bounded_height(3))
+            sage: list(A.points_of_bounded_height(bound=3))
             [(0, 0), (1, 0), (-1, 0), (1/2, 0), (-1/2, 0), (2, 0), (-2, 0), (0, 1),
             (1, 1), (-1, 1), (1/2, 1), (-1/2, 1), (2, 1), (-2, 1), (0, -1), (1, -1),
             (-1, -1), (1/2, -1), (-1/2, -1), (2, -1), (-2, -1), (0, 1/2), (1, 1/2),
@@ -927,8 +939,8 @@ class AffineSpace_field(AffineSpace_generic):
 
             sage: u = QQ['u'].0
             sage: A.<x,y> = AffineSpace(NumberField(u^2 - 2, 'v'), 2)
-            sage: len(list(A.points_of_bounded_height(6)))
-            121
+            sage: len(list(A.points_of_bounded_height(bound=2, tolerance=0.1)))
+            529
         """
         if (is_RationalField(self.base_ring())):
             ftype = False # stores whether field is a number field or the rational field
@@ -936,8 +948,8 @@ class AffineSpace_field(AffineSpace_generic):
             ftype = True
         else:
             raise NotImplementedError("self must be affine space over a number field.")
-
-        bound = bound**(1/self.base_ring().absolute_degree()) # convert to relative height
+        bound = kwds.pop('bound')
+        B = bound**self.base_ring().absolute_degree() # convert to relative height
 
         n = self.dimension_relative()
         R = self.base_ring()
@@ -945,9 +957,11 @@ class AffineSpace_field(AffineSpace_generic):
         P = [ zero for _ in range(n) ]
         yield self(P)
         if not ftype:
-            iters = [ R.range_by_height(bound) for _ in range(n) ]
+            iters = [ R.range_by_height(B) for _ in range(n) ]
         else:
-            iters = [ R.elements_of_bounded_height(bound) for _ in range(n) ]
+            tol = kwds.pop('tolerance', 1e-2)
+            prec = kwds.pop('precision', 53)
+            iters = [ R.elements_of_bounded_height(bound=B, tolerance=tol, precision=prec) for _ in range(n) ]
         for x in iters: next(x) # put at zero
         i = 0
         while i < n:
@@ -957,9 +971,9 @@ class AffineSpace_field(AffineSpace_generic):
                 i = 0
             except StopIteration:
                 if not ftype:
-                    iters[i] = R.range_by_height(bound) # reset
+                    iters[i] = R.range_by_height(B) # reset
                 else:
-                    iters[i] = R.elements_of_bounded_height(bound)
+                    iters[i] = R.elements_of_bounded_height(bound=B, tolerance=tol, precision=prec)
                 next(iters[i]) # put at zero
                 P[i] = zero
                 i += 1
@@ -1058,7 +1072,7 @@ class AffineSpace_finite_field(AffineSpace_field):
         return SchemeMorphism_polynomial_affine_space_finite_field(*args, **kwds)
 
 #fix the pickles from moving affine_space.py
-from sage.structure.sage_object import register_unpickle_override
+from sage.misc.persist import register_unpickle_override
 register_unpickle_override('sage.schemes.generic.affine_space',
                            'AffineSpace_generic',
                            AffineSpace_generic)
