@@ -126,7 +126,7 @@ def hilbert_class_polynomial(D, algorithm=None):
         raise ValueError("%s is not a valid algorithm"%algorithm)
 
     from sage.quadratic_forms.binary_qf import BinaryQF_reduced_representatives
-    from sage.rings.all import RR, ZZ, ComplexField
+    from sage.rings.all import RR, ComplexField
     from sage.functions.all import elliptic_j
 
     # get all primitive reduced quadratic forms, (necessary to exclude
@@ -139,7 +139,7 @@ def hilbert_class_polynomial(D, algorithm=None):
     # NB: [https://arxiv.org/abs/0802.0979v1], quoting Enge (2006), is
     # incorrect.  Enge writes (2009-04-20 email to John Cremona) "The
     # source is my paper on class polynomials
-    # [http://hal.inria.fr/inria-00001040] It was pointed out to me by
+    # [https://hal.inria.fr/inria-00001040] It was pointed out to me by
     # the referee after ANTS that the constant given there was
     # wrong. The final version contains a corrected constant on p.7
     # which is consistent with your example. It says:
@@ -211,7 +211,8 @@ def cm_j_invariants(K, proof=None):
         sage: len(cm_j_invariants(K))
         23
     """
-    return list(sorted([j for D,f,j in cm_j_invariants_and_orders(K, proof=proof)]))
+    return sorted([j for D,f,j in cm_j_invariants_and_orders(K, proof=proof)])
+
 
 @cached_function
 def cm_j_invariants_and_orders(K, proof=None):
@@ -317,7 +318,6 @@ def cm_orders(h, proof=None):
         84
     """
     h = Integer(h)
-    T = None
     if h <= 0:
         # trivial case
         return []
@@ -404,7 +404,7 @@ def largest_fundamental_disc_with_class_number(h):
 
 @cached_function
 def discriminants_with_bounded_class_number(hmax, B=None, proof=None):
-    """
+    r"""
     Return dictionary with keys class numbers `h\le hmax` and values the
     list of all pairs `(D, f)`, with `D<0` a fundamental discriminant such
     that `Df^2` has class number `h`.  If the optional bound `B` is given,
@@ -451,8 +451,6 @@ def discriminants_with_bounded_class_number(hmax, B=None, proof=None):
     """
     # imports that are needed only for this function
     from sage.structure.proof.proof import get_flag
-    import math
-    from sage.misc.functional import round
 
     # deal with input defaults and type checking
     proof = get_flag(proof, 'number_field')
@@ -554,11 +552,12 @@ def discriminants_with_bounded_class_number(hmax, B=None, proof=None):
         # discriminants; we might as well, since Watkins provides this
         # data.
         for h in T:
-            if len([D for D,f in T[h] if f==1]) != fund_count[h]:
+            if len([DD for DD, ff in T[h] if ff == 1]) != fund_count[h]:
                 raise RuntimeError("number of discriminants inconsistent with Watkins's table")
 
     return T
 
+
 @cached_function
 def is_cm_j_invariant(j, method='new'):
     """
@@ -680,7 +679,7 @@ def is_cm_j_invariant(j, method='new'):
     # divides all the values a_P^2-4N(P), since that is the
     # discriminant of the order containing the Frobenius at P.  So we
     # end up with a finite number (usually one) of candidate
-    # discriminats to test.  Each is tested by checking that its class
+    # discriminants to test.  Each is tested by checking that its class
     # number is h, and if so then that j is a root of its Hilbert
     # class polynomial.  In practice non CM curves will be eliminated
     # by the local test at a small number of primes (probably just 2).
