@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-L-series for elliptic curves
+`L`-series for elliptic curves
 
 AUTHORS:
 
@@ -25,7 +25,7 @@ from six.moves import range
 
 from sage.structure.sage_object import SageObject
 from sage.rings.all import RealField, RationalField
-from math import sqrt, exp, log, ceil
+from math import sqrt, log, ceil
 import sage.functions.exp_integral as exp_integral
 from sage.misc.all import verbose
 
@@ -161,7 +161,6 @@ class Lseries_ell(SageObject):
                        eps = self.__E.root_number(),
                        poles = [],
                        prec = prec)
-        gp = L.gp()
         s = 'e = ellinit(%s);'%list(self.__E.minimal_model().a_invariants())
         s += 'a(k) = ellak(e, k);'
         L.init_coeffs('a(k)', 1, pari_precode = s,
