@@ -556,7 +556,6 @@ def _multiply_point(E, R, P, m):
 
     # now walk through list and compute g(k)
     g = {0 : R(0), 1 : R(1), 2 : R(-1), 3 : B8, 4 : B6**2 - B4*B8}
-    last = [0, 1, 2, 3, 4]     # last few k
     for i in reversed(intervals):
         k = i[0]
         while k < i[1]:
@@ -592,7 +591,6 @@ def _multiply_point(E, R, P, m):
     return theta, omega, psi_m * d
 
 
-
 def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
     r"""
     Compute the cyclotomic p-adic height.
@@ -1074,22 +1072,21 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
         raise NotImplementedError("p (=%s) must be at least 5" % p)
 
     N = int(N)
-    if N <= 2:
-        # a few special cases for small N
-        if N < 1:
-            raise ValueError("N (=%s) must be at least 1" % prec)
 
-        if N == 1:
-            # return simply t + O(t^2)
-            K = Qp(p, 2)
-            return PowerSeriesRing(K, "t")([K(0), K(1, 1)], prec=2)
+    # a few special cases for small N
+    if N < 1:
+        raise ValueError("N (=%s) must be at least 1" % N)
 
+    if N == 1:
+        # return simply t + O(t^2)
+        K = Qp(p, 2)
+        return PowerSeriesRing(K, "t")([K(0), K(1, 1)], prec=2)
 
-        if N == 2:
-            # return t + a_1/2 t^2 + O(t^3)
-            K = Qp(p, 3)
-            return PowerSeriesRing(K, "t")([K(0), K(1, 2),
-                                            K(self.a1()/2, 1)], prec=3)
+    if N == 2:
+        # return t + a_1/2 t^2 + O(t^3)
+        K = Qp(p, 3)
+        return PowerSeriesRing(K, "t")([K(0), K(1, 2),
+                                        K(self.a1()/2, 1)], prec=3)
 
     if self.discriminant().valuation(p) != 0:
         raise NotImplementedError("equation of curve must be minimal at p")
@@ -1631,7 +1628,7 @@ def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, al
 
     # todo: The following strategy won't work at all for p = 2, 3.
 
-    X=self.minimal_model().short_weierstrass_model()
+    X = self.minimal_model().short_weierstrass_model()
 
     assert X.discriminant().valuation(p) == 0, "Something's gone wrong. " \
            "The discriminant of the Weierstrass model should be a unit " \
@@ -1649,14 +1646,12 @@ def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, al
             trace = self.ap(p)
 
         base_ring = rings.Integers(p**adjusted_prec)
-        output_ring = rings.pAdicField(p, prec)
 
         R, x = rings.PolynomialRing(base_ring, 'x').objgen()
         Q = x**3 + base_ring(X.a4()) * x + base_ring(X.a6())
         frob_p = sage.schemes.hyperelliptic_curves.monsky_washnitzer.matrix_of_frobenius(
                          Q, p, adjusted_prec, trace)
 
-
     else:   # algorithm == "sqrtp"
         p_to_prec = p**prec
         R = rings.PolynomialRing(Integers(), "x")
@@ -1668,9 +1663,6 @@ def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, al
         trace = self.ap(p)
         check = True
 
-
-    # return frob_p ## why was this here ?
-
     if check:
         trace_of_frobenius = frob_p.trace().lift() % p**prec
         correct_trace = self.ap(p) % p**prec
@@ -1740,11 +1732,10 @@ def _brent(F, p, N):
         ....:                "incorrect precision output"
     """
     Rx = F.parent()           # Rx = power series ring over Z/p^{N-1} Z
-    R = Rx.base_ring()        # R = Z/p^{N-1} Z
     Qx = PowerSeriesRing(RationalField(), "x")
 
     # initial approximation:
-    G = Rx(1)
+    G = Rx.one()
 
     # loop over an appropriate increasing sequence of lengths s
     for s in misc.newton_method_sizes(N):
