@@ -38,12 +38,9 @@ AUTHORS:
 # (at your option) any later version.
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
-from __future__ import print_function
-from __future__ import absolute_import
+from __future__ import print_function, absolute_import
 
 from sage.calculus.functions import jacobian
-from sage.categories.number_fields import NumberFields
-from sage.categories.homset import Hom, End
 from sage.misc.all import prod
 from sage.misc.cachefunc import cached_method
 from sage.rings.all import Integer
@@ -52,22 +49,21 @@ from sage.rings.complex_field import ComplexField_class
 from sage.rings.complex_interval_field import ComplexIntervalField_class
 from sage.rings.finite_rings.finite_field_constructor import is_PrimeFiniteField
 from sage.rings.fraction_field import FractionField
-from sage.rings.fraction_field_element import is_FractionFieldElement, FractionFieldElement
 from sage.rings.integer_ring import ZZ
 from sage.rings.number_field.order import is_NumberFieldOrder
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.qqbar import QQbar, number_field_elements_from_algebraics
 from sage.rings.quotient_ring import QuotientRing_generic
-from sage.rings.qqbar import QQbar
 from sage.rings.rational_field import QQ
 from sage.rings.real_mpfr import RealField_class
 from sage.rings.real_mpfi import RealIntervalField_class
 from sage.schemes.generic.morphism import SchemeMorphism_polynomial
-from sage.symbolic.constants import e
 from sage.ext.fast_callable import fast_callable
 from sage.misc.lazy_attribute import lazy_attribute
 import sys
+
 from sage.categories.number_fields import NumberFields
+from sage.categories.homset import Hom, End
 _NumberFields = NumberFields()
 from sage.categories.fields import Fields
 _Fields = Fields()
@@ -213,18 +209,18 @@ class SchemeMorphism_polynomial_projective_space(SchemeMorphism_polynomial):
             # morphisms from projective space are always given by
             # homogeneous polynomials of the same degree
             try:
-                d = polys[0].degree()
+                polys[0].degree()
             except AttributeError:
                 polys = [f.lift() for f in polys]
-            if not all([f.is_homogeneous() for f in polys]):
+            if not all(f.is_homogeneous() for f in polys):
                 raise  ValueError("polys (=%s) must be homogeneous" % polys)
             degs = [f.degree() for f in polys]
-            if not all([d == degs[0] for d in degs[1:]]):
+            if not all(d == degs[0] for d in degs[1:]):
                 raise ValueError("polys (=%s) must be of the same degree" % polys)
         self._is_prime_finite_field = is_PrimeFiniteField(polys[0].base_ring())
 
     def __call__(self, x, check=True):
-        """
+        r"""
         Compute the forward image of the point or subscheme ``x`` by this map.
 
         For subschemes, the forward image is computed through elimination.
@@ -541,7 +537,18 @@ class SchemeMorphism_polynomial_projective_space(SchemeMorphism_polynomial):
             sage: f = H([x^2, y^2])
             sage: type(f.as_dynamical_system())
             <class 'sage.dynamics.arithmetic_dynamics.projective_ds.DynamicalSystem_projective_finite_field'>
+
+        ::
+
+            sage: P.<x,y> = ProjectiveSpace(RR, 1)
+            sage: f = DynamicalSystem([x^2 + y^2, y^2], P)
+            sage: g = f.as_dynamical_system()
+            sage: g is f
+            True
         """
+        from sage.dynamics.arithmetic_dynamics.generic_ds import DynamicalSystem
+        if isinstance(self, DynamicalSystem):
+            return self
         if not self.is_endomorphism():
             raise TypeError("must be an endomorphism")
         from sage.dynamics.arithmetic_dynamics.projective_ds import DynamicalSystem_projective
@@ -2026,7 +2033,7 @@ class SchemeMorphism_polynomial_projective_space_field(SchemeMorphism_polynomial
 
     def connected_rational_component(self, P, n=0):
         """
-        Return the component of all ratioanl preimage and forward images.
+        Return the component of all rational preimage and forward images.
 
         EXAMPLES::
 
@@ -2497,4 +2504,4 @@ class SchemeMorphism_polynomial_projective_space_finite_field(SchemeMorphism_pol
         from sage.misc.superseded import deprecation
         deprecation(23479, "use sage.dynamics.arithmetic_dynamics.projective_ds.automorphism_group instead")
         return self.as_dynamical_system().automorphism_group(**kwds)
-    
+
