@@ -87,7 +87,7 @@ def _iter_vectors(n, lower, upper, step=None):
     """
     if step is None:
         if ZZ(lower) >= ZZ(upper):
-            raise ValueError("Expected lower < uppper, but got %d >= %d" % (lower, upper))
+            raise ValueError("Expected lower < upper, but got %d >= %d" % (lower, upper))
         if ZZ(n) <= 0:
             raise ValueError("Expected n>0 but got %d <= 0" % n)
         step = n
