@@ -879,5 +879,5 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
             raise AttributeError("'Sequence_generic' object has no attribute '%s'"%name)
 seq = Sequence
 
-from sage.structure.sage_object import register_unpickle_override
+from sage.misc.persist import register_unpickle_override
 register_unpickle_override('sage.structure.sequence', 'Sequence', Sequence_generic)
