@@ -803,12 +803,13 @@ class CachedRepresentation(six.with_metaclass(ClasscallMetaclass)):
 
     .. rubric:: More on cached representation and identity
 
-    :class:`CachedRepresentation` is implemented by means of a cache. This
-    cache uses weak references. Hence, when all other references to, say,
-    ``MyClass(1)`` have been deleted, the instance is actually deleted from
-    memory. A later call to ``MyClass(1)`` reconstructs the instance from
-    scratch.
-    ::
+    :class:`CachedRepresentation` is implemented by means of a cache.
+    This cache uses weak references in general, but strong references to
+    the most recently created objects. Hence, when all other references
+    to, say, ``MyClass(1)`` have been deleted, the instance is
+    eventually deleted from memory (after enough other objects have been
+    created to remove the strong reference to ``MyClass(1)``). A later
+    call to ``MyClass(1)`` reconstructs the instance from scratch::
 
         sage: class SomeClass(UniqueRepresentation):
         ....:     def __init__(self, i):
@@ -816,20 +817,25 @@ class CachedRepresentation(six.with_metaclass(ClasscallMetaclass)):
         ....:         self.i = i
         ....:     def __del__(self):
         ....:         print("deleting instance for argument %s" % self.i)
-        ....:
+        sage: class OtherClass(UniqueRepresentation):
+        ....:     def __init__(self, i):
+        ....:         pass
         sage: O = SomeClass(1)
         creating new instance for argument 1
         sage: O is SomeClass(1)
         True
         sage: O is SomeClass(2)
         creating new instance for argument 2
-        deleting instance for argument 2
         False
+        sage: L = [OtherClass(i) for i in range(200)]
+        deleting instance for argument 2
         sage: del O
         deleting instance for argument 1
         sage: O = SomeClass(1)
         creating new instance for argument 1
         sage: del O
+        sage: del L
+        sage: L = [OtherClass(i) for i in range(200)]
         deleting instance for argument 1
 
     .. rubric:: Cached representation and pickling
@@ -1001,9 +1007,8 @@ class CachedRepresentation(six.with_metaclass(ClasscallMetaclass)):
     unprocessed arguments will be passed down to
     :meth:`__init__<object.__init__>`.
     """
-    _included_private_doc_ = ["__classcall__"]
 
-    @weak_cached_function # automatically a staticmethod
+    @weak_cached_function(cache=128)  # automatically a staticmethod
     def __classcall__(cls, *args, **options):
         """
         Construct a new object of this class or reuse an existing one.
