@@ -79,14 +79,13 @@ class IndefiniteIntegral(BuiltinFunction):
         if not is_SymbolicVariable(x):
             if len(x.variables()) == 1:
                 nx = x.variables()[0]
-                f = f*x.diff(nx)
+                f = f * x.diff(nx)
                 x = nx
             else:
                 return None
 
         # we try all listed integration algorithms
         for integrator in self.integrators:
-            res = integrator(f, x)
             try:
                 return integrator(f, x)
             except NotImplementedError:
@@ -111,7 +110,7 @@ class IndefiniteIntegral(BuiltinFunction):
             return f.derivative(diff_param).integral(x)
 
     def _print_latex_(self, f, x):
-        """
+        r"""
         EXAMPLES::
 
             sage: from sage.symbolic.integration.integral import indefinite_integral
