@@ -139,7 +139,7 @@ _INTERPRETERS = sorted(filter(lambda c: (isinstance(c, type) and
                        key=lambda c: c.name)
 
 # Tuple of (filename_root, extension, method) where filename_root is the
-# root of the filename to be joined with "_<interpeter_name>".ext and
+# root of the filename to be joined with "_<interpreter_name>".ext and
 # method is the name of a get_ method on InterpreterGenerator that returns
 # the contents of that file
 _INTERPRETER_SOURCES = [
@@ -160,7 +160,8 @@ def build_interp(interp_spec, dir):
         sage: testdir = tmp_dir()
         sage: rdf_interp = RDFInterpreter()
         sage: build_interp(rdf_interp, testdir)
-        sage: open(testdir + '/interp_rdf.c').readline()
+        sage: with open(testdir + '/interp_rdf.c') as f:
+        ....:     f.readline()
         '/* Automatically generated by ... */\n'
     """
 
@@ -185,7 +186,8 @@ def rebuild(dirname, force=False):
         sage: rebuild(testdir)
         Building interpreters for fast_callable
         -> First build of interpreters
-        sage: open(testdir + '/wrapper_el.pyx').readline()
+        sage: with open(testdir + '/wrapper_el.pyx') as f:
+        ....:     f.readline()
         '# Automatically generated by ...\n'
     """
     # This line will show up in "sage -b" (once per upgrade, not every time
